Class: Aws::Odb::Types::AdminPasswordSourceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Note:

AdminPasswordSourceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AdminPasswordSourceConfiguration corresponding to the set member.

The configuration of the admin password source. This is a union, so only one of the following members can be specified.

Defined Under Namespace

Classes: CustomerManagedAwsSecret, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_managed_aws_secretTypes::CustomerManagedAwsSecretConfiguration

The configuration for a customer-managed Amazon Web Services Secrets Manager secret used as the admin password source.



56
57
58
59
60
61
62
63
64
65
# File 'lib/aws-sdk-odb/types.rb', line 56

class AdminPasswordSourceConfiguration < Struct.new(
  :customer_managed_aws_secret,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerManagedAwsSecret < AdminPasswordSourceConfiguration; end
  class Unknown < AdminPasswordSourceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



56
57
58
# File 'lib/aws-sdk-odb/types.rb', line 56

def unknown
  @unknown
end