Class: Aws::Odb::Types::AdminPasswordSourceConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Note:

AdminPasswordSourceConfigurationInput is a union - when making an API calls you must set exactly one of the members.

The input configuration for the admin password source. This is a union, so only one of the following members can be specified.

Defined Under Namespace

Classes: CustomerManagedAwsSecret, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_managed_aws_secretTypes::CustomerManagedAwsSecretConfigurationInput

The configuration for using a customer-managed Amazon Web Services Secrets Manager secret as the admin password source.



79
80
81
82
83
84
85
86
87
88
# File 'lib/aws-sdk-odb/types.rb', line 79

class AdminPasswordSourceConfigurationInput < Struct.new(
  :customer_managed_aws_secret,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerManagedAwsSecret < AdminPasswordSourceConfigurationInput; end
  class Unknown < AdminPasswordSourceConfigurationInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



79
80
81
# File 'lib/aws-sdk-odb/types.rb', line 79

def unknown
  @unknown
end