Class: Aws::Odb::Types::AssociateIamRoleToResourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::AssociateIamRoleToResourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_integration ⇒ String
The Amazon Web Services integration configuration settings for the Amazon Web Services Identity and Access Management (IAM) service role association.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) service role to associate with the resource.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target resource to associate with the Amazon Web Services Identity and Access Management (IAM) service role.
Instance Attribute Details
#aws_integration ⇒ String
The Amazon Web Services integration configuration settings for the Amazon Web Services Identity and Access Management (IAM) service role association.
131 132 133 134 135 136 137 |
# File 'lib/aws-sdk-odb/types.rb', line 131 class AssociateIamRoleToResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) service role to associate with the resource.
131 132 133 134 135 136 137 |
# File 'lib/aws-sdk-odb/types.rb', line 131 class AssociateIamRoleToResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target resource to associate with the Amazon Web Services Identity and Access Management (IAM) service role.
131 132 133 134 135 136 137 |
# File 'lib/aws-sdk-odb/types.rb', line 131 class AssociateIamRoleToResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |