Class: Aws::Odb::Types::AssociateVirtualMachinesToExadbVmClusterInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::AssociateVirtualMachinesToExadbVmClusterInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#desired_node_count ⇒ Integer
The desired number of nodes in the Exascale VM cluster after the association.
-
#exadb_vm_cluster_id ⇒ String
The unique identifier of the Exascale VM cluster to add virtual machines to.
Instance Attribute Details
#desired_node_count ⇒ Integer
The desired number of nodes in the Exascale VM cluster after the association.
155 156 157 158 159 160 |
# File 'lib/aws-sdk-odb/types.rb', line 155 class AssociateVirtualMachinesToExadbVmClusterInput < Struct.new( :exadb_vm_cluster_id, :desired_node_count) SENSITIVE = [] include Aws::Structure end |
#exadb_vm_cluster_id ⇒ String
The unique identifier of the Exascale VM cluster to add virtual machines to.
155 156 157 158 159 160 |
# File 'lib/aws-sdk-odb/types.rb', line 155 class AssociateVirtualMachinesToExadbVmClusterInput < Struct.new( :exadb_vm_cluster_id, :desired_node_count) SENSITIVE = [] include Aws::Structure end |