Class: Aws::Odb::Types::AutonomousDatabaseConnectionUrls
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::AutonomousDatabaseConnectionUrls
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The connection URLs for accessing tools and services for an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apex_url ⇒ String
The URL for accessing Oracle Application Express (APEX) for the Autonomous Database.
-
#database_transforms_url ⇒ String
The URL for accessing Oracle Database Transforms for the Autonomous Database.
-
#graph_studio_url ⇒ String
The URL for accessing Oracle Graph Studio for the Autonomous Database.
-
#machine_learning_notebook_url ⇒ String
The URL for accessing the Oracle Machine Learning notebook for the Autonomous Database.
-
#machine_learning_user_management_url ⇒ String
The URL for accessing Oracle Machine Learning user management for the Autonomous Database.
-
#mongo_db_url ⇒ String
The URL for accessing the MongoDB API for the Autonomous Database.
-
#ords_url ⇒ String
The URL for accessing Oracle REST Data Services (ORDS) for the Autonomous Database.
-
#spatial_studio_url ⇒ String
The URL for accessing Oracle Spatial Studio for the Autonomous Database.
-
#sql_dev_web_url ⇒ String
The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
Instance Attribute Details
#apex_url ⇒ String
The URL for accessing Oracle Application Express (APEX) for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#database_transforms_url ⇒ String
The URL for accessing Oracle Database Transforms for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#graph_studio_url ⇒ String
The URL for accessing Oracle Graph Studio for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#machine_learning_notebook_url ⇒ String
The URL for accessing the Oracle Machine Learning notebook for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#machine_learning_user_management_url ⇒ String
The URL for accessing Oracle Machine Learning user management for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#mongo_db_url ⇒ String
The URL for accessing the MongoDB API for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#ords_url ⇒ String
The URL for accessing Oracle REST Data Services (ORDS) for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#spatial_studio_url ⇒ String
The URL for accessing Oracle Spatial Studio for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |
#sql_dev_web_url ⇒ String
The URL for accessing Oracle SQL Developer Web for the Autonomous Database.
975 976 977 978 979 980 981 982 983 984 985 986 987 |
# File 'lib/aws-sdk-odb/types.rb', line 975 class AutonomousDatabaseConnectionUrls < Struct.new( :apex_url, :database_transforms_url, :graph_studio_url, :machine_learning_notebook_url, :machine_learning_user_management_url, :mongo_db_url, :ords_url, :spatial_studio_url, :sql_dev_web_url) SENSITIVE = [] include Aws::Structure end |