Class: Aws::Odb::Types::AutonomousDatabasePeerSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::AutonomousDatabasePeerSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
A summary of a peer database of an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_arn ⇒ String
The Amazon Resource Name (ARN) of the peer Autonomous Database.
-
#autonomous_database_id ⇒ String
The unique identifier of the peer Autonomous Database.
-
#ocid ⇒ String
The Oracle Cloud Identifier (OCID) of the peer Autonomous Database.
-
#region ⇒ String
The Amazon Web Services Region where the peer Autonomous Database is located.
Instance Attribute Details
#autonomous_database_arn ⇒ String
The Amazon Resource Name (ARN) of the peer Autonomous Database.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-odb/types.rb', line 1010 class AutonomousDatabasePeerSummary < Struct.new( :autonomous_database_id, :autonomous_database_arn, :ocid, :region) SENSITIVE = [] include Aws::Structure end |
#autonomous_database_id ⇒ String
The unique identifier of the peer Autonomous Database.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-odb/types.rb', line 1010 class AutonomousDatabasePeerSummary < Struct.new( :autonomous_database_id, :autonomous_database_arn, :ocid, :region) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The Oracle Cloud Identifier (OCID) of the peer Autonomous Database.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-odb/types.rb', line 1010 class AutonomousDatabasePeerSummary < Struct.new( :autonomous_database_id, :autonomous_database_arn, :ocid, :region) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region where the peer Autonomous Database is located.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/aws-sdk-odb/types.rb', line 1010 class AutonomousDatabasePeerSummary < Struct.new( :autonomous_database_id, :autonomous_database_arn, :ocid, :region) SENSITIVE = [] include Aws::Structure end |