Class: Aws::Odb::Types::AutonomousDatabaseWalletDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The wallet details for an Autonomous Database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#password_source_summaryTypes::WalletPasswordSourceSummary

The summary of the password source configuration for the Autonomous Database wallet.



1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-odb/types.rb', line 1738

class AutonomousDatabaseWalletDetails < Struct.new(
  :status,
  :time_rotated,
  :password_source_summary)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the Autonomous Database wallet.

Returns:

  • (String)


1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-odb/types.rb', line 1738

class AutonomousDatabaseWalletDetails < Struct.new(
  :status,
  :time_rotated,
  :password_source_summary)
  SENSITIVE = []
  include Aws::Structure
end

#time_rotatedTime

The date and time when the Autonomous Database wallet was last rotated.

Returns:

  • (Time)


1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-odb/types.rb', line 1738

class AutonomousDatabaseWalletDetails < Struct.new(
  :status,
  :time_rotated,
  :password_source_summary)
  SENSITIVE = []
  include Aws::Structure
end