Class: Aws::Odb::Types::CloneToRefreshableConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The configuration for creating an Autonomous Database as a refreshable clone.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_refresh_frequency_in_secondsInteger

The frequency, in seconds, at which the refreshable clone is automatically refreshed.

Returns:

  • (Integer)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-odb/types.rb', line 1835

class CloneToRefreshableConfiguration < Struct.new(
  :source_autonomous_database_id,
  :refreshable_mode,
  :auto_refresh_frequency_in_seconds,
  :auto_refresh_point_lag_in_seconds,
  :time_of_auto_refresh_start,
  :open_mode,
  :clone_type)
  SENSITIVE = []
  include Aws::Structure
end

#auto_refresh_point_lag_in_secondsInteger

The time lag, in seconds, between the refreshable clone and its source database.

Returns:

  • (Integer)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-odb/types.rb', line 1835

class CloneToRefreshableConfiguration < Struct.new(
  :source_autonomous_database_id,
  :refreshable_mode,
  :auto_refresh_frequency_in_seconds,
  :auto_refresh_point_lag_in_seconds,
  :time_of_auto_refresh_start,
  :open_mode,
  :clone_type)
  SENSITIVE = []
  include Aws::Structure
end

#clone_typeString

The type of clone to create.

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-odb/types.rb', line 1835

class CloneToRefreshableConfiguration < Struct.new(
  :source_autonomous_database_id,
  :refreshable_mode,
  :auto_refresh_frequency_in_seconds,
  :auto_refresh_point_lag_in_seconds,
  :time_of_auto_refresh_start,
  :open_mode,
  :clone_type)
  SENSITIVE = []
  include Aws::Structure
end

#open_modeString

The mode in which to open the refreshable clone, either read-only or read/write.

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-odb/types.rb', line 1835

class CloneToRefreshableConfiguration < Struct.new(
  :source_autonomous_database_id,
  :refreshable_mode,
  :auto_refresh_frequency_in_seconds,
  :auto_refresh_point_lag_in_seconds,
  :time_of_auto_refresh_start,
  :open_mode,
  :clone_type)
  SENSITIVE = []
  include Aws::Structure
end

#refreshable_modeString

The refresh mode of the refreshable clone, either automatic or manual.

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-odb/types.rb', line 1835

class CloneToRefreshableConfiguration < Struct.new(
  :source_autonomous_database_id,
  :refreshable_mode,
  :auto_refresh_frequency_in_seconds,
  :auto_refresh_point_lag_in_seconds,
  :time_of_auto_refresh_start,
  :open_mode,
  :clone_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_autonomous_database_idString

The unique identifier of the source Autonomous Database to create the refreshable clone from.

Returns:

  • (String)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-odb/types.rb', line 1835

class CloneToRefreshableConfiguration < Struct.new(
  :source_autonomous_database_id,
  :refreshable_mode,
  :auto_refresh_frequency_in_seconds,
  :auto_refresh_point_lag_in_seconds,
  :time_of_auto_refresh_start,
  :open_mode,
  :clone_type)
  SENSITIVE = []
  include Aws::Structure
end

#time_of_auto_refresh_startTime

The date and time at which the automatic refresh of the refreshable clone starts.

Returns:

  • (Time)


1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
# File 'lib/aws-sdk-odb/types.rb', line 1835

class CloneToRefreshableConfiguration < Struct.new(
  :source_autonomous_database_id,
  :refreshable_mode,
  :auto_refresh_frequency_in_seconds,
  :auto_refresh_point_lag_in_seconds,
  :time_of_auto_refresh_start,
  :open_mode,
  :clone_type)
  SENSITIVE = []
  include Aws::Structure
end