Class: Aws::Odb::Types::CloudExadataInfrastructure
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CloudExadataInfrastructure
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Information about an Exadata infrastructure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activated_storage_count ⇒ Integer
The number of storage servers requested for the Exadata infrastructure.
-
#additional_storage_count ⇒ Integer
The number of storage servers requested for the Exadata infrastructure.
-
#availability_zone ⇒ String
The name of the Availability Zone (AZ) where the Exadata infrastructure is located.
-
#availability_zone_id ⇒ String
The AZ ID of the AZ where the Exadata infrastructure is located.
-
#available_storage_size_in_g_bs ⇒ Integer
The amount of available storage, in gigabytes (GB), for the Exadata infrastructure.
-
#cloud_exadata_infrastructure_arn ⇒ String
The Amazon Resource Name (ARN) for the Exadata infrastructure.
-
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier for the Exadata infrastructure.
-
#compute_count ⇒ Integer
The number of database servers for the Exadata infrastructure.
-
#compute_model ⇒ String
The OCI model compute model used when you create or clone an instance: ECPU or OCPU.
-
#cpu_count ⇒ Integer
The total number of CPU cores that are allocated to the Exadata infrastructure.
-
#created_at ⇒ Time
The date and time when the Exadata infrastructure was created.
-
#customer_contacts_to_send_to_oci ⇒ Array<Types::CustomerContact>
The email addresses of contacts to receive notification from Oracle about maintenance updates for the Exadata infrastructure.
-
#data_storage_size_in_t_bs ⇒ Float
The size of the Exadata infrastructure’s data disk group, in terabytes (TB).
-
#database_server_type ⇒ String
The database server model type of the Exadata infrastructure.
-
#db_node_storage_size_in_g_bs ⇒ Integer
The size of the Exadata infrastructure’s local node storage, in gigabytes (GB).
-
#db_server_version ⇒ String
The software version of the database servers (dom0) in the Exadata infrastructure.
-
#display_name ⇒ String
The user-friendly name for the Exadata infrastructure.
-
#last_maintenance_run_id ⇒ String
The Oracle Cloud Identifier (OCID) of the last maintenance run for the Exadata infrastructure.
-
#maintenance_window ⇒ Types::MaintenanceWindow
The scheduling details for the maintenance window.
-
#max_cpu_count ⇒ Integer
The total number of CPU cores available on the Exadata infrastructure.
-
#max_data_storage_in_t_bs ⇒ Float
The total amount of data disk group storage, in terabytes (TB), that’s available on the Exadata infrastructure.
-
#max_db_node_storage_size_in_g_bs ⇒ Integer
The total amount of local node storage, in gigabytes (GB), that’s available on the Exadata infrastructure.
-
#max_memory_in_g_bs ⇒ Integer
The total amount of memory, in gigabytes (GB), that’s available on the Exadata infrastructure.
-
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), that’s allocated on the Exadata infrastructure.
-
#monthly_db_server_version ⇒ String
The monthly software version of the database servers installed on the Exadata infrastructure.
-
#monthly_storage_server_version ⇒ String
The monthly software version of the storage servers installed on the Exadata infrastructure.
-
#next_maintenance_run_id ⇒ String
The OCID of the next maintenance run for the Exadata infrastructure.
-
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the Exadata infrastructure.
-
#oci_url ⇒ String
The HTTPS link to the Exadata infrastructure in OCI.
-
#ocid ⇒ String
The OCID of the Exadata infrastructure.
-
#percent_progress ⇒ Float
The amount of progress made on the current operation on the Exadata infrastructure, expressed as a percentage.
-
#shape ⇒ String
The model name of the Exadata infrastructure.
-
#status ⇒ String
The current status of the Exadata infrastructure.
-
#status_reason ⇒ String
Additional information about the status of the Exadata infrastructure.
-
#storage_count ⇒ Integer
The number of storage servers that are activated for the Exadata infrastructure.
-
#storage_server_type ⇒ String
The storage server model type of the Exadata infrastructure.
-
#storage_server_version ⇒ String
The software version of the storage servers on the Exadata infrastructure.
-
#total_storage_size_in_g_bs ⇒ Integer
The total amount of storage, in gigabytes (GB), on the the Exadata infrastructure.
Instance Attribute Details
#activated_storage_count ⇒ Integer
The number of storage servers requested for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#additional_storage_count ⇒ Integer
The number of storage servers requested for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The name of the Availability Zone (AZ) where the Exadata infrastructure is located.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The AZ ID of the AZ where the Exadata infrastructure is located.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#available_storage_size_in_g_bs ⇒ Integer
The amount of available storage, in gigabytes (GB), for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#cloud_exadata_infrastructure_arn ⇒ String
The Amazon Resource Name (ARN) for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#compute_count ⇒ Integer
The number of database servers for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#compute_model ⇒ String
The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#cpu_count ⇒ Integer
The total number of CPU cores that are allocated to the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the Exadata infrastructure was created.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#customer_contacts_to_send_to_oci ⇒ Array<Types::CustomerContact>
The email addresses of contacts to receive notification from Oracle about maintenance updates for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#data_storage_size_in_t_bs ⇒ Float
The size of the Exadata infrastructure’s data disk group, in terabytes (TB).
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#database_server_type ⇒ String
The database server model type of the Exadata infrastructure. For the list of valid model names, use the ‘ListDbSystemShapes` operation.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#db_node_storage_size_in_g_bs ⇒ Integer
The size of the Exadata infrastructure’s local node storage, in gigabytes (GB).
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#db_server_version ⇒ String
The software version of the database servers (dom0) in the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#last_maintenance_run_id ⇒ String
The Oracle Cloud Identifier (OCID) of the last maintenance run for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#maintenance_window ⇒ Types::MaintenanceWindow
The scheduling details for the maintenance window. Patching and system updates take place during the maintenance window.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#max_cpu_count ⇒ Integer
The total number of CPU cores available on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#max_data_storage_in_t_bs ⇒ Float
The total amount of data disk group storage, in terabytes (TB), that’s available on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#max_db_node_storage_size_in_g_bs ⇒ Integer
The total amount of local node storage, in gigabytes (GB), that’s available on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#max_memory_in_g_bs ⇒ Integer
The total amount of memory, in gigabytes (GB), that’s available on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), that’s allocated on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#monthly_db_server_version ⇒ String
The monthly software version of the database servers installed on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#monthly_storage_server_version ⇒ String
The monthly software version of the storage servers installed on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#next_maintenance_run_id ⇒ String
The OCID of the next maintenance run for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#oci_url ⇒ String
The HTTPS link to the Exadata infrastructure in OCI.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The OCID of the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#percent_progress ⇒ Float
The amount of progress made on the current operation on the Exadata infrastructure, expressed as a percentage.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#shape ⇒ String
The model name of the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#storage_count ⇒ Integer
The number of storage servers that are activated for the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#storage_server_type ⇒ String
The storage server model type of the Exadata infrastructure. For the list of valid model names, use the ‘ListDbSystemShapes` operation.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#storage_server_version ⇒ String
The software version of the storage servers on the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |
#total_storage_size_in_g_bs ⇒ Integer
The total amount of storage, in gigabytes (GB), on the the Exadata infrastructure.
2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 |
# File 'lib/aws-sdk-odb/types.rb', line 2661 class CloudExadataInfrastructure < Struct.new( :cloud_exadata_infrastructure_id, :display_name, :status, :status_reason, :cloud_exadata_infrastructure_arn, :activated_storage_count, :additional_storage_count, :available_storage_size_in_g_bs, :availability_zone, :availability_zone_id, :compute_count, :cpu_count, :customer_contacts_to_send_to_oci, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_server_version, :last_maintenance_run_id, :maintenance_window, :max_cpu_count, :max_data_storage_in_t_bs, :max_db_node_storage_size_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :monthly_db_server_version, :monthly_storage_server_version, :next_maintenance_run_id, :oci_resource_anchor_name, :oci_url, :ocid, :shape, :storage_count, :storage_server_version, :created_at, :total_storage_size_in_g_bs, :percent_progress, :database_server_type, :storage_server_type, :compute_model) SENSITIVE = [] include Aws::Structure end |