Class: Aws::Odb::Types::CloudExadataInfrastructureUnallocatedResources

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about unallocated resources in the Cloud Exadata infrastructure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_autonomous_vm_clustersArray<Types::CloudAutonomousVmClusterResourceDetails>

A list of Autonomous VM clusters associated with this Cloud Exadata Infrastructure.



2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/aws-sdk-odb/types.rb', line 2970

class CloudExadataInfrastructureUnallocatedResources < Struct.new(
  :cloud_autonomous_vm_clusters,
  :cloud_exadata_infrastructure_display_name,
  :exadata_storage_in_t_bs,
  :cloud_exadata_infrastructure_id,
  :local_storage_in_g_bs,
  :memory_in_g_bs,
  :ocpus)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_exadata_infrastructure_display_nameString

The display name of the Cloud Exadata infrastructure.

Returns:

  • (String)


2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/aws-sdk-odb/types.rb', line 2970

class CloudExadataInfrastructureUnallocatedResources < Struct.new(
  :cloud_autonomous_vm_clusters,
  :cloud_exadata_infrastructure_display_name,
  :exadata_storage_in_t_bs,
  :cloud_exadata_infrastructure_id,
  :local_storage_in_g_bs,
  :memory_in_g_bs,
  :ocpus)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_exadata_infrastructure_idString

The unique identifier of the Cloud Exadata infrastructure.

Returns:

  • (String)


2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/aws-sdk-odb/types.rb', line 2970

class CloudExadataInfrastructureUnallocatedResources < Struct.new(
  :cloud_autonomous_vm_clusters,
  :cloud_exadata_infrastructure_display_name,
  :exadata_storage_in_t_bs,
  :cloud_exadata_infrastructure_id,
  :local_storage_in_g_bs,
  :memory_in_g_bs,
  :ocpus)
  SENSITIVE = []
  include Aws::Structure
end

#exadata_storage_in_t_bsFloat

The amount of unallocated Exadata storage available, in terabytes (TB).

Returns:

  • (Float)


2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/aws-sdk-odb/types.rb', line 2970

class CloudExadataInfrastructureUnallocatedResources < Struct.new(
  :cloud_autonomous_vm_clusters,
  :cloud_exadata_infrastructure_display_name,
  :exadata_storage_in_t_bs,
  :cloud_exadata_infrastructure_id,
  :local_storage_in_g_bs,
  :memory_in_g_bs,
  :ocpus)
  SENSITIVE = []
  include Aws::Structure
end

#local_storage_in_g_bsInteger

The amount of unallocated local storage available, in gigabytes (GB).

Returns:

  • (Integer)


2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/aws-sdk-odb/types.rb', line 2970

class CloudExadataInfrastructureUnallocatedResources < Struct.new(
  :cloud_autonomous_vm_clusters,
  :cloud_exadata_infrastructure_display_name,
  :exadata_storage_in_t_bs,
  :cloud_exadata_infrastructure_id,
  :local_storage_in_g_bs,
  :memory_in_g_bs,
  :ocpus)
  SENSITIVE = []
  include Aws::Structure
end

#memory_in_g_bsInteger

The amount of unallocated memory available, in gigabytes (GB).

Returns:

  • (Integer)


2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/aws-sdk-odb/types.rb', line 2970

class CloudExadataInfrastructureUnallocatedResources < Struct.new(
  :cloud_autonomous_vm_clusters,
  :cloud_exadata_infrastructure_display_name,
  :exadata_storage_in_t_bs,
  :cloud_exadata_infrastructure_id,
  :local_storage_in_g_bs,
  :memory_in_g_bs,
  :ocpus)
  SENSITIVE = []
  include Aws::Structure
end

#ocpusInteger

The number of unallocated Oracle CPU Units (OCPUs) available.

Returns:

  • (Integer)


2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
# File 'lib/aws-sdk-odb/types.rb', line 2970

class CloudExadataInfrastructureUnallocatedResources < Struct.new(
  :cloud_autonomous_vm_clusters,
  :cloud_exadata_infrastructure_display_name,
  :exadata_storage_in_t_bs,
  :cloud_exadata_infrastructure_id,
  :local_storage_in_g_bs,
  :memory_in_g_bs,
  :ocpus)
  SENSITIVE = []
  include Aws::Structure
end