Class: Aws::Odb::Types::CloudVmCluster

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about a VM cluster.

Constant Summary collapse

SENSITIVE =
[:ssh_public_keys]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_exadata_infrastructure_arn ⇒ String

The Amazon Resource Name (ARN) of the Exadata infrastructure that this VM cluster belongs to.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#cloud_exadata_infrastructure_id ⇒ String

The unique identifier of the Exadata infrastructure that this VM cluster belongs to.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#cloud_vm_cluster_arn ⇒ String

The Amazon Resource Name (ARN) of the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#cloud_vm_cluster_id ⇒ String

The unique identifier of the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#cluster_name ⇒ String

The name of the Grid Infrastructure (GI) cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#compute_model ⇒ String

The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#cpu_core_count ⇒ Integer

The number of CPU cores enabled on the VM cluster.

Returns:

  • (Integer)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#created_at ⇒ Time

The date and time when the VM cluster was created.

Returns:

  • (Time)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#data_collection_options ⇒ Types::DataCollectionOptions

The set of diagnostic collection options enabled for the VM cluster.



3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#data_storage_size_in_t_bs ⇒ Float

The size of the data disk group, in terabytes (TB), that's allocated for the VM cluster.

Returns:

  • (Float)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#db_node_storage_size_in_g_bs ⇒ Integer

The amount of local node storage, in gigabytes (GB), that's allocated for the VM cluster.

Returns:

  • (Integer)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#db_servers ⇒ Array<String>

The list of database servers for the VM cluster.

Returns:

  • (Array<String>)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#disk_redundancy ⇒ String

The type of redundancy configured for the VM cluster. NORMAL is 2-way redundancy. HIGH is 3-way redundancy.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#display_name ⇒ String

The user-friendly name for the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#domain ⇒ String

The domain of the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#gi_version ⇒ String

The software version of the Oracle Grid Infrastructure (GI) for the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#hostname ⇒ String

The host name for the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#iam_roles ⇒ Array<Types::IamRole>

The Amazon Web Services Identity and Access Management (IAM) service roles associated with the VM cluster.

Returns:



3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#iorm_config_cache ⇒ Types::ExadataIormConfig

The ExadataIormConfig cache details for the VM cluster.



3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#is_local_backup_enabled ⇒ Boolean

Indicates whether database backups to local Exadata storage is enabled for the VM cluster.

Returns:

  • (Boolean)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#is_sparse_diskgroup_enabled ⇒ Boolean

Indicates whether the VM cluster is configured with a sparse disk group.

Returns:

  • (Boolean)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#last_update_history_entry_id ⇒ String

The Oracle Cloud ID (OCID) of the last maintenance update history entry.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#license_model ⇒ String

The Oracle license model applied to the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#listener_port ⇒ Integer

The port number configured for the listener on the VM cluster.

Returns:

  • (Integer)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#memory_size_in_g_bs ⇒ Integer

The amount of memory, in gigabytes (GB), that's allocated for the VM cluster.

Returns:

  • (Integer)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#node_count ⇒ Integer

The number of nodes in the VM cluster.

Returns:

  • (Integer)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#oci_resource_anchor_name ⇒ String

The name of the OCI resource anchor for the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#oci_url ⇒ String

The HTTPS link to the VM cluster in OCI.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#ocid ⇒ String

The OCID of the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#odb_network_arn ⇒ String

The Amazon Resource Name (ARN) of the ODB network associated with this VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#odb_network_id ⇒ String

The unique identifier of the ODB network for the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#percent_progress ⇒ Float

The amount of progress made on the current operation on the VM cluster, expressed as a percentage.

Returns:

  • (Float)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#scan_dns_name ⇒ String

The fully qualified domain name (FQDN) of the DNS record for the Single Client Access Name (SCAN) IP addresses that are associated with the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#scan_dns_record_id ⇒ String

The OCID of the DNS record for the SCAN IP addresses that are associated with the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#scan_ip_ids ⇒ Array<String>

The OCID of the SCAN IP addresses that are associated with the VM cluster.

Returns:

  • (Array<String>)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#shape ⇒ String

The hardware model name of the Exadata infrastructure that's running the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#ssh_public_keys ⇒ Array<String>

The public key portion of one or more key pairs used for SSH access to the VM cluster.

Returns:

  • (Array<String>)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#status ⇒ String

The current status of the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#status_reason ⇒ String

Additional information about the status of the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#storage_size_in_g_bs ⇒ Integer

The amount of local node storage, in gigabytes (GB), that's allocated to the VM cluster.

Returns:

  • (Integer)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#system_version ⇒ String

The operating system version of the image chosen for the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#time_zone ⇒ String

The time zone of the VM cluster.

Returns:

  • (String)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end

#vip_ids ⇒ Array<String>

The virtual IP (VIP) addresses that are associated with the VM cluster. Oracle's Cluster Ready Services (CRS) creates and maintains one VIP address for each node in the VM cluster to enable failover. If one node fails, the VIP is reassigned to another active node in the cluster.

Returns:

  • (Array<String>)


3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
# File 'lib/aws-sdk-odb/types.rb', line 3318

class CloudVmCluster < Struct.new(
  :cloud_vm_cluster_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_vm_cluster_arn,
  :cloud_exadata_infrastructure_id,
  :cloud_exadata_infrastructure_arn,
  :cluster_name,
  :cpu_core_count,
  :data_collection_options,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_servers,
  :disk_redundancy,
  :gi_version,
  :hostname,
  :iorm_config_cache,
  :is_local_backup_enabled,
  :is_sparse_diskgroup_enabled,
  :last_update_history_entry_id,
  :license_model,
  :listener_port,
  :memory_size_in_g_bs,
  :node_count,
  :ocid,
  :oci_resource_anchor_name,
  :oci_url,
  :domain,
  :scan_dns_name,
  :scan_dns_record_id,
  :scan_ip_ids,
  :shape,
  :ssh_public_keys,
  :storage_size_in_g_bs,
  :system_version,
  :created_at,
  :time_zone,
  :vip_ids,
  :odb_network_id,
  :odb_network_arn,
  :percent_progress,
  :compute_model,
  :iam_roles)
  SENSITIVE = [:ssh_public_keys]
  include Aws::Structure
end