Class: Aws::Odb::Types::ConflictException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Occurs when a conflict with the current status of your resource. Fix any inconsistencies with your resource and try again.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3503
3504
3505
3506
3507
3508
3509
# File 'lib/aws-sdk-odb/types.rb', line 3503

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the resource that caused the conflict.

Returns:

  • (String)


3503
3504
3505
3506
3507
3508
3509
# File 'lib/aws-sdk-odb/types.rb', line 3503

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource that caused the conflict.

Returns:

  • (String)


3503
3504
3505
3506
3507
3508
3509
# File 'lib/aws-sdk-odb/types.rb', line 3503

class ConflictException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end