Class: Aws::Odb::Types::CreateAutonomousDatabaseBackupInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#autonomous_database_idString

The unique identifier of the Autonomous Database to back up.

Returns:

  • (String)


3538
3539
3540
3541
3542
3543
3544
3545
3546
# File 'lib/aws-sdk-odb/types.rb', line 3538

class CreateAutonomousDatabaseBackupInput < Struct.new(
  :autonomous_database_id,
  :display_name,
  :retention_period_in_days,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A client-provided token to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3538
3539
3540
3541
3542
3543
3544
3545
3546
# File 'lib/aws-sdk-odb/types.rb', line 3538

class CreateAutonomousDatabaseBackupInput < Struct.new(
  :autonomous_database_id,
  :display_name,
  :retention_period_in_days,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The user-friendly name for the Autonomous Database backup.

Returns:

  • (String)


3538
3539
3540
3541
3542
3543
3544
3545
3546
# File 'lib/aws-sdk-odb/types.rb', line 3538

class CreateAutonomousDatabaseBackupInput < Struct.new(
  :autonomous_database_id,
  :display_name,
  :retention_period_in_days,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#retention_period_in_daysInteger

The retention period, in days, for the Autonomous Database backup.

Returns:

  • (Integer)


3538
3539
3540
3541
3542
3543
3544
3545
3546
# File 'lib/aws-sdk-odb/types.rb', line 3538

class CreateAutonomousDatabaseBackupInput < Struct.new(
  :autonomous_database_id,
  :display_name,
  :retention_period_in_days,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The list of resource tags to apply to the Autonomous Database backup. Each tag is a key-value pair with no predefined name, type, or namespace.

Returns:

  • (Hash<String,String>)


3538
3539
3540
3541
3542
3543
3544
3545
3546
# File 'lib/aws-sdk-odb/types.rb', line 3538

class CreateAutonomousDatabaseBackupInput < Struct.new(
  :autonomous_database_id,
  :display_name,
  :retention_period_in_days,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end