Class: Aws::Odb::Types::CreateAutonomousDatabaseInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:admin_password]

Instance Attribute Summary collapse

Instance Attribute Details

#admin_passwordString

The password for the ‘ADMIN` user of the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#allowlisted_ipsArray<String>

The list of IP addresses that are allowed to access the Autonomous Database.

Returns:

  • (Array<String>)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#autonomous_maintenance_schedule_typeString

The maintenance schedule type for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#backup_retention_period_in_daysInteger

The retention period, in days, for automatic backups of the Autonomous Database.

Returns:

  • (Integer)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#byol_compute_count_limitFloat

The maximum number of compute resources that you can allocate to the Autonomous Database under the bring-your-own-license (BYOL) model.

Returns:

  • (Float)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#character_setString

The character set to use for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#client_tokenString

A client-provided token to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#compute_countFloat

The compute capacity, in number of Elastic CPUs (ECPUs) or Oracle CPUs (OCPUs), to assign to the Autonomous Database.

Returns:

  • (Float)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#cpu_core_countInteger

The number of CPU cores to allocate to the Autonomous Database.

Returns:

  • (Integer)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#customer_contacts_to_send_to_ociArray<Types::CustomerContact>

The list of customer contacts to receive operational notifications from Oracle Cloud Infrastructure (OCI) for the Autonomous Database.

Returns:



3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#data_storage_size_in_g_bsInteger

The size, in gigabytes (GB), of the data volume to allocate for the Autonomous Database.

Returns:

  • (Integer)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#data_storage_size_in_t_bsInteger

The size, in terabytes (TB), of the data volume to allocate for the Autonomous Database.

Returns:

  • (Integer)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#database_editionString

The Oracle Database edition to apply to the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#db_nameString

The name of the Autonomous Database. The name must begin with an alphabetic character and can contain a maximum of 30 alphanumeric characters. Special characters are not permitted. The name must be unique in the Amazon Web Services account.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#db_tools_detailsArray<Types::DatabaseTool>

The list of database management tools to enable for the Autonomous Database.

Returns:



3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#db_versionString

The Oracle Database software version to use for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#db_workloadString

The intended use of the Autonomous Database, such as transaction processing, data warehouse, JSON database, or APEX.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#display_nameString

The user-friendly name for the Autonomous Database. The name does not have to be unique.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#encryption_key_configurationTypes::EncryptionKeyConfigurationInput

The configuration of the encryption key to use for the Autonomous Database.



3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#encryption_key_providerString

The provider of the encryption key to use for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#is_auto_scaling_enabledBoolean

Specifies whether to enable automatic scaling of the compute resources for the Autonomous Database.

Returns:

  • (Boolean)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#is_auto_scaling_for_storage_enabledBoolean

Specifies whether to enable automatic scaling of the storage for the Autonomous Database.

Returns:

  • (Boolean)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#is_backup_retention_lockedBoolean

Specifies whether to lock the backup retention period of the Autonomous Database to prevent it from being shortened.

Returns:

  • (Boolean)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#is_local_data_guard_enabledBoolean

Specifies whether to enable local Oracle Data Guard for the Autonomous Database.

Returns:

  • (Boolean)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#is_mtls_connection_requiredBoolean

Specifies whether mutual TLS (mTLS) authentication is required to connect to the Autonomous Database.

Returns:

  • (Boolean)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#license_modelString

The Oracle license model to apply to the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#ncharacter_setString

The national character set to use for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#odb_network_idString

The unique identifier of the ODB network to be used for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#private_endpoint_ipString

The private endpoint IP address for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#private_endpoint_labelString

The private endpoint label for the Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#resource_pool_leader_idString

The unique identifier of the resource pool leader Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#resource_pool_summaryTypes::ResourcePoolSummary

The configuration of the resource pool for the Autonomous Database.



3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#scheduled_operationsArray<Types::ScheduledOperationDetails>

The list of scheduled start and stop times for the Autonomous Database.



3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#sourceString

The source from which to create the Autonomous Database, such as a clone, backup, or cross-Region copy.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#source_configurationTypes::SourceConfiguration

The configuration details for the source used to create the Autonomous Database.



3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#standby_allowlisted_ipsArray<String>

The list of IP addresses that are allowed to access the standby Autonomous Database.

Returns:

  • (Array<String>)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#standby_allowlisted_ips_sourceString

The source of the allowlisted IP addresses for the standby Autonomous Database.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#tagsHash<String,String>

The list of resource tags to apply to the Autonomous Database. Each tag is a key-value pair with no predefined name, type, or namespace.

Returns:

  • (Hash<String,String>)


3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end

#transportable_tablespaceTypes::TransportableTablespace

The transportable tablespace configuration to use when creating the Autonomous Database.



3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
3811
# File 'lib/aws-sdk-odb/types.rb', line 3769

class CreateAutonomousDatabaseInput < Struct.new(
  :odb_network_id,
  :display_name,
  :db_name,
  :admin_password,
  :compute_count,
  :data_storage_size_in_t_bs,
  :data_storage_size_in_g_bs,
  :db_workload,
  :is_auto_scaling_enabled,
  :is_auto_scaling_for_storage_enabled,
  :license_model,
  :character_set,
  :ncharacter_set,
  :db_version,
  :database_edition,
  :standby_allowlisted_ips_source,
  :autonomous_maintenance_schedule_type,
  :backup_retention_period_in_days,
  :byol_compute_count_limit,
  :cpu_core_count,
  :customer_contacts_to_send_to_oci,
  :private_endpoint_ip,
  :private_endpoint_label,
  :resource_pool_leader_id,
  :resource_pool_summary,
  :scheduled_operations,
  :standby_allowlisted_ips,
  :allowlisted_ips,
  :transportable_tablespace,
  :is_backup_retention_locked,
  :is_local_data_guard_enabled,
  :is_mtls_connection_required,
  :db_tools_details,
  :source,
  :source_configuration,
  :encryption_key_provider,
  :encryption_key_configuration,
  :client_token,
  :tags)
  SENSITIVE = [:admin_password]
  include Aws::Structure
end