Class: Aws::Odb::Types::CreateAutonomousDatabaseOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateAutonomousDatabaseOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was created.
-
#display_name ⇒ String
The user-friendly name of the Autonomous Database that was created.
-
#status ⇒ String
The current status of the Autonomous Database.
-
#status_reason ⇒ String
Additional information about the current status of the Autonomous Database, if applicable.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was created.
3832 3833 3834 3835 3836 3837 3838 3839 |
# File 'lib/aws-sdk-odb/types.rb', line 3832 class CreateAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the Autonomous Database that was created.
3832 3833 3834 3835 3836 3837 3838 3839 |
# File 'lib/aws-sdk-odb/types.rb', line 3832 class CreateAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Autonomous Database.
3832 3833 3834 3835 3836 3837 3838 3839 |
# File 'lib/aws-sdk-odb/types.rb', line 3832 class CreateAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the current status of the Autonomous Database, if applicable.
3832 3833 3834 3835 3836 3837 3838 3839 |
# File 'lib/aws-sdk-odb/types.rb', line 3832 class CreateAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |