Class: Aws::Odb::Types::CreateAutonomousDatabaseWalletInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:password]

Instance Attribute Summary collapse

Instance Attribute Details

#autonomous_database_idString

The unique identifier of the Autonomous Database to create a wallet for.

Returns:

  • (String)


3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-odb/types.rb', line 3973

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :password_source,
  :password_source_configuration,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#client_tokenString

A client-provided token to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-odb/types.rb', line 3973

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :password_source,
  :password_source_configuration,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#passwordString

The password to encrypt the keys inside the wallet.

Returns:

  • (String)


3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-odb/types.rb', line 3973

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :password_source,
  :password_source_configuration,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#password_sourceString

The source of the password for encrypting the wallet. When set to CUSTOMER_MANAGED_AWS_SECRET, the password is retrieved from an Amazon Web Services Secrets Manager secret.

Returns:

  • (String)


3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-odb/types.rb', line 3973

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :password_source,
  :password_source_configuration,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#password_source_configurationTypes::WalletPasswordSourceConfigurationInput

The configuration of the password source for the Autonomous Database wallet.



3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-odb/types.rb', line 3973

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :password_source,
  :password_source_configuration,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#wallet_typeString

The type of wallet to create, either a regional wallet or an instance wallet.

Returns:

  • (String)


3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
# File 'lib/aws-sdk-odb/types.rb', line 3973

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :password_source,
  :password_source_configuration,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end