Class: Aws::Odb::Types::CreateAutonomousDatabaseWalletOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateAutonomousDatabaseWalletOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:autonomous_database_wallet_file]
Instance Attribute Summary collapse
-
#autonomous_database_wallet_file ⇒ String
The generated wallet file for the Autonomous Database, returned as a compressed archive.
Instance Attribute Details
#autonomous_database_wallet_file ⇒ String
The generated wallet file for the Autonomous Database, returned as a compressed archive.
3880 3881 3882 3883 3884 |
# File 'lib/aws-sdk-odb/types.rb', line 3880 class CreateAutonomousDatabaseWalletOutput < Struct.new( :autonomous_database_wallet_file) SENSITIVE = [:autonomous_database_wallet_file] include Aws::Structure end |