Class: Aws::Odb::Types::CreateCloudAutonomousVmClusterInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateCloudAutonomousVmClusterInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_data_storage_size_in_t_bs ⇒ Float
The data disk group size to be allocated for Autonomous Databases, in terabytes (TB).
-
#client_token ⇒ String
A client-provided token to ensure idempotency of the request.
-
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier of the Exadata infrastructure where the VM cluster will be created.
-
#cpu_core_count_per_node ⇒ Integer
The number of CPU cores to be enabled per VM cluster node.
-
#db_servers ⇒ Array<String>
The list of database servers to be used for the Autonomous VM cluster.
-
#description ⇒ String
A user-provided description of the Autonomous VM cluster.
-
#display_name ⇒ String
The display name for the Autonomous VM cluster.
-
#is_mtls_enabled_vm_cluster ⇒ Boolean
Specifies whether to enable mutual TLS (mTLS) authentication for the Autonomous VM cluster.
-
#license_model ⇒ String
The Oracle license model to apply to the Autonomous VM cluster.
-
#maintenance_window ⇒ Types::MaintenanceWindow
The scheduling details for the maintenance window.
-
#memory_per_oracle_compute_unit_in_g_bs ⇒ Integer
The amount of memory to be allocated per OCPU, in GB.
-
#odb_network_id ⇒ String
The unique identifier of the ODB network to be used for the VM cluster.
-
#scan_listener_port_non_tls ⇒ Integer
The SCAN listener port for non-TLS (TCP) protocol.
-
#scan_listener_port_tls ⇒ Integer
The SCAN listener port for TLS (TCP) protocol.
-
#tags ⇒ Hash<String,String>
Free-form tags for this resource.
-
#time_zone ⇒ String
The time zone to use for the Autonomous VM cluster.
-
#total_container_databases ⇒ Integer
The total number of Autonomous CDBs that you can create in the Autonomous VM cluster.
Instance Attribute Details
#autonomous_data_storage_size_in_t_bs ⇒ Float
The data disk group size to be allocated for Autonomous Databases, in terabytes (TB).
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A client-provided token to ensure idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier of the Exadata infrastructure where the VM cluster will be created.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#cpu_core_count_per_node ⇒ Integer
The number of CPU cores to be enabled per VM cluster node.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#db_servers ⇒ Array<String>
The list of database servers to be used for the Autonomous VM cluster.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A user-provided description of the Autonomous VM cluster.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name for the Autonomous VM cluster. The name does not need to be unique.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#is_mtls_enabled_vm_cluster ⇒ Boolean
Specifies whether to enable mutual TLS (mTLS) authentication for the Autonomous VM cluster.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#license_model ⇒ String
The Oracle license model to apply to the Autonomous VM cluster.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#maintenance_window ⇒ Types::MaintenanceWindow
The scheduling details for the maintenance window. Patching and system updates take place during the maintenance window.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#memory_per_oracle_compute_unit_in_g_bs ⇒ Integer
The amount of memory to be allocated per OCPU, in GB.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#odb_network_id ⇒ String
The unique identifier of the ODB network to be used for the VM cluster.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#scan_listener_port_non_tls ⇒ Integer
The SCAN listener port for non-TLS (TCP) protocol.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#scan_listener_port_tls ⇒ Integer
The SCAN listener port for TLS (TCP) protocol.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Free-form tags for this resource. Each tag is a key-value pair with no predefined name, type, or namespace.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The time zone to use for the Autonomous VM cluster.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |
#total_container_databases ⇒ Integer
The total number of Autonomous CDBs that you can create in the Autonomous VM cluster.
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-odb/types.rb', line 4127 class CreateCloudAutonomousVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :odb_network_id, :display_name, :client_token, :autonomous_data_storage_size_in_t_bs, :cpu_core_count_per_node, :db_servers, :description, :is_mtls_enabled_vm_cluster, :license_model, :maintenance_window, :memory_per_oracle_compute_unit_in_g_bs, :scan_listener_port_non_tls, :scan_listener_port_tls, :tags, :time_zone, :total_container_databases) SENSITIVE = [] include Aws::Structure end |