Class: Aws::Odb::Types::CreateCloudExadataInfrastructureInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The name of the Availability Zone (AZ) where the Exadata infrastructure is located.

This operation requires that you specify a value for either ‘availabilityZone` or `availabilityZoneId`.

Example: ‘us-east-1a`

Returns:

  • (String)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The AZ ID of the AZ where the Exadata infrastructure is located.

This operation requires that you specify a value for either ‘availabilityZone` or `availabilityZoneId`.

Example: ‘use1-az1`

Returns:

  • (String)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency. The client token is valid for up to 24 hours after it’s first used.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#compute_countInteger

The number of database servers for the Exadata infrastructure. Valid values for this parameter depend on the shape. To get information about the minimum and maximum values, use the ‘ListDbSystemShapes` operation.

Returns:

  • (Integer)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#customer_contacts_to_send_to_ociArray<Types::CustomerContact>

The email addresses of contacts to receive notification from Oracle about maintenance updates for the Exadata infrastructure.

Returns:



4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#database_server_typeString

The database server model type of the Exadata infrastructure. For the list of valid model names, use the ‘ListDbSystemShapes` operation.

Returns:

  • (String)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

A user-friendly name for the Exadata infrastructure.

Returns:

  • (String)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_windowTypes::MaintenanceWindow

The maintenance window configuration for the Exadata Cloud infrastructure.

This allows you to define when maintenance operations such as patching and updates can be performed on the infrastructure.



4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#shapeString

The model name of the Exadata infrastructure. For the list of valid model names, use the ‘ListDbSystemShapes` operation.

Returns:

  • (String)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_countInteger

The number of storage servers to activate for this Exadata infrastructure. Valid values for this parameter depend on the shape. To get information about the minimum and maximum values, use the ‘ListDbSystemShapes` operation.

Returns:

  • (Integer)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_server_typeString

The storage server model type of the Exadata infrastructure. For the list of valid model names, use the ‘ListDbSystemShapes` operation.

Returns:

  • (String)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The list of resource tags to apply to the Exadata infrastructure.

Returns:

  • (Hash<String,String>)


4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
# File 'lib/aws-sdk-odb/types.rb', line 4101

class CreateCloudExadataInfrastructureInput < Struct.new(
  :display_name,
  :shape,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :compute_count,
  :customer_contacts_to_send_to_oci,
  :maintenance_window,
  :storage_count,
  :client_token,
  :database_server_type,
  :storage_server_type)
  SENSITIVE = []
  include Aws::Structure
end