Class: Aws::Odb::Types::CreateCloudVmClusterInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateCloudVmClusterInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier of the Exadata infrastructure for this VM cluster.
-
#cluster_name ⇒ String
A name for the Grid Infrastructure cluster.
-
#cpu_core_count ⇒ Integer
The number of CPU cores to enable on the VM cluster.
-
#data_collection_options ⇒ Types::DataCollectionOptions
The set of preferences for the various diagnostic collection options for the VM cluster.
-
#data_storage_size_in_t_bs ⇒ Float
The size of the data disk group, in terabytes (TBs), to allocate for the VM cluster.
-
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), to allocate for the VM cluster.
-
#db_servers ⇒ Array<String>
The list of database servers for the VM cluster.
-
#display_name ⇒ String
A user-friendly name for the VM cluster.
-
#gi_version ⇒ String
A valid software version of Oracle Grid Infrastructure (GI).
-
#hostname ⇒ String
The host name for the VM cluster.
-
#is_local_backup_enabled ⇒ Boolean
Specifies whether to enable database backups to local Exadata storage for the VM cluster.
-
#is_sparse_diskgroup_enabled ⇒ Boolean
Specifies whether to create a sparse disk group for the VM cluster.
-
#license_model ⇒ String
The Oracle license model to apply to the VM cluster.
-
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), to allocate for the VM cluster.
-
#odb_network_id ⇒ String
The unique identifier of the ODB network for the VM cluster.
-
#scan_listener_port_tcp ⇒ Integer
The port number for TCP connections to the single client access name (SCAN) listener.
-
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the VM cluster.
-
#system_version ⇒ String
The version of the operating system of the image for the VM cluster.
-
#tags ⇒ Hash<String,String>
The list of resource tags to apply to the VM cluster.
-
#time_zone ⇒ String
The time zone for the VM cluster.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency. The client token is valid for up to 24 hours after it's first used.
A suitable default value is auto-generated. You should normally not need to pass this option.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier of the Exadata infrastructure for this VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
A name for the Grid Infrastructure cluster. The name isn't case sensitive.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#cpu_core_count ⇒ Integer
The number of CPU cores to enable on the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#data_collection_options ⇒ Types::DataCollectionOptions
The set of preferences for the various diagnostic collection options for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#data_storage_size_in_t_bs ⇒ Float
The size of the data disk group, in terabytes (TBs), to allocate for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), to allocate for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#db_servers ⇒ Array<String>
The list of database servers for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
A user-friendly name for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#gi_version ⇒ String
A valid software version of Oracle Grid Infrastructure (GI). To get
the list of valid values, use the ListGiVersions operation and
specify the shape of the Exadata infrastructure.
Example: 19.0.0.0
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#hostname ⇒ String
The host name for the VM cluster.
Constraints:
-
Can't be "localhost" or "hostname".
-
Can't contain "-version".
-
The maximum length of the combined hostname and domain is 63 characters.
-
The hostname must be unique within the subnet.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#is_local_backup_enabled ⇒ Boolean
Specifies whether to enable database backups to local Exadata storage for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#is_sparse_diskgroup_enabled ⇒ Boolean
Specifies whether to create a sparse disk group for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#license_model ⇒ String
The Oracle license model to apply to the VM cluster.
Default: LICENSE_INCLUDED
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), to allocate for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#odb_network_id ⇒ String
The unique identifier of the ODB network for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#scan_listener_port_tcp ⇒ Integer
The port number for TCP connections to the single client access name (SCAN) listener.
Valid values: 1024–8999 with the following exceptions: 2484,
6100, 6200, 7060, 7070, 7085, and 7879
Default: 1521
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#system_version ⇒ String
The version of the operating system of the image for the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of resource tags to apply to the VM cluster.
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The time zone for the VM cluster. For a list of valid values for time zone, you can check the options in the console.
Default: UTC
4432 4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 |
# File 'lib/aws-sdk-odb/types.rb', line 4432 class CreateCloudVmClusterInput < Struct.new( :cloud_exadata_infrastructure_id, :cpu_core_count, :display_name, :gi_version, :hostname, :ssh_public_keys, :odb_network_id, :cluster_name, :data_collection_options, :data_storage_size_in_t_bs, :db_node_storage_size_in_g_bs, :db_servers, :tags, :is_local_backup_enabled, :is_sparse_diskgroup_enabled, :license_model, :memory_size_in_g_bs, :system_version, :time_zone, :client_token, :scan_listener_port_tcp) SENSITIVE = [] include Aws::Structure end |