Class: Aws::Odb::Types::CreateOdbNetworkInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone ⇒ String

The Amazon Web Services Availability Zone (AZ) where the ODB network is located.

This operation requires that you specify a value for either availabilityZone or availabilityZoneId.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_id ⇒ String

The AZ ID of the AZ where the ODB network is located.

This operation requires that you specify a value for either availabilityZone or availabilityZoneId.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#backup_subnet_cidr ⇒ String

The CIDR range of the backup subnet for the ODB network.

Constraints:

  • Must not overlap with the CIDR range of the client subnet.

  • Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network.

  • Must not use the following CIDR ranges that are reserved by OCI:

  • 100.106.0.0/16 and 100.107.0.0/16

  • 169.254.0.0/16

  • 224.0.0.0 - 239.255.255.255

  • 240.0.0.0 - 255.255.255.255

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_subnet_cidr ⇒ String

The CIDR range of the client subnet for the ODB network.

Constraints:

  • Must not overlap with the CIDR range of the backup subnet.

  • Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network.

  • Must not use the following CIDR ranges that are reserved by OCI:

  • 100.106.0.0/16 and 100.107.0.0/16

  • 169.254.0.0/16

  • 224.0.0.0 - 239.255.255.255

  • 240.0.0.0 - 255.255.255.255

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency. The client token is valid for up to 24 hours after it's first used.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#cross_region_s3_restore_sources_to_enable ⇒ Array<String>

The cross-Region Amazon S3 restore sources to enable for the ODB network.

Returns:

  • (Array<String>)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_name ⇒ String

The domain name to use for the resources in the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_dns_prefix ⇒ String

The DNS prefix to the default DNS domain name. The default DNS domain name is oraclevcn.com.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#display_name ⇒ String

A user-friendly name for the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_access ⇒ String

The Amazon Web Services Key Management Service (KMS) access configuration for the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_policy_document ⇒ String

The Amazon Web Services Key Management Service (KMS) policy document that defines permissions for key usage within the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#s3_access ⇒ String

Specifies the configuration for Amazon S3 access from the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#s3_policy_document ⇒ String

Specifies the endpoint policy for Amazon S3 access from the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#sts_access ⇒ String

The Amazon Web Services Security Token Service (STS) access configuration for the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#sts_policy_document ⇒ String

The Amazon Web Services Security Token Service (STS) policy document that defines permissions for token service usage within the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The list of resource tags to apply to the ODB network.

Returns:

  • (Hash<String,String>)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#zero_etl_access ⇒ String

Specifies the configuration for Zero-ETL access from the ODB network.

Returns:

  • (String)


4874
4875
4876
4877
4878
4879
4880
4881
4882
4883
4884
4885
4886
4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/aws-sdk-odb/types.rb', line 4874

class CreateOdbNetworkInput < Struct.new(
  :display_name,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :client_token,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end