Class: Aws::Odb::Types::CreateOdbPeeringConnectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateOdbPeeringConnectionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token for the ODB peering connection request.
-
#display_name ⇒ String
The display name for the ODB peering connection.
-
#odb_network_id ⇒ String
The unique identifier of the ODB network that initiates the peering connection.
-
#peer_network_cidrs_to_be_added ⇒ Array<String>
A list of CIDR blocks to add to the peering connection.
-
#peer_network_id ⇒ String
The unique identifier of the peer network.
-
#peer_network_route_table_ids ⇒ Array<String>
The unique identifier of the VPC route table for which a route to the ODB network is automatically created during peering connection establishment.
-
#tags ⇒ Hash<String,String>
The tags to assign to the ODB peering connection.
Instance Attribute Details
#client_token ⇒ String
The client token for the ODB peering connection request.
Constraints:
- Must be unique for each request.
^
A suitable default value is auto-generated. You should normally not need to pass this option.
4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 |
# File 'lib/aws-sdk-odb/types.rb', line 4964 class CreateOdbPeeringConnectionInput < Struct.new( :odb_network_id, :peer_network_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_route_table_ids, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name for the ODB peering connection.
4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 |
# File 'lib/aws-sdk-odb/types.rb', line 4964 class CreateOdbPeeringConnectionInput < Struct.new( :odb_network_id, :peer_network_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_route_table_ids, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#odb_network_id ⇒ String
The unique identifier of the ODB network that initiates the peering connection.
4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 |
# File 'lib/aws-sdk-odb/types.rb', line 4964 class CreateOdbPeeringConnectionInput < Struct.new( :odb_network_id, :peer_network_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_route_table_ids, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#peer_network_cidrs_to_be_added ⇒ Array<String>
A list of CIDR blocks to add to the peering connection. These CIDR blocks define the IP address ranges that can communicate through the peering connection.
4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 |
# File 'lib/aws-sdk-odb/types.rb', line 4964 class CreateOdbPeeringConnectionInput < Struct.new( :odb_network_id, :peer_network_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_route_table_ids, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#peer_network_id ⇒ String
The unique identifier of the peer network. This can be either a VPC ID or another ODB network ID.
4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 |
# File 'lib/aws-sdk-odb/types.rb', line 4964 class CreateOdbPeeringConnectionInput < Struct.new( :odb_network_id, :peer_network_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_route_table_ids, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#peer_network_route_table_ids ⇒ Array<String>
The unique identifier of the VPC route table for which a route to the ODB network is automatically created during peering connection establishment.
4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 |
# File 'lib/aws-sdk-odb/types.rb', line 4964 class CreateOdbPeeringConnectionInput < Struct.new( :odb_network_id, :peer_network_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_route_table_ids, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the ODB peering connection.
4964 4965 4966 4967 4968 4969 4970 4971 4972 4973 4974 |
# File 'lib/aws-sdk-odb/types.rb', line 4964 class CreateOdbPeeringConnectionInput < Struct.new( :odb_network_id, :peer_network_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_route_table_ids, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |