Class: Aws::Odb::Types::CreateOdbPeeringConnectionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateOdbPeeringConnectionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the ODB peering connection.
-
#odb_peering_connection_id ⇒ String
The unique identifier of the ODB peering connection.
-
#status ⇒ String
The status of the ODB peering connection.
-
#status_reason ⇒ String
The reason for the current status of the ODB peering connection.
Instance Attribute Details
#display_name ⇒ String
The display name of the ODB peering connection.
2367 2368 2369 2370 2371 2372 2373 2374 |
# File 'lib/aws-sdk-odb/types.rb', line 2367 class CreateOdbPeeringConnectionOutput < Struct.new( :display_name, :status, :status_reason, :odb_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_id ⇒ String
The unique identifier of the ODB peering connection.
2367 2368 2369 2370 2371 2372 2373 2374 |
# File 'lib/aws-sdk-odb/types.rb', line 2367 class CreateOdbPeeringConnectionOutput < Struct.new( :display_name, :status, :status_reason, :odb_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the ODB peering connection.
Valid Values: ‘provisioning | active | terminating | terminated | failed`
2367 2368 2369 2370 2371 2372 2373 2374 |
# File 'lib/aws-sdk-odb/types.rb', line 2367 class CreateOdbPeeringConnectionOutput < Struct.new( :display_name, :status, :status_reason, :odb_peering_connection_id) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status of the ODB peering connection.
2367 2368 2369 2370 2371 2372 2373 2374 |
# File 'lib/aws-sdk-odb/types.rb', line 2367 class CreateOdbPeeringConnectionOutput < Struct.new( :display_name, :status, :status_reason, :odb_peering_connection_id) SENSITIVE = [] include Aws::Structure end |