Class: Aws::Odb::Types::CrossRegionDisasterRecoveryConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The configuration for creating an Autonomous Database as a cross-Region disaster recovery peer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_replicate_automatic_backupsBoolean

Indicates whether automatic backups are replicated to the disaster recovery database.

Returns:

  • (Boolean)


4623
4624
4625
4626
4627
4628
4629
# File 'lib/aws-sdk-odb/types.rb', line 4623

class CrossRegionDisasterRecoveryConfiguration < Struct.new(
  :source_autonomous_database_arn,
  :remote_disaster_recovery_type,
  :is_replicate_automatic_backups)
  SENSITIVE = []
  include Aws::Structure
end

#remote_disaster_recovery_typeString

The type of remote disaster recovery to configure, either Autonomous Data Guard or backup-based.

Returns:

  • (String)


4623
4624
4625
4626
4627
4628
4629
# File 'lib/aws-sdk-odb/types.rb', line 4623

class CrossRegionDisasterRecoveryConfiguration < Struct.new(
  :source_autonomous_database_arn,
  :remote_disaster_recovery_type,
  :is_replicate_automatic_backups)
  SENSITIVE = []
  include Aws::Structure
end

#source_autonomous_database_arnString

The Amazon Resource Name (ARN) of the source Autonomous Database for the cross-Region disaster recovery configuration.

Returns:

  • (String)


4623
4624
4625
4626
4627
4628
4629
# File 'lib/aws-sdk-odb/types.rb', line 4623

class CrossRegionDisasterRecoveryConfiguration < Struct.new(
  :source_autonomous_database_arn,
  :remote_disaster_recovery_type,
  :is_replicate_automatic_backups)
  SENSITIVE = []
  include Aws::Structure
end