Class: Aws::Odb::Types::CustomerManagedAwsSecretConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The input configuration for a customer-managed Amazon Web Services Secrets Manager secret used to supply a password.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#external_id_typeString

The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.

The valid values depend on the operation. For the CreateAutonomousDatabase operation, only compartment_ocid and tenant_ocid are allowed. For the UpdateAutonomousDatabase and CreateAutonomousDatabaseWallet operations, database_ocid, compartment_ocid, and tenant_ocid are all allowed.

Returns:

  • (String)


5146
5147
5148
5149
5150
5151
5152
# File 'lib/aws-sdk-odb/types.rb', line 5146

class CustomerManagedAwsSecretConfigurationInput < Struct.new(
  :secret_id,
  :iam_role_arn,
  :external_id_type)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.

Returns:

  • (String)


5146
5147
5148
5149
5150
5151
5152
# File 'lib/aws-sdk-odb/types.rb', line 5146

class CustomerManagedAwsSecretConfigurationInput < Struct.new(
  :secret_id,
  :iam_role_arn,
  :external_id_type)
  SENSITIVE = []
  include Aws::Structure
end

#secret_idString

The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.

Returns:

  • (String)


5146
5147
5148
5149
5150
5151
5152
# File 'lib/aws-sdk-odb/types.rb', line 5146

class CustomerManagedAwsSecretConfigurationInput < Struct.new(
  :secret_id,
  :iam_role_arn,
  :external_id_type)
  SENSITIVE = []
  include Aws::Structure
end