Class: Aws::Odb::Types::DatabaseConnectionStringProfile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

A connection string profile for an Autonomous Database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_groupString

The consumer group associated with the connection string profile.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The user-friendly name of the connection string profile.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#host_formatString

The host name format used in the connection string.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#is_regionalBoolean

Indicates whether the connection string profile is regional.

Returns:

  • (Boolean)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol used by the connection string profile.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#session_modeString

The session mode of the connection string profile.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#syntax_formatString

The syntax format of the connection string profile.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#tls_authenticationString

The TLS authentication method used by the connection string profile.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The connection string value of the profile.

Returns:

  • (String)


4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/aws-sdk-odb/types.rb', line 4931

class DatabaseConnectionStringProfile < Struct.new(
  :consumer_group,
  :display_name,
  :host_format,
  :is_regional,
  :protocol,
  :session_mode,
  :syntax_format,
  :tls_authentication,
  :value)
  SENSITIVE = []
  include Aws::Structure
end