Class: Aws::Odb::Types::DatabaseStandbySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

A summary of a standby Autonomous Database in an Oracle Data Guard configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_domainString

The availability domain of the standby Autonomous Database.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#lag_time_in_secondsInteger

The time lag, in seconds, between the standby database and the primary database.

Returns:

  • (Integer)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_target_componentString

The component on the standby Autonomous Database that the current maintenance is being applied to.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the standby Autonomous Database.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Additional information about the current status of the standby Autonomous Database, if applicable.

Returns:

  • (String)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#time_data_guard_role_changedTime

The date and time when the Oracle Data Guard role of the standby database last changed.

Returns:

  • (Time)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#time_disaster_recovery_role_changedTime

The date and time when the disaster recovery role of the standby database last changed.

Returns:

  • (Time)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#time_maintenance_beginTime

The date and time when the next maintenance of the standby database begins.

Returns:

  • (Time)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end

#time_maintenance_endTime

The date and time when the next maintenance of the standby database ends.

Returns:

  • (Time)


4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-odb/types.rb', line 4824

class DatabaseStandbySummary < Struct.new(
  :availability_domain,
  :lag_time_in_seconds,
  :status,
  :status_reason,
  :maintenance_target_component,
  :time_data_guard_role_changed,
  :time_disaster_recovery_role_changed,
  :time_maintenance_begin,
  :time_maintenance_end)
  SENSITIVE = []
  include Aws::Structure
end