Class: Aws::Odb::Types::DatabaseTool

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about a database management tool for an Autonomous Database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_countFloat

The compute capacity allocated to the database management tool.

Returns:

  • (Float)


4860
4861
4862
4863
4864
4865
4866
4867
# File 'lib/aws-sdk-odb/types.rb', line 4860

class DatabaseTool < Struct.new(
  :is_enabled,
  :name,
  :compute_count,
  :max_idle_time_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end

#is_enabledBoolean

Indicates whether the database management tool is enabled.

Returns:

  • (Boolean)


4860
4861
4862
4863
4864
4865
4866
4867
# File 'lib/aws-sdk-odb/types.rb', line 4860

class DatabaseTool < Struct.new(
  :is_enabled,
  :name,
  :compute_count,
  :max_idle_time_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end

#max_idle_time_in_minutesInteger

The maximum amount of time, in minutes, that the database management tool can be idle before it is shut down.

Returns:

  • (Integer)


4860
4861
4862
4863
4864
4865
4866
4867
# File 'lib/aws-sdk-odb/types.rb', line 4860

class DatabaseTool < Struct.new(
  :is_enabled,
  :name,
  :compute_count,
  :max_idle_time_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the database management tool.

Returns:

  • (String)


4860
4861
4862
4863
4864
4865
4866
4867
# File 'lib/aws-sdk-odb/types.rb', line 4860

class DatabaseTool < Struct.new(
  :is_enabled,
  :name,
  :compute_count,
  :max_idle_time_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end