Class: Aws::Odb::Types::DbNode

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about a DB node.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_detailsString

Additional information about the planned maintenance.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#backup_ip_idString

The Oracle Cloud ID (OCID) of the backup IP address that's associated with the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#backup_vnic_2_idString

The OCID of the second backup VNIC.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#backup_vnic_idString

The OCID of the backup VNIC.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#cpu_core_countInteger

Number of CPU cores enabled on the DB node.

Returns:

  • (Integer)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the DB node was created.

Returns:

  • (Time)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#db_node_arnString

The Amazon Resource Name (ARN) of the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#db_node_idString

The unique identifier of the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#db_node_storage_size_in_g_bsInteger

The amount of local node storage, in gigabytes (GB), that's allocated on the DB node.

Returns:

  • (Integer)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#db_server_idString

The unique identifier of the Db server that is associated with the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#db_system_idString

The OCID of the DB system.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#fault_domainString

The name of the fault domain the instance is contained in.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#floating_ip_addressString

The floating IP address assigned to the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#host_ip_idString

The OCID of the host IP address that's associated with the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#hostnameString

The host name for the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_typeString

The type of database node maintenance. Either VMDB_REBOOT_MIGRATION or EXADBXS_REBOOT_MIGRATION.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#memory_size_in_g_bsInteger

The allocated memory in GBs on the DB node.

Returns:

  • (Integer)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#oci_resource_anchor_nameString

The name of the OCI resource anchor for the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#ocidString

The OCID of the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressString

The private IP address assigned to the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#software_storage_size_in_gbInteger

The size (in GB) of the block storage volume allocation for the DB system.

Returns:

  • (Integer)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Additional information about the status of the DB node.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#time_maintenance_window_endString

End date and time of maintenance window.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#time_maintenance_window_startString

Start date and time of maintenance window.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#total_cpu_core_countInteger

The total number of CPU cores reserved on the DB node.

Returns:

  • (Integer)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#vnic2_idString

The OCID of the second VNIC.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end

#vnic_idString

The OCID of the VNIC.

Returns:

  • (String)


5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
5525
5526
5527
5528
5529
5530
5531
5532
5533
5534
5535
5536
5537
5538
5539
5540
5541
# File 'lib/aws-sdk-odb/types.rb', line 5510

class DbNode < Struct.new(
  :db_node_id,
  :db_node_arn,
  :status,
  :status_reason,
  :additional_details,
  :backup_ip_id,
  :backup_vnic_2_id,
  :backup_vnic_id,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_id,
  :db_system_id,
  :fault_domain,
  :host_ip_id,
  :hostname,
  :ocid,
  :oci_resource_anchor_name,
  :maintenance_type,
  :memory_size_in_g_bs,
  :software_storage_size_in_gb,
  :created_at,
  :time_maintenance_window_end,
  :time_maintenance_window_start,
  :total_cpu_core_count,
  :vnic2_id,
  :vnic_id,
  :private_ip_address,
  :floating_ip_address)
  SENSITIVE = []
  include Aws::Structure
end