Class: Aws::Odb::Types::DbSystemShapeSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about a hardware system model (shape) that’s available for an Exadata infrastructure. The shape determines resources, such as CPU cores, memory, and storage, to allocate to the Exadata infrastructure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#are_server_types_supportedBoolean

Indicates whether the hardware system model supports configurable database and server storage types.

Returns:

  • (Boolean)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_core_countInteger

The maximum number of CPU cores that can be enabled for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_core_count_per_nodeInteger

The maximum number of CPU cores per DB node that can be enabled for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_data_storage_in_t_bsInteger

The maximum amount of data storage, in terabytes (TB), that can be enabled for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_data_storage_per_server_in_t_bsInteger

The maximum amount of data storage, in terabytes (TB), that’s available per storage server for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_db_node_per_node_in_g_bsInteger

The maximum amount of DB node storage, in gigabytes (GB), that’s available per DB node for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_db_node_storage_in_g_bsInteger

The maximum amount of DB node storage, in gigabytes (GB), that can be enabled for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_memory_in_g_bsInteger

The maximum amount of memory, in gigabytes (GB), that can be enabled for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#available_memory_per_node_in_g_bsInteger

The maximum amount of memory, in gigabytes (GB), that’s available per DB node for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#compute_modelString

The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.

Returns:

  • (String)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#core_count_incrementInteger

The discrete number by which the CPU core count for the shape can be increased or decreased.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#max_storage_countInteger

The maximum number of Exadata storage servers that’s available for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_node_countInteger

The maximum number of compute servers that is available for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#min_core_count_per_nodeInteger

The minimum number of CPU cores that can be enabled per node for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#min_data_storage_in_t_bsInteger

The minimum amount of data storage, in terabytes (TB), that must be allocated for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#min_db_node_storage_per_node_in_g_bsInteger

The minimum amount of DB node storage, in gigabytes (GB), that must be allocated per DB node for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#min_memory_per_node_in_g_bsInteger

The minimum amount of memory, in gigabytes (GB), that must be allocated per DB node for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#min_storage_countInteger

The minimum number of Exadata storage servers that are available for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_core_countInteger

The minimum number of CPU cores that can be enabled for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_node_countInteger

The minimum number of compute servers that are available for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the shape.

Returns:

  • (String)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_minimum_core_countInteger

The runtime minimum number of CPU cores that can be enabled for the shape.

Returns:

  • (Integer)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#shape_familyString

The family of the shape.

Returns:

  • (String)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end

#shape_typeString

The shape type. This property is determined by the CPU hardware.

Returns:

  • (String)


5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
# File 'lib/aws-sdk-odb/types.rb', line 5606

class DbSystemShapeSummary < Struct.new(
  :available_core_count,
  :available_core_count_per_node,
  :available_data_storage_in_t_bs,
  :available_data_storage_per_server_in_t_bs,
  :available_db_node_per_node_in_g_bs,
  :available_db_node_storage_in_g_bs,
  :available_memory_in_g_bs,
  :available_memory_per_node_in_g_bs,
  :core_count_increment,
  :max_storage_count,
  :maximum_node_count,
  :min_core_count_per_node,
  :min_data_storage_in_t_bs,
  :min_db_node_storage_per_node_in_g_bs,
  :min_memory_per_node_in_g_bs,
  :min_storage_count,
  :minimum_core_count,
  :minimum_node_count,
  :runtime_minimum_core_count,
  :shape_family,
  :shape_type,
  :name,
  :compute_model,
  :are_server_types_supported)
  SENSITIVE = []
  include Aws::Structure
end