Class: Aws::Odb::Types::DeleteCloudExadataInfrastructureInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DeleteCloudExadataInfrastructureInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier of the Exadata infrastructure to delete.
Instance Attribute Details
#cloud_exadata_infrastructure_id ⇒ String
The unique identifier of the Exadata infrastructure to delete.
5689 5690 5691 5692 5693 |
# File 'lib/aws-sdk-odb/types.rb', line 5689 class DeleteCloudExadataInfrastructureInput < Struct.new( :cloud_exadata_infrastructure_id) SENSITIVE = [] include Aws::Structure end |