Class: Aws::Odb::Types::DeleteExascaleDbStorageVaultInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DeleteExascaleDbStorageVaultInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exascale_db_storage_vault_id ⇒ String
The unique identifier of the Exascale storage vault to delete.
Instance Attribute Details
#exascale_db_storage_vault_id ⇒ String
The unique identifier of the Exascale storage vault to delete.
6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-odb/types.rb', line 6223 class DeleteExascaleDbStorageVaultInput < Struct.new( :exascale_db_storage_vault_id) SENSITIVE = [] include Aws::Structure end |