Class: Aws::Odb::Types::DisassociateIamRoleFromResourceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_integrationString

The Amazon Web Services integration configuration settings for the Amazon Web Services Identity and Access Management (IAM) service role disassociation.

Returns:

  • (String)


6291
6292
6293
6294
6295
6296
6297
# File 'lib/aws-sdk-odb/types.rb', line 6291

class DisassociateIamRoleFromResourceInput < Struct.new(
  :iam_role_arn,
  :aws_integration,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) service role to disassociate from the resource.

Returns:

  • (String)


6291
6292
6293
6294
6295
6296
6297
# File 'lib/aws-sdk-odb/types.rb', line 6291

class DisassociateIamRoleFromResourceInput < Struct.new(
  :iam_role_arn,
  :aws_integration,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the target resource to disassociate from the Amazon Web Services Identity and Access Management (IAM) service role.

Returns:

  • (String)


6291
6292
6293
6294
6295
6296
6297
# File 'lib/aws-sdk-odb/types.rb', line 6291

class DisassociateIamRoleFromResourceInput < Struct.new(
  :iam_role_arn,
  :aws_integration,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end