Class: Aws::Odb::Types::DisassociateVirtualMachinesFromExadbVmClusterOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DisassociateVirtualMachinesFromExadbVmClusterOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The user-friendly name for the Exascale VM cluster.
-
#exadb_vm_cluster_id ⇒ String
The unique identifier of the Exascale VM cluster.
-
#status ⇒ String
The current status of the Exascale VM cluster.
-
#status_reason ⇒ String
Additional information about the status of the Exascale VM cluster.
Instance Attribute Details
#display_name ⇒ String
The user-friendly name for the Exascale VM cluster.
6339 6340 6341 6342 6343 6344 6345 6346 |
# File 'lib/aws-sdk-odb/types.rb', line 6339 class DisassociateVirtualMachinesFromExadbVmClusterOutput < Struct.new( :display_name, :status, :status_reason, :exadb_vm_cluster_id) SENSITIVE = [] include Aws::Structure end |
#exadb_vm_cluster_id ⇒ String
The unique identifier of the Exascale VM cluster.
6339 6340 6341 6342 6343 6344 6345 6346 |
# File 'lib/aws-sdk-odb/types.rb', line 6339 class DisassociateVirtualMachinesFromExadbVmClusterOutput < Struct.new( :display_name, :status, :status_reason, :exadb_vm_cluster_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Exascale VM cluster.
6339 6340 6341 6342 6343 6344 6345 6346 |
# File 'lib/aws-sdk-odb/types.rb', line 6339 class DisassociateVirtualMachinesFromExadbVmClusterOutput < Struct.new( :display_name, :status, :status_reason, :exadb_vm_cluster_id) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Exascale VM cluster.
6339 6340 6341 6342 6343 6344 6345 6346 |
# File 'lib/aws-sdk-odb/types.rb', line 6339 class DisassociateVirtualMachinesFromExadbVmClusterOutput < Struct.new( :display_name, :status, :status_reason, :exadb_vm_cluster_id) SENSITIVE = [] include Aws::Structure end |