Class: Aws::Odb::Types::DisasterRecoveryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DisasterRecoveryConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The disaster recovery configuration for an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disaster_recovery_type ⇒ String
The type of disaster recovery configured for the Autonomous Database.
-
#is_replicate_automatic_backups ⇒ Boolean
Indicates whether automatic backups are replicated to the disaster recovery database.
-
#is_snapshot_standby ⇒ Boolean
Indicates whether the standby database is a snapshot standby.
-
#time_snapshot_standby_enabled_till ⇒ Time
The date and time until which the snapshot standby database remains enabled.
Instance Attribute Details
#disaster_recovery_type ⇒ String
The type of disaster recovery configured for the Autonomous Database.
5977 5978 5979 5980 5981 5982 5983 5984 |
# File 'lib/aws-sdk-odb/types.rb', line 5977 class DisasterRecoveryConfiguration < Struct.new( :disaster_recovery_type, :is_replicate_automatic_backups, :is_snapshot_standby, :time_snapshot_standby_enabled_till) SENSITIVE = [] include Aws::Structure end |
#is_replicate_automatic_backups ⇒ Boolean
Indicates whether automatic backups are replicated to the disaster recovery database.
5977 5978 5979 5980 5981 5982 5983 5984 |
# File 'lib/aws-sdk-odb/types.rb', line 5977 class DisasterRecoveryConfiguration < Struct.new( :disaster_recovery_type, :is_replicate_automatic_backups, :is_snapshot_standby, :time_snapshot_standby_enabled_till) SENSITIVE = [] include Aws::Structure end |
#is_snapshot_standby ⇒ Boolean
Indicates whether the standby database is a snapshot standby.
5977 5978 5979 5980 5981 5982 5983 5984 |
# File 'lib/aws-sdk-odb/types.rb', line 5977 class DisasterRecoveryConfiguration < Struct.new( :disaster_recovery_type, :is_replicate_automatic_backups, :is_snapshot_standby, :time_snapshot_standby_enabled_till) SENSITIVE = [] include Aws::Structure end |
#time_snapshot_standby_enabled_till ⇒ Time
The date and time until which the snapshot standby database remains enabled.
5977 5978 5979 5980 5981 5982 5983 5984 |
# File 'lib/aws-sdk-odb/types.rb', line 5977 class DisasterRecoveryConfiguration < Struct.new( :disaster_recovery_type, :is_replicate_automatic_backups, :is_snapshot_standby, :time_snapshot_standby_enabled_till) SENSITIVE = [] include Aws::Structure end |