Class: Aws::Odb::Types::ExadataIormConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ExadataIormConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The IORM settings of the Exadata DB system.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_plans ⇒ Array<Types::DbIormConfig>
An array of IORM settings for all the database in the Exadata DB system.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
-
#lifecycle_state ⇒ String
The current state of IORM configuration for the Exadata DB system.
-
#objective ⇒ String
The current value for the IORM objective.
Instance Attribute Details
#db_plans ⇒ Array<Types::DbIormConfig>
An array of IORM settings for all the database in the Exadata DB system.
5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-odb/types.rb', line 5919 class ExadataIormConfig < Struct.new( :db_plans, :lifecycle_details, :lifecycle_state, :objective) SENSITIVE = [] include Aws::Structure end |
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-odb/types.rb', line 5919 class ExadataIormConfig < Struct.new( :db_plans, :lifecycle_details, :lifecycle_state, :objective) SENSITIVE = [] include Aws::Structure end |
#lifecycle_state ⇒ String
The current state of IORM configuration for the Exadata DB system.
5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-odb/types.rb', line 5919 class ExadataIormConfig < Struct.new( :db_plans, :lifecycle_details, :lifecycle_state, :objective) SENSITIVE = [] include Aws::Structure end |
#objective ⇒ String
The current value for the IORM objective. The default is AUTO.
5919 5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-odb/types.rb', line 5919 class ExadataIormConfig < Struct.new( :db_plans, :lifecycle_details, :lifecycle_state, :objective) SENSITIVE = [] include Aws::Structure end |