Class: Aws::Odb::Types::ExascaleDbStorageVault
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ExascaleDbStorageVault
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Information about an Exascale storage vault.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_flash_cache_in_percent ⇒ Integer
The additional flash cache percentage for the Exascale storage vault.
-
#attached_shape_attributes ⇒ Array<String>
The list of shape attributes attached to the Exascale storage vault.
-
#autoscale_limit_in_g_bs ⇒ Integer
The autoscale limit in gigabytes (GB) for the Exascale storage vault.
-
#availability_zone ⇒ String
The Availability Zone for the Exascale storage vault.
-
#availability_zone_id ⇒ String
The Availability Zone ID for the Exascale storage vault.
-
#created_at ⇒ Time
The date and time when the Exascale storage vault was created.
-
#description ⇒ String
The description of the Exascale storage vault.
-
#display_name ⇒ String
The user-friendly name for the Exascale storage vault.
-
#exascale_db_storage_vault_arn ⇒ String
The Amazon Resource Name (ARN) of the Exascale storage vault.
-
#exascale_db_storage_vault_id ⇒ String
The unique identifier of the Exascale storage vault.
-
#high_capacity_database_storage ⇒ Types::ExascaleDbStorageDetails
The high-capacity database storage details for the Exascale storage vault.
-
#is_autoscale_enabled ⇒ Boolean
Specifies whether autoscaling is enabled for the Exascale storage vault.
-
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the Exascale storage vault.
-
#oci_url ⇒ String
The HTTPS link to the Exascale storage vault in Oracle Cloud Infrastructure (OCI).
-
#ocid ⇒ String
The OCID of the Exascale storage vault.
-
#percent_progress ⇒ Float
The amount of progress made on the current operation on the Exascale storage vault, expressed as a percentage.
-
#status ⇒ String
The current status of the Exascale storage vault.
-
#status_reason ⇒ String
Additional information about the status of the Exascale storage vault.
-
#time_zone ⇒ String
The time zone of the Exascale storage vault.
-
#vm_cluster_arns ⇒ Array<String>
The list of Amazon Resource Names (ARNs) of the VM clusters associated with this Exascale storage vault.
-
#vm_cluster_count ⇒ Integer
The number of VM clusters associated with this Exascale storage vault.
-
#vm_cluster_ids ⇒ Array<String>
The list of unique identifiers of the VM clusters associated with this Exascale storage vault.
Instance Attribute Details
#additional_flash_cache_in_percent ⇒ Integer
The additional flash cache percentage for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#attached_shape_attributes ⇒ Array<String>
The list of shape attributes attached to the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#autoscale_limit_in_g_bs ⇒ Integer
The autoscale limit in gigabytes (GB) for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The Availability Zone ID for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the Exascale storage vault was created.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#exascale_db_storage_vault_arn ⇒ String
The Amazon Resource Name (ARN) of the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#exascale_db_storage_vault_id ⇒ String
The unique identifier of the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#high_capacity_database_storage ⇒ Types::ExascaleDbStorageDetails
The high-capacity database storage details for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#is_autoscale_enabled ⇒ Boolean
Specifies whether autoscaling is enabled for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#oci_url ⇒ String
The HTTPS link to the Exascale storage vault in Oracle Cloud Infrastructure (OCI).
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The OCID of the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#percent_progress ⇒ Float
The amount of progress made on the current operation on the Exascale storage vault, expressed as a percentage.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The time zone of the Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#vm_cluster_arns ⇒ Array<String>
The list of Amazon Resource Names (ARNs) of the VM clusters associated with this Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#vm_cluster_count ⇒ Integer
The number of VM clusters associated with this Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |
#vm_cluster_ids ⇒ Array<String>
The list of unique identifiers of the VM clusters associated with this Exascale storage vault.
7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 |
# File 'lib/aws-sdk-odb/types.rb', line 7140 class ExascaleDbStorageVault < Struct.new( :exascale_db_storage_vault_id, :additional_flash_cache_in_percent, :attached_shape_attributes, :autoscale_limit_in_g_bs, :availability_zone, :availability_zone_id, :created_at, :description, :display_name, :vm_cluster_arns, :vm_cluster_count, :vm_cluster_ids, :exascale_db_storage_vault_arn, :high_capacity_database_storage, :is_autoscale_enabled, :ocid, :oci_resource_anchor_name, :oci_url, :percent_progress, :status, :status_reason, :time_zone) SENSITIVE = [] include Aws::Structure end |