Class: Aws::Odb::Types::FailoverAutonomousDatabaseInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::FailoverAutonomousDatabaseInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to fail over.
-
#peer_db_arn ⇒ String
The Amazon Resource Name (ARN) of the peer Autonomous Database to fail over to.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to fail over.
5939 5940 5941 5942 5943 5944 |
# File 'lib/aws-sdk-odb/types.rb', line 5939 class FailoverAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :peer_db_arn) SENSITIVE = [] include Aws::Structure end |
#peer_db_arn ⇒ String
The Amazon Resource Name (ARN) of the peer Autonomous Database to fail over to.
5939 5940 5941 5942 5943 5944 |
# File 'lib/aws-sdk-odb/types.rb', line 5939 class FailoverAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :peer_db_arn) SENSITIVE = [] include Aws::Structure end |