Class: Aws::Odb::Types::FailoverAutonomousDatabaseOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::FailoverAutonomousDatabaseOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was failed over.
-
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
-
#status ⇒ String
The current status of the Autonomous Database after the failover operation.
-
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the failover operation.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was failed over.
5967 5968 5969 5970 5971 5972 5973 5974 |
# File 'lib/aws-sdk-odb/types.rb', line 5967 class FailoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
5967 5968 5969 5970 5971 5972 5973 5974 |
# File 'lib/aws-sdk-odb/types.rb', line 5967 class FailoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Autonomous Database after the failover operation.
5967 5968 5969 5970 5971 5972 5973 5974 |
# File 'lib/aws-sdk-odb/types.rb', line 5967 class FailoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the failover operation.
5967 5968 5969 5970 5971 5972 5973 5974 |
# File 'lib/aws-sdk-odb/types.rb', line 5967 class FailoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |