Class: Aws::Odb::Types::GetCloudExadataInfrastructureUnallocatedResourcesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::GetCloudExadataInfrastructureUnallocatedResourcesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_exadata_infrastructure_unallocated_resources ⇒ Types::CloudExadataInfrastructureUnallocatedResources
Details about the unallocated resources in the specified Cloud Exadata infrastructure.
Instance Attribute Details
#cloud_exadata_infrastructure_unallocated_resources ⇒ Types::CloudExadataInfrastructureUnallocatedResources
Details about the unallocated resources in the specified Cloud Exadata infrastructure.
6125 6126 6127 6128 6129 |
# File 'lib/aws-sdk-odb/types.rb', line 6125 class GetCloudExadataInfrastructureUnallocatedResourcesOutput < Struct.new( :cloud_exadata_infrastructure_unallocated_resources) SENSITIVE = [] include Aws::Structure end |