Class: Aws::Odb::Types::GetDbServerInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_exadata_infrastructure_idString

The unique identifier of the Oracle Exadata infrastructure that contains the database server.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
# File 'lib/aws-sdk-odb/types.rb', line 6196

class GetDbServerInput < Struct.new(
  :cloud_exadata_infrastructure_id,
  :db_server_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_server_idString

The unique identifier of the database server to retrieve information about.

Returns:

  • (String)


6196
6197
6198
6199
6200
6201
# File 'lib/aws-sdk-odb/types.rb', line 6196

class GetDbServerInput < Struct.new(
  :cloud_exadata_infrastructure_id,
  :db_server_id)
  SENSITIVE = []
  include Aws::Structure
end