Class: Aws::Odb::Types::InternalServerException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::InternalServerException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Occurs when there is an internal failure in the Oracle Database@Amazon Web Services service. Wait and try again.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the request after an internal server error.
Instance Attribute Details
#message ⇒ String
6406 6407 6408 6409 6410 6411 |
# File 'lib/aws-sdk-odb/types.rb', line 6406 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the request after an internal server error.
6406 6407 6408 6409 6410 6411 |
# File 'lib/aws-sdk-odb/types.rb', line 6406 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |