Class: Aws::Odb::Types::ListCloudAutonomousVmClustersInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_exadata_infrastructure_id ⇒ String

The unique identifier of the Cloud Exadata Infrastructure that hosts the Autonomous VM clusters to be listed.

Returns:

  • (String)


8310
8311
8312
8313
8314
8315
8316
# File 'lib/aws-sdk-odb/types.rb', line 8310

class ListCloudAutonomousVmClustersInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_exadata_infrastructure_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return per page.

Returns:

  • (Integer)


8310
8311
8312
8313
8314
8315
8316
# File 'lib/aws-sdk-odb/types.rb', line 8310

class ListCloudAutonomousVmClustersInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_exadata_infrastructure_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token to continue listing from.

Returns:

  • (String)


8310
8311
8312
8313
8314
8315
8316
# File 'lib/aws-sdk-odb/types.rb', line 8310

class ListCloudAutonomousVmClustersInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_exadata_infrastructure_id)
  SENSITIVE = []
  include Aws::Structure
end