Class: Aws::Odb::Types::ListCloudExadataInfrastructuresOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_exadata_infrastructures ⇒ Array<Types::CloudExadataInfrastructureSummary>

The list of Exadata infrastructures along with their properties.



8370
8371
8372
8373
8374
8375
# File 'lib/aws-sdk-odb/types.rb', line 8370

class ListCloudExadataInfrastructuresOutput < Struct.new(
  :next_token,
  :cloud_exadata_infrastructures)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


8370
8371
8372
8373
8374
8375
# File 'lib/aws-sdk-odb/types.rb', line 8370

class ListCloudExadataInfrastructuresOutput < Struct.new(
  :next_token,
  :cloud_exadata_infrastructures)
  SENSITIVE = []
  include Aws::Structure
end