Class: Aws::Odb::Types::ListCloudVmClustersInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_exadata_infrastructure_id ⇒ String

The unique identifier of the Oracle Exadata infrastructure.

Returns:

  • (String)


8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-odb/types.rb', line 8397

class ListCloudVmClustersInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_exadata_infrastructure_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Returns:

  • (Integer)


8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-odb/types.rb', line 8397

class ListCloudVmClustersInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_exadata_infrastructure_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


8397
8398
8399
8400
8401
8402
8403
# File 'lib/aws-sdk-odb/types.rb', line 8397

class ListCloudVmClustersInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_exadata_infrastructure_id)
  SENSITIVE = []
  include Aws::Structure
end