Class: Aws::Odb::Types::ListCloudVmClustersOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_vm_clusters ⇒ Array<Types::CloudVmClusterSummary>

The list of VM clusters along with their properties.

Returns:



8416
8417
8418
8419
8420
8421
# File 'lib/aws-sdk-odb/types.rb', line 8416

class ListCloudVmClustersOutput < Struct.new(
  :next_token,
  :cloud_vm_clusters)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


8416
8417
8418
8419
8420
8421
# File 'lib/aws-sdk-odb/types.rb', line 8416

class ListCloudVmClustersOutput < Struct.new(
  :next_token,
  :cloud_vm_clusters)
  SENSITIVE = []
  include Aws::Structure
end