Class: Aws::Odb::Types::ListDbNodesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_vm_cluster_id ⇒ String

The unique identifier of the VM cluster. You must specify either this parameter or exadbVmClusterId.

Returns:

  • (String)


8449
8450
8451
8452
8453
8454
8455
8456
# File 'lib/aws-sdk-odb/types.rb', line 8449

class ListDbNodesInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_vm_cluster_id,
  :exadb_vm_cluster_id)
  SENSITIVE = []
  include Aws::Structure
end

#exadb_vm_cluster_id ⇒ String

The unique identifier of the Exascale VM cluster. You must specify either this parameter or cloudVmClusterId.

Returns:

  • (String)


8449
8450
8451
8452
8453
8454
8455
8456
# File 'lib/aws-sdk-odb/types.rb', line 8449

class ListDbNodesInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_vm_cluster_id,
  :exadb_vm_cluster_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Returns:

  • (Integer)


8449
8450
8451
8452
8453
8454
8455
8456
# File 'lib/aws-sdk-odb/types.rb', line 8449

class ListDbNodesInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_vm_cluster_id,
  :exadb_vm_cluster_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


8449
8450
8451
8452
8453
8454
8455
8456
# File 'lib/aws-sdk-odb/types.rb', line 8449

class ListDbNodesInput < Struct.new(
  :max_results,
  :next_token,
  :cloud_vm_cluster_id,
  :exadb_vm_cluster_id)
  SENSITIVE = []
  include Aws::Structure
end