Class: Aws::Odb::Types::ListDbNodesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_nodes ⇒ Array<Types::DbNodeSummary>

The list of DB nodes along with their properties.

Returns:



8469
8470
8471
8472
8473
8474
# File 'lib/aws-sdk-odb/types.rb', line 8469

class ListDbNodesOutput < Struct.new(
  :next_token,
  :db_nodes)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


8469
8470
8471
8472
8473
8474
# File 'lib/aws-sdk-odb/types.rb', line 8469

class ListDbNodesOutput < Struct.new(
  :next_token,
  :db_nodes)
  SENSITIVE = []
  include Aws::Structure
end