Class: Aws::Odb::Types::ListDbSystemShapesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone ⇒ String

The logical name of the AZ, for example, us-east-1a. This name varies depending on the account.

Returns:

  • (String)


8552
8553
8554
8555
8556
8557
8558
8559
8560
# File 'lib/aws-sdk-odb/types.rb', line 8552

class ListDbSystemShapesInput < Struct.new(
  :max_results,
  :next_token,
  :availability_zone,
  :availability_zone_id,
  :shape_family)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_id ⇒ String

The physical ID of the AZ, for example, use1-az4. This ID persists across accounts.

Returns:

  • (String)


8552
8553
8554
8555
8556
8557
8558
8559
8560
# File 'lib/aws-sdk-odb/types.rb', line 8552

class ListDbSystemShapesInput < Struct.new(
  :max_results,
  :next_token,
  :availability_zone,
  :availability_zone_id,
  :shape_family)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Returns:

  • (Integer)


8552
8553
8554
8555
8556
8557
8558
8559
8560
# File 'lib/aws-sdk-odb/types.rb', line 8552

class ListDbSystemShapesInput < Struct.new(
  :max_results,
  :next_token,
  :availability_zone,
  :availability_zone_id,
  :shape_family)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


8552
8553
8554
8555
8556
8557
8558
8559
8560
# File 'lib/aws-sdk-odb/types.rb', line 8552

class ListDbSystemShapesInput < Struct.new(
  :max_results,
  :next_token,
  :availability_zone,
  :availability_zone_id,
  :shape_family)
  SENSITIVE = []
  include Aws::Structure
end

#shape_family ⇒ String

The shape family to filter results by.

Returns:

  • (String)


8552
8553
8554
8555
8556
8557
8558
8559
8560
# File 'lib/aws-sdk-odb/types.rb', line 8552

class ListDbSystemShapesInput < Struct.new(
  :max_results,
  :next_token,
  :availability_zone,
  :availability_zone_id,
  :shape_family)
  SENSITIVE = []
  include Aws::Structure
end