Class: Aws::Odb::Types::ListDbSystemShapesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_system_shapes ⇒ Array<Types::DbSystemShapeSummary>

The list of shapes and their properties.

Returns:



8573
8574
8575
8576
8577
8578
# File 'lib/aws-sdk-odb/types.rb', line 8573

class ListDbSystemShapesOutput < Struct.new(
  :next_token,
  :db_system_shapes)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


8573
8574
8575
8576
8577
8578
# File 'lib/aws-sdk-odb/types.rb', line 8573

class ListDbSystemShapesOutput < Struct.new(
  :next_token,
  :db_system_shapes)
  SENSITIVE = []
  include Aws::Structure
end