Class: Aws::Odb::Types::ListGiVersionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Returns:

  • (Integer)


8789
8790
8791
8792
8793
8794
8795
# File 'lib/aws-sdk-odb/types.rb', line 8789

class ListGiVersionsInput < Struct.new(
  :max_results,
  :next_token,
  :shape)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


8789
8790
8791
8792
8793
8794
8795
# File 'lib/aws-sdk-odb/types.rb', line 8789

class ListGiVersionsInput < Struct.new(
  :max_results,
  :next_token,
  :shape)
  SENSITIVE = []
  include Aws::Structure
end

#shape ⇒ String

The shape to return GI versions for. For a list of valid shapes, use the ListDbSystemShapes operation..

Returns:

  • (String)


8789
8790
8791
8792
8793
8794
8795
# File 'lib/aws-sdk-odb/types.rb', line 8789

class ListGiVersionsInput < Struct.new(
  :max_results,
  :next_token,
  :shape)
  SENSITIVE = []
  include Aws::Structure
end