Class: Aws::Odb::Types::ListGiVersionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#gi_versions ⇒ Array<Types::GiVersionSummary>

The list of GI versions and their properties.

Returns:



8808
8809
8810
8811
8812
8813
# File 'lib/aws-sdk-odb/types.rb', line 8808

class ListGiVersionsOutput < Struct.new(
  :next_token,
  :gi_versions)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


8808
8809
8810
8811
8812
8813
# File 'lib/aws-sdk-odb/types.rb', line 8808

class ListGiVersionsOutput < Struct.new(
  :next_token,
  :gi_versions)
  SENSITIVE = []
  include Aws::Structure
end