Class: Aws::Odb::Types::ListOdbPeeringConnectionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ListOdbPeeringConnectionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of ODB peering connections to return in the response.
-
#next_token ⇒ String
The pagination token for the next page of ODB peering connections.
-
#odb_network_id ⇒ String
The identifier of the ODB network to list peering connections for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of ODB peering connections to return in the response.
Default: 20
Constraints:
- Must be between 1 and 100.
^
8881 8882 8883 8884 8885 8886 8887 |
# File 'lib/aws-sdk-odb/types.rb', line 8881 class ListOdbPeeringConnectionsInput < Struct.new( :max_results, :next_token, :odb_network_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the next page of ODB peering connections.
8881 8882 8883 8884 8885 8886 8887 |
# File 'lib/aws-sdk-odb/types.rb', line 8881 class ListOdbPeeringConnectionsInput < Struct.new( :max_results, :next_token, :odb_network_id) SENSITIVE = [] include Aws::Structure end |
#odb_network_id ⇒ String
The identifier of the ODB network to list peering connections for.
If not specified, lists all ODB peering connections in the account.
8881 8882 8883 8884 8885 8886 8887 |
# File 'lib/aws-sdk-odb/types.rb', line 8881 class ListOdbPeeringConnectionsInput < Struct.new( :max_results, :next_token, :odb_network_id) SENSITIVE = [] include Aws::Structure end |