Class: Aws::Odb::Types::ListOdbPeeringConnectionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ListOdbPeeringConnectionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token for the next page of ODB peering connections.
-
#odb_peering_connections ⇒ Array<Types::OdbPeeringConnectionSummary>
The list of ODB peering connections.
Instance Attribute Details
#next_token ⇒ String
The pagination token for the next page of ODB peering connections.
8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-odb/types.rb', line 8899 class ListOdbPeeringConnectionsOutput < Struct.new( :next_token, :odb_peering_connections) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connections ⇒ Array<Types::OdbPeeringConnectionSummary>
The list of ODB peering connections.
8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-odb/types.rb', line 8899 class ListOdbPeeringConnectionsOutput < Struct.new( :next_token, :odb_peering_connections) SENSITIVE = [] include Aws::Structure end |