Class: Aws::Odb::Types::ListSystemVersionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#gi_version ⇒ String

The software version of the Exadata Grid Infrastructure (GI).

Returns:

  • (String)


8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-odb/types.rb', line 8930

class ListSystemVersionsInput < Struct.new(
  :max_results,
  :next_token,
  :gi_version,
  :shape)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.

Default: 10

Returns:

  • (Integer)


8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-odb/types.rb', line 8930

class ListSystemVersionsInput < Struct.new(
  :max_results,
  :next_token,
  :gi_version,
  :shape)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.

Returns:

  • (String)


8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-odb/types.rb', line 8930

class ListSystemVersionsInput < Struct.new(
  :max_results,
  :next_token,
  :gi_version,
  :shape)
  SENSITIVE = []
  include Aws::Structure
end

#shape ⇒ String

The Exadata hardware system model.

Returns:

  • (String)


8930
8931
8932
8933
8934
8935
8936
8937
# File 'lib/aws-sdk-odb/types.rb', line 8930

class ListSystemVersionsInput < Struct.new(
  :max_results,
  :next_token,
  :gi_version,
  :shape)
  SENSITIVE = []
  include Aws::Structure
end