Class: Aws::Odb::Types::ListSystemVersionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to include in another request to get the next page of items. This value is null when there are no more items to return.

Returns:

  • (String)


8950
8951
8952
8953
8954
8955
# File 'lib/aws-sdk-odb/types.rb', line 8950

class ListSystemVersionsOutput < Struct.new(
  :next_token,
  :system_versions)
  SENSITIVE = []
  include Aws::Structure
end

#system_versions ⇒ Array<Types::SystemVersionSummary>

The list of system versions.

Returns:



8950
8951
8952
8953
8954
8955
# File 'lib/aws-sdk-odb/types.rb', line 8950

class ListSystemVersionsOutput < Struct.new(
  :next_token,
  :system_versions)
  SENSITIVE = []
  include Aws::Structure
end