Class: Aws::Odb::Types::PointInTimeRestoreConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The configuration for creating an Autonomous Database by restoring to a point in time.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clone_table_space_listArray<Integer>

The list of tablespace identifiers to clone from the point-in-time restore.

Returns:

  • (Array<Integer>)


8007
8008
8009
8010
8011
8012
8013
8014
8015
# File 'lib/aws-sdk-odb/types.rb', line 8007

class PointInTimeRestoreConfiguration < Struct.new(
  :source_autonomous_database_id,
  :clone_type,
  :timestamp,
  :use_latest_available_backup_timestamp,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end

#clone_typeString

The type of clone to create from the point-in-time restore.

Returns:

  • (String)


8007
8008
8009
8010
8011
8012
8013
8014
8015
# File 'lib/aws-sdk-odb/types.rb', line 8007

class PointInTimeRestoreConfiguration < Struct.new(
  :source_autonomous_database_id,
  :clone_type,
  :timestamp,
  :use_latest_available_backup_timestamp,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end

#source_autonomous_database_idString

The unique identifier of the source Autonomous Database to restore from.

Returns:

  • (String)


8007
8008
8009
8010
8011
8012
8013
8014
8015
# File 'lib/aws-sdk-odb/types.rb', line 8007

class PointInTimeRestoreConfiguration < Struct.new(
  :source_autonomous_database_id,
  :clone_type,
  :timestamp,
  :use_latest_available_backup_timestamp,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The date and time to which to restore the Autonomous Database.

Returns:

  • (Time)


8007
8008
8009
8010
8011
8012
8013
8014
8015
# File 'lib/aws-sdk-odb/types.rb', line 8007

class PointInTimeRestoreConfiguration < Struct.new(
  :source_autonomous_database_id,
  :clone_type,
  :timestamp,
  :use_latest_available_backup_timestamp,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end

#use_latest_available_backup_timestampBoolean

Indicates whether to use the latest available backup timestamp for the restore.

Returns:

  • (Boolean)


8007
8008
8009
8010
8011
8012
8013
8014
8015
# File 'lib/aws-sdk-odb/types.rb', line 8007

class PointInTimeRestoreConfiguration < Struct.new(
  :source_autonomous_database_id,
  :clone_type,
  :timestamp,
  :use_latest_available_backup_timestamp,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end