Class: Aws::Odb::Types::ResourceNotFoundException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The operation tried to access a resource that doesn't exist. Make sure you provided the correct resource and try again.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


9873
9874
9875
9876
9877
9878
9879
# File 'lib/aws-sdk-odb/types.rb', line 9873

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

The identifier of the resource that was not found.

Returns:

  • (String)


9873
9874
9875
9876
9877
9878
9879
# File 'lib/aws-sdk-odb/types.rb', line 9873

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

The type of resource that was not found.

Returns:

  • (String)


9873
9874
9875
9876
9877
9878
9879
# File 'lib/aws-sdk-odb/types.rb', line 9873

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end