Class: Aws::Odb::Types::ResourcePoolSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ResourcePoolSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The configuration of a resource pool for an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available_compute_capacity ⇒ Integer
The available compute capacity in the resource pool.
-
#available_storage_capacity_in_t_bs ⇒ Float
The available storage capacity in the resource pool, in TB.
-
#is_disabled ⇒ Boolean
Indicates whether the resource pool is disabled.
-
#pool_size ⇒ Integer
The number of Autonomous Databases that the resource pool can contain.
-
#pool_storage_size_in_t_bs ⇒ Integer
The total storage size of the resource pool, in terabytes (TB).
-
#total_compute_capacity ⇒ Integer
The total compute capacity of the resource pool.
Instance Attribute Details
#available_compute_capacity ⇒ Integer
The available compute capacity in the resource pool.
8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-odb/types.rb', line 8345 class ResourcePoolSummary < Struct.new( :is_disabled, :pool_size, :pool_storage_size_in_t_bs, :available_storage_capacity_in_t_bs, :total_compute_capacity, :available_compute_capacity) SENSITIVE = [] include Aws::Structure end |
#available_storage_capacity_in_t_bs ⇒ Float
The available storage capacity in the resource pool, in TB.
8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-odb/types.rb', line 8345 class ResourcePoolSummary < Struct.new( :is_disabled, :pool_size, :pool_storage_size_in_t_bs, :available_storage_capacity_in_t_bs, :total_compute_capacity, :available_compute_capacity) SENSITIVE = [] include Aws::Structure end |
#is_disabled ⇒ Boolean
Indicates whether the resource pool is disabled.
8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-odb/types.rb', line 8345 class ResourcePoolSummary < Struct.new( :is_disabled, :pool_size, :pool_storage_size_in_t_bs, :available_storage_capacity_in_t_bs, :total_compute_capacity, :available_compute_capacity) SENSITIVE = [] include Aws::Structure end |
#pool_size ⇒ Integer
The number of Autonomous Databases that the resource pool can contain.
8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-odb/types.rb', line 8345 class ResourcePoolSummary < Struct.new( :is_disabled, :pool_size, :pool_storage_size_in_t_bs, :available_storage_capacity_in_t_bs, :total_compute_capacity, :available_compute_capacity) SENSITIVE = [] include Aws::Structure end |
#pool_storage_size_in_t_bs ⇒ Integer
The total storage size of the resource pool, in terabytes (TB).
8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-odb/types.rb', line 8345 class ResourcePoolSummary < Struct.new( :is_disabled, :pool_size, :pool_storage_size_in_t_bs, :available_storage_capacity_in_t_bs, :total_compute_capacity, :available_compute_capacity) SENSITIVE = [] include Aws::Structure end |
#total_compute_capacity ⇒ Integer
The total compute capacity of the resource pool.
8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 |
# File 'lib/aws-sdk-odb/types.rb', line 8345 class ResourcePoolSummary < Struct.new( :is_disabled, :pool_size, :pool_storage_size_in_t_bs, :available_storage_capacity_in_t_bs, :total_compute_capacity, :available_compute_capacity) SENSITIVE = [] include Aws::Structure end |