Class: Aws::Odb::Types::RestoreAutonomousDatabaseInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::RestoreAutonomousDatabaseInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to restore.
-
#timestamp ⇒ Time
The date and time to which to restore the Autonomous Database.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to restore.
8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-odb/types.rb', line 8179 class RestoreAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The date and time to which to restore the Autonomous Database.
8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-odb/types.rb', line 8179 class RestoreAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :timestamp) SENSITIVE = [] include Aws::Structure end |