Class: Aws::Odb::Types::RestoreAutonomousDatabaseOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::RestoreAutonomousDatabaseOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was restored.
-
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
-
#status ⇒ String
The current status of the Autonomous Database after the restore operation.
-
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the restore operation.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was restored.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-odb/types.rb', line 8206 class RestoreAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-odb/types.rb', line 8206 class RestoreAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Autonomous Database after the restore operation.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-odb/types.rb', line 8206 class RestoreAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the restore operation.
8206 8207 8208 8209 8210 8211 8212 8213 |
# File 'lib/aws-sdk-odb/types.rb', line 8206 class RestoreAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |