Class: Aws::Odb::Types::RestoreFromBackupConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The configuration for creating an Autonomous Database by restoring from a backup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#autonomous_database_backup_idString

The unique identifier of the Autonomous Database backup to restore from.

Returns:

  • (String)


8233
8234
8235
8236
8237
8238
8239
# File 'lib/aws-sdk-odb/types.rb', line 8233

class RestoreFromBackupConfiguration < Struct.new(
  :autonomous_database_backup_id,
  :clone_type,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end

#clone_table_space_listArray<Integer>

The list of tablespace identifiers to clone from the backup.

Returns:

  • (Array<Integer>)


8233
8234
8235
8236
8237
8238
8239
# File 'lib/aws-sdk-odb/types.rb', line 8233

class RestoreFromBackupConfiguration < Struct.new(
  :autonomous_database_backup_id,
  :clone_type,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end

#clone_typeString

The type of clone to create from the backup.

Returns:

  • (String)


8233
8234
8235
8236
8237
8238
8239
# File 'lib/aws-sdk-odb/types.rb', line 8233

class RestoreFromBackupConfiguration < Struct.new(
  :autonomous_database_backup_id,
  :clone_type,
  :clone_table_space_list)
  SENSITIVE = []
  include Aws::Structure
end