Class: Aws::Odb::Types::ScheduledOperationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ScheduledOperationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The scheduled start and stop times for an Autonomous Database on a specific day of the week.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#day_of_week ⇒ Types::DayOfWeek
The day of the week on which the scheduled operation occurs.
-
#scheduled_start_time ⇒ String
The scheduled start time for the Autonomous Database, in UTC.
-
#scheduled_stop_time ⇒ String
The scheduled stop time for the Autonomous Database, in UTC.
Instance Attribute Details
#day_of_week ⇒ Types::DayOfWeek
The day of the week on which the scheduled operation occurs.
8287 8288 8289 8290 8291 8292 8293 |
# File 'lib/aws-sdk-odb/types.rb', line 8287 class ScheduledOperationDetails < Struct.new( :day_of_week, :scheduled_start_time, :scheduled_stop_time) SENSITIVE = [] include Aws::Structure end |
#scheduled_start_time ⇒ String
The scheduled start time for the Autonomous Database, in UTC.
8287 8288 8289 8290 8291 8292 8293 |
# File 'lib/aws-sdk-odb/types.rb', line 8287 class ScheduledOperationDetails < Struct.new( :day_of_week, :scheduled_start_time, :scheduled_stop_time) SENSITIVE = [] include Aws::Structure end |
#scheduled_stop_time ⇒ String
The scheduled stop time for the Autonomous Database, in UTC.
8287 8288 8289 8290 8291 8292 8293 |
# File 'lib/aws-sdk-odb/types.rb', line 8287 class ScheduledOperationDetails < Struct.new( :day_of_week, :scheduled_start_time, :scheduled_stop_time) SENSITIVE = [] include Aws::Structure end |