Class: Aws::Odb::Types::SourceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::SourceConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
SourceConfiguration is a union - when making an API calls you must set exactly one of the members.
The configuration details for the source used to create an Autonomous Database. This is a union, so only one of the following members can be specified.
Direct Known Subclasses
CloneToRefreshable, CrossRegionDataGuard, CrossRegionDisasterRecovery, DatabaseClone, PointInTimeRestore, RestoreFromBackup, Unknown
Defined Under Namespace
Classes: CloneToRefreshable, CrossRegionDataGuard, CrossRegionDisasterRecovery, DatabaseClone, PointInTimeRestore, RestoreFromBackup, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clone_to_refreshable ⇒ Types::CloneToRefreshableConfiguration
The configuration for creating the Autonomous Database as a refreshable clone.
-
#cross_region_data_guard ⇒ Types::CrossRegionDataGuardConfiguration
The configuration for creating the Autonomous Database as a cross-Region Oracle Data Guard peer.
-
#cross_region_disaster_recovery ⇒ Types::CrossRegionDisasterRecoveryConfiguration
The configuration for creating the Autonomous Database as a cross-Region disaster recovery peer.
-
#database_clone ⇒ Types::DatabaseCloneConfiguration
The configuration for creating the Autonomous Database as a clone of an existing database.
-
#point_in_time_restore ⇒ Types::PointInTimeRestoreConfiguration
The configuration for creating the Autonomous Database by restoring to a point in time.
-
#restore_from_backup ⇒ Types::RestoreFromBackupConfiguration
The configuration for creating the Autonomous Database by restoring from a backup.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#clone_to_refreshable ⇒ Types::CloneToRefreshableConfiguration
The configuration for creating the Autonomous Database as a refreshable clone.
8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-odb/types.rb', line 8421 class SourceConfiguration < Struct.new( :database_clone, :restore_from_backup, :point_in_time_restore, :cross_region_data_guard, :cross_region_disaster_recovery, :clone_to_refreshable, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DatabaseClone < SourceConfiguration; end class RestoreFromBackup < SourceConfiguration; end class PointInTimeRestore < SourceConfiguration; end class CrossRegionDataGuard < SourceConfiguration; end class CrossRegionDisasterRecovery < SourceConfiguration; end class CloneToRefreshable < SourceConfiguration; end class Unknown < SourceConfiguration; end end |
#cross_region_data_guard ⇒ Types::CrossRegionDataGuardConfiguration
The configuration for creating the Autonomous Database as a cross-Region Oracle Data Guard peer.
8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-odb/types.rb', line 8421 class SourceConfiguration < Struct.new( :database_clone, :restore_from_backup, :point_in_time_restore, :cross_region_data_guard, :cross_region_disaster_recovery, :clone_to_refreshable, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DatabaseClone < SourceConfiguration; end class RestoreFromBackup < SourceConfiguration; end class PointInTimeRestore < SourceConfiguration; end class CrossRegionDataGuard < SourceConfiguration; end class CrossRegionDisasterRecovery < SourceConfiguration; end class CloneToRefreshable < SourceConfiguration; end class Unknown < SourceConfiguration; end end |
#cross_region_disaster_recovery ⇒ Types::CrossRegionDisasterRecoveryConfiguration
The configuration for creating the Autonomous Database as a cross-Region disaster recovery peer.
8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-odb/types.rb', line 8421 class SourceConfiguration < Struct.new( :database_clone, :restore_from_backup, :point_in_time_restore, :cross_region_data_guard, :cross_region_disaster_recovery, :clone_to_refreshable, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DatabaseClone < SourceConfiguration; end class RestoreFromBackup < SourceConfiguration; end class PointInTimeRestore < SourceConfiguration; end class CrossRegionDataGuard < SourceConfiguration; end class CrossRegionDisasterRecovery < SourceConfiguration; end class CloneToRefreshable < SourceConfiguration; end class Unknown < SourceConfiguration; end end |
#database_clone ⇒ Types::DatabaseCloneConfiguration
The configuration for creating the Autonomous Database as a clone of an existing database.
8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-odb/types.rb', line 8421 class SourceConfiguration < Struct.new( :database_clone, :restore_from_backup, :point_in_time_restore, :cross_region_data_guard, :cross_region_disaster_recovery, :clone_to_refreshable, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DatabaseClone < SourceConfiguration; end class RestoreFromBackup < SourceConfiguration; end class PointInTimeRestore < SourceConfiguration; end class CrossRegionDataGuard < SourceConfiguration; end class CrossRegionDisasterRecovery < SourceConfiguration; end class CloneToRefreshable < SourceConfiguration; end class Unknown < SourceConfiguration; end end |
#point_in_time_restore ⇒ Types::PointInTimeRestoreConfiguration
The configuration for creating the Autonomous Database by restoring to a point in time.
8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-odb/types.rb', line 8421 class SourceConfiguration < Struct.new( :database_clone, :restore_from_backup, :point_in_time_restore, :cross_region_data_guard, :cross_region_disaster_recovery, :clone_to_refreshable, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DatabaseClone < SourceConfiguration; end class RestoreFromBackup < SourceConfiguration; end class PointInTimeRestore < SourceConfiguration; end class CrossRegionDataGuard < SourceConfiguration; end class CrossRegionDisasterRecovery < SourceConfiguration; end class CloneToRefreshable < SourceConfiguration; end class Unknown < SourceConfiguration; end end |
#restore_from_backup ⇒ Types::RestoreFromBackupConfiguration
The configuration for creating the Autonomous Database by restoring from a backup.
8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-odb/types.rb', line 8421 class SourceConfiguration < Struct.new( :database_clone, :restore_from_backup, :point_in_time_restore, :cross_region_data_guard, :cross_region_disaster_recovery, :clone_to_refreshable, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DatabaseClone < SourceConfiguration; end class RestoreFromBackup < SourceConfiguration; end class PointInTimeRestore < SourceConfiguration; end class CrossRegionDataGuard < SourceConfiguration; end class CrossRegionDisasterRecovery < SourceConfiguration; end class CloneToRefreshable < SourceConfiguration; end class Unknown < SourceConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8421 8422 8423 |
# File 'lib/aws-sdk-odb/types.rb', line 8421 def unknown @unknown end |