Class: Aws::Odb::Types::StartAutonomousDatabaseOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::StartAutonomousDatabaseOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was started.
-
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
-
#status ⇒ String
The current status of the Autonomous Database after the start operation.
-
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the start operation.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was started.
8474 8475 8476 8477 8478 8479 8480 8481 |
# File 'lib/aws-sdk-odb/types.rb', line 8474 class StartAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
8474 8475 8476 8477 8478 8479 8480 8481 |
# File 'lib/aws-sdk-odb/types.rb', line 8474 class StartAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Autonomous Database after the start operation.
8474 8475 8476 8477 8478 8479 8480 8481 |
# File 'lib/aws-sdk-odb/types.rb', line 8474 class StartAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the start operation.
8474 8475 8476 8477 8478 8479 8480 8481 |
# File 'lib/aws-sdk-odb/types.rb', line 8474 class StartAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |