Class: Aws::Odb::Types::StopAutonomousDatabaseOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::StopAutonomousDatabaseOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was stopped.
-
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
-
#status ⇒ String
The current status of the Autonomous Database after the stop operation.
-
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the stop operation.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was stopped.
8556 8557 8558 8559 8560 8561 8562 8563 |
# File 'lib/aws-sdk-odb/types.rb', line 8556 class StopAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
8556 8557 8558 8559 8560 8561 8562 8563 |
# File 'lib/aws-sdk-odb/types.rb', line 8556 class StopAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Autonomous Database after the stop operation.
8556 8557 8558 8559 8560 8561 8562 8563 |
# File 'lib/aws-sdk-odb/types.rb', line 8556 class StopAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the stop operation.
8556 8557 8558 8559 8560 8561 8562 8563 |
# File 'lib/aws-sdk-odb/types.rb', line 8556 class StopAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |