Class: Aws::Odb::Types::SwitchoverAutonomousDatabaseInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::SwitchoverAutonomousDatabaseInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to switch over.
-
#peer_db_arn ⇒ String
The Amazon Resource Name (ARN) of the peer Autonomous Database to switch over to.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to switch over.
8666 8667 8668 8669 8670 8671 |
# File 'lib/aws-sdk-odb/types.rb', line 8666 class SwitchoverAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :peer_db_arn) SENSITIVE = [] include Aws::Structure end |
#peer_db_arn ⇒ String
The Amazon Resource Name (ARN) of the peer Autonomous Database to switch over to.
8666 8667 8668 8669 8670 8671 |
# File 'lib/aws-sdk-odb/types.rb', line 8666 class SwitchoverAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :peer_db_arn) SENSITIVE = [] include Aws::Structure end |