Class: Aws::Odb::Types::SwitchoverAutonomousDatabaseOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::SwitchoverAutonomousDatabaseOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was switched over.
-
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
-
#status ⇒ String
The current status of the Autonomous Database after the switchover operation.
-
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the switchover operation.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database that was switched over.
8694 8695 8696 8697 8698 8699 8700 8701 |
# File 'lib/aws-sdk-odb/types.rb', line 8694 class SwitchoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the Autonomous Database.
8694 8695 8696 8697 8698 8699 8700 8701 |
# File 'lib/aws-sdk-odb/types.rb', line 8694 class SwitchoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Autonomous Database after the switchover operation.
8694 8695 8696 8697 8698 8699 8700 8701 |
# File 'lib/aws-sdk-odb/types.rb', line 8694 class SwitchoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the Autonomous Database after the switchover operation.
8694 8695 8696 8697 8698 8699 8700 8701 |
# File 'lib/aws-sdk-odb/types.rb', line 8694 class SwitchoverAutonomousDatabaseOutput < Struct.new( :autonomous_database_id, :display_name, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |