Class: Aws::Odb::Types::TransportableTablespace

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The transportable tablespace configuration used when creating an Autonomous Database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tts_bundle_urlString

The URL of the transportable tablespace bundle to use when creating the Autonomous Database.

Returns:

  • (String)


8779
8780
8781
8782
8783
# File 'lib/aws-sdk-odb/types.rb', line 8779

class TransportableTablespace < Struct.new(
  :tts_bundle_url)
  SENSITIVE = []
  include Aws::Structure
end