Class: Aws::Odb::Types::UpdateCloudExadataInfrastructureInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_exadata_infrastructure_idString

The unique identifier of the Exadata infrastructure to update.

Returns:

  • (String)


9140
9141
9142
9143
9144
9145
# File 'lib/aws-sdk-odb/types.rb', line 9140

class UpdateCloudExadataInfrastructureInput < Struct.new(
  :cloud_exadata_infrastructure_id,
  :maintenance_window)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_windowTypes::MaintenanceWindow

The scheduling details for the maintenance window. Patching and system updates take place during the maintenance window.



9140
9141
9142
9143
9144
9145
# File 'lib/aws-sdk-odb/types.rb', line 9140

class UpdateCloudExadataInfrastructureInput < Struct.new(
  :cloud_exadata_infrastructure_id,
  :maintenance_window)
  SENSITIVE = []
  include Aws::Structure
end