Class: Aws::Odb::Types::UpdateExadbVmClusterInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_collection_optionsTypes::DataCollectionOptions

The set of preferences for the various diagnostic collection options for the Exascale VM cluster.



10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

A new user-friendly name for the Exascale VM cluster.

Returns:

  • (String)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#enabled_ecpu_countInteger

The number of ECPUs to enable for the Exascale VM cluster.

Returns:

  • (Integer)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#exadb_vm_cluster_idString

The unique identifier of the Exascale VM cluster to update.

Returns:

  • (String)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#grid_image_idString

The Grid Infrastructure software image ID for the Exascale VM cluster.

Returns:

  • (String)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

The Oracle license model to apply to the Exascale VM cluster.

Returns:

  • (String)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#ssh_public_keysArray<String>

The public key portion of one or more key pairs used for SSH access to the Exascale VM cluster.

Returns:

  • (Array<String>)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#system_versionString

The version of the operating system of the image for the Exascale VM cluster.

Returns:

  • (String)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#total_ecpu_countInteger

The total number of ECPUs for the Exascale VM cluster.

Returns:

  • (Integer)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#update_actionString

The update action to perform on the Exascale VM cluster.

Returns:

  • (String)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end

#vm_file_system_storage_total_size_in_g_bsInteger

The total amount of file system storage, in gigabytes (GB), for the Exascale VM cluster.

Returns:

  • (Integer)


10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
# File 'lib/aws-sdk-odb/types.rb', line 10879

class UpdateExadbVmClusterInput < Struct.new(
  :exadb_vm_cluster_id,
  :data_collection_options,
  :display_name,
  :enabled_ecpu_count,
  :grid_image_id,
  :license_model,
  :ssh_public_keys,
  :system_version,
  :total_ecpu_count,
  :update_action,
  :vm_file_system_storage_total_size_in_g_bs)
  SENSITIVE = []
  include Aws::Structure
end