Class: Aws::Odb::Types::UpdateOdbPeeringConnectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

A new display name for the peering connection.

Returns:

  • (String)


11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-odb/types.rb', line 11130

class UpdateOdbPeeringConnectionInput < Struct.new(
  :odb_peering_connection_id,
  :display_name,
  :peer_network_cidrs_to_be_added,
  :peer_network_cidrs_to_be_removed)
  SENSITIVE = []
  include Aws::Structure
end

#odb_peering_connection_idString

The identifier of the Oracle Database@Amazon Web Services peering connection to update.

Returns:

  • (String)


11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-odb/types.rb', line 11130

class UpdateOdbPeeringConnectionInput < Struct.new(
  :odb_peering_connection_id,
  :display_name,
  :peer_network_cidrs_to_be_added,
  :peer_network_cidrs_to_be_removed)
  SENSITIVE = []
  include Aws::Structure
end

#peer_network_cidrs_to_be_addedArray<String>

A list of CIDR blocks to add to the peering connection. These CIDR blocks define the IP address ranges that can communicate through the peering connection. The CIDR blocks must not overlap with existing CIDR blocks in the Oracle Database@Amazon Web Services network.

Returns:

  • (Array<String>)


11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-odb/types.rb', line 11130

class UpdateOdbPeeringConnectionInput < Struct.new(
  :odb_peering_connection_id,
  :display_name,
  :peer_network_cidrs_to_be_added,
  :peer_network_cidrs_to_be_removed)
  SENSITIVE = []
  include Aws::Structure
end

#peer_network_cidrs_to_be_removedArray<String>

A list of CIDR blocks to remove from the peering connection. The CIDR blocks must currently exist in the peering connection.

Returns:

  • (Array<String>)


11130
11131
11132
11133
11134
11135
11136
11137
# File 'lib/aws-sdk-odb/types.rb', line 11130

class UpdateOdbPeeringConnectionInput < Struct.new(
  :odb_peering_connection_id,
  :display_name,
  :peer_network_cidrs_to_be_added,
  :peer_network_cidrs_to_be_removed)
  SENSITIVE = []
  include Aws::Structure
end