Class: Aws::Odb::Types::WalletPasswordSourceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Note:

WalletPasswordSourceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WalletPasswordSourceConfiguration corresponding to the set member.

The configuration of the wallet password source. This is a union, so only one of the following members can be specified.

Defined Under Namespace

Classes: CustomerManagedAwsSecret, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_managed_aws_secret ⇒ Types::CustomerManagedAwsSecretConfiguration

The configuration for a customer-managed Amazon Web Services Secrets Manager secret used as the wallet password source.



11352
11353
11354
11355
11356
11357
11358
11359
11360
11361
# File 'lib/aws-sdk-odb/types.rb', line 11352

class WalletPasswordSourceConfiguration < Struct.new(
  :customer_managed_aws_secret,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerManagedAwsSecret < WalletPasswordSourceConfiguration; end
  class Unknown < WalletPasswordSourceConfiguration; end
end

#unknown ⇒ Object

Returns the value of attribute unknown

Returns:

  • (Object) —

    the current value of unknown



11352
11353
11354
# File 'lib/aws-sdk-odb/types.rb', line 11352

def unknown
  @unknown
end