Class: Aws::Odb::Types::WalletPasswordSourceConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::WalletPasswordSourceConfigurationInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Note:
WalletPasswordSourceConfigurationInput is a union - when making an API calls you must set exactly one of the members.
The input configuration for the wallet password source. This is a union, so only one of the following members can be specified.
Defined Under Namespace
Classes: CustomerManagedAwsSecret, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_managed_aws_secret ⇒ Types::CustomerManagedAwsSecretConfigurationInput
The configuration for using a customer-managed Amazon Web Services Secrets Manager secret as the wallet password source.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#customer_managed_aws_secret ⇒ Types::CustomerManagedAwsSecretConfigurationInput
The configuration for using a customer-managed Amazon Web Services Secrets Manager secret as the wallet password source.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 |
# File 'lib/aws-sdk-odb/types.rb', line 11248 class WalletPasswordSourceConfigurationInput < Struct.new( :customer_managed_aws_secret, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerManagedAwsSecret < WalletPasswordSourceConfigurationInput; end class Unknown < WalletPasswordSourceConfigurationInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
11248 11249 11250 |
# File 'lib/aws-sdk-odb/types.rb', line 11248 def unknown @unknown end |