Class: Aws::Odb::Types::WalletPasswordSourceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

A summary of the password source configuration for an Autonomous Database wallet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#password_source ⇒ String

The source of the password for the Autonomous Database wallet.

Returns:

  • (String)


11400
11401
11402
11403
11404
11405
# File 'lib/aws-sdk-odb/types.rb', line 11400

class WalletPasswordSourceSummary < Struct.new(
  :password_source,
  :password_source_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#password_source_configuration ⇒ Types::WalletPasswordSourceConfiguration

The configuration of the password source for the Autonomous Database wallet.



11400
11401
11402
11403
11404
11405
# File 'lib/aws-sdk-odb/types.rb', line 11400

class WalletPasswordSourceSummary < Struct.new(
  :password_source,
  :password_source_configuration)
  SENSITIVE = []
  include Aws::Structure
end