Class: Aws::Odb::Types::AutonomousDatabaseWalletDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::AutonomousDatabaseWalletDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The wallet details for an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The current status of the Autonomous Database wallet.
-
#time_rotated ⇒ Time
The date and time when the Autonomous Database wallet was last rotated.
Instance Attribute Details
#status ⇒ String
The current status of the Autonomous Database wallet.
1654 1655 1656 1657 1658 1659 |
# File 'lib/aws-sdk-odb/types.rb', line 1654 class AutonomousDatabaseWalletDetails < Struct.new( :status, :time_rotated) SENSITIVE = [] include Aws::Structure end |
#time_rotated ⇒ Time
The date and time when the Autonomous Database wallet was last rotated.
1654 1655 1656 1657 1658 1659 |
# File 'lib/aws-sdk-odb/types.rb', line 1654 class AutonomousDatabaseWalletDetails < Struct.new( :status, :time_rotated) SENSITIVE = [] include Aws::Structure end |