Class: Aws::Odb::Types::AutonomousVirtualMachineSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::AutonomousVirtualMachineSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
A summary of an Autonomous Virtual Machine (VM) within an Autonomous VM cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_virtual_machine_id ⇒ String
The unique identifier of the Autonomous VM.
-
#client_ip_address ⇒ String
The IP address used by clients to connect to this Autonomous VM.
-
#cloud_autonomous_vm_cluster_id ⇒ String
The unique identifier of the Autonomous VM cluster containing this Autonomous VM.
-
#cpu_core_count ⇒ Integer
The number of CPU cores allocated to this Autonomous VM.
-
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of storage allocated to this Autonomous Virtual Machine, in gigabytes (GB).
-
#db_server_display_name ⇒ String
The display name of the database server hosting this Autonomous VM.
-
#db_server_id ⇒ String
The unique identifier of the database server hosting this Autonomous VM.
-
#memory_size_in_g_bs ⇒ Integer
The amount of memory allocated to this Autonomous VM, in gigabytes (GB).
-
#oci_resource_anchor_name ⇒ String
The name of the Oracle Cloud Infrastructure (OCI) resource anchor associated with this Autonomous VM.
-
#ocid ⇒ String
The Oracle Cloud Identifier (OCID) of the Autonomous VM.
-
#status ⇒ String
The current status of the Autonomous VM.
-
#status_reason ⇒ String
Additional information about the current status of the Autonomous VM, if applicable.
-
#vm_name ⇒ String
The name of the Autonomous VM.
Instance Attribute Details
#autonomous_virtual_machine_id ⇒ String
The unique identifier of the Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#client_ip_address ⇒ String
The IP address used by clients to connect to this Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#cloud_autonomous_vm_cluster_id ⇒ String
The unique identifier of the Autonomous VM cluster containing this Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#cpu_core_count ⇒ Integer
The number of CPU cores allocated to this Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of storage allocated to this Autonomous Virtual Machine, in gigabytes (GB).
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#db_server_display_name ⇒ String
The display name of the database server hosting this Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#db_server_id ⇒ String
The unique identifier of the database server hosting this Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_g_bs ⇒ Integer
The amount of memory allocated to this Autonomous VM, in gigabytes (GB).
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the Oracle Cloud Infrastructure (OCI) resource anchor associated with this Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The Oracle Cloud Identifier (OCID) of the Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the current status of the Autonomous VM, if applicable.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |
#vm_name ⇒ String
The name of the Autonomous VM.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/aws-sdk-odb/types.rb', line 1724 class AutonomousVirtualMachineSummary < Struct.new( :autonomous_virtual_machine_id, :status, :status_reason, :vm_name, :db_server_id, :db_server_display_name, :cpu_core_count, :memory_size_in_g_bs, :db_node_storage_size_in_g_bs, :client_ip_address, :cloud_autonomous_vm_cluster_id, :ocid, :oci_resource_anchor_name) SENSITIVE = [] include Aws::Structure end |