Class: Aws::Odb::Types::AwsEncryptionKeyConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::AwsEncryptionKeyConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The configuration of the Amazon Web Services Key Management Service (KMS) encryption key used for an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#external_id_type ⇒ String
The type of external identifier associated with the encryption key.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that grants access to the KMS key.
-
#kms_key_id ⇒ String
The identifier or ARN of the Amazon Web Services KMS key used for encryption.
Instance Attribute Details
#external_id_type ⇒ String
The type of external identifier associated with the encryption key.
1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-odb/types.rb', line 1761 class AwsEncryptionKeyConfiguration < Struct.new( :iam_role_arn, :external_id_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that grants access to the KMS key.
1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-odb/types.rb', line 1761 class AwsEncryptionKeyConfiguration < Struct.new( :iam_role_arn, :external_id_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The identifier or ARN of the Amazon Web Services KMS key used for encryption.
1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-odb/types.rb', line 1761 class AwsEncryptionKeyConfiguration < Struct.new( :iam_role_arn, :external_id_type, :kms_key_id) SENSITIVE = [] include Aws::Structure end |