Class: Aws::Odb::Types::AwsEncryptionKeyConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The configuration of the Amazon Web Services Key Management Service (KMS) encryption key to use for an Autonomous Database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#external_id_typeString

The type of external identifier associated with the encryption key.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
# File 'lib/aws-sdk-odb/types.rb', line 1788

class AwsEncryptionKeyConfigurationInput < Struct.new(
  :iam_role_arn,
  :external_id_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that grants access to the KMS key.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
# File 'lib/aws-sdk-odb/types.rb', line 1788

class AwsEncryptionKeyConfigurationInput < Struct.new(
  :iam_role_arn,
  :external_id_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The identifier or ARN of the Amazon Web Services KMS key to use for encryption.

Returns:

  • (String)


1788
1789
1790
1791
1792
1793
1794
# File 'lib/aws-sdk-odb/types.rb', line 1788

class AwsEncryptionKeyConfigurationInput < Struct.new(
  :iam_role_arn,
  :external_id_type,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end