Class: Aws::Odb::Types::CloudExadataInfrastructureSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about an Exadata infrastructure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activated_storage_countInteger

The number of storage servers requested for the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#additional_storage_countInteger

The number of storage servers requested for the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The name of the Availability Zone (AZ) where the Exadata infrastructure is located.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The AZ ID of the AZ where the Exadata infrastructure is located.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#available_storage_size_in_g_bsInteger

The amount of available storage, in gigabytes (GB), for the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_exadata_infrastructure_arnString

The Amazon Resource Name (ARN) for the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_exadata_infrastructure_idString

The unique identifier for the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#compute_countInteger

The number of database servers for the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#compute_modelString

The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#cpu_countInteger

The total number of CPU cores that are allocated to the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the Exadata infrastructure was created.

Returns:

  • (Time)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#customer_contacts_to_send_to_ociArray<Types::CustomerContact>

The email addresses of contacts to receive notification from Oracle about maintenance updates for the Exadata infrastructure.

Returns:



2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#data_storage_size_in_t_bsFloat

The size of the Exadata infrastructure’s data disk group, in terabytes (TB).

Returns:

  • (Float)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#database_server_typeString

The database server model type of the Exadata infrastructure. For the list of valid model names, use the ‘ListDbSystemShapes` operation.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#db_node_storage_size_in_g_bsInteger

The size of the Exadata infrastructure’s local node storage, in gigabytes (GB).

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#db_server_versionString

The software version of the database servers on the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The user-friendly name for the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#last_maintenance_run_idString

The Oracle Cloud Identifier (OCID) of the last maintenance run for the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_windowTypes::MaintenanceWindow

The scheduling details for the maintenance window. Patching and system updates take place during the maintenance window.



2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#max_cpu_countInteger

The total number of CPU cores available on the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#max_data_storage_in_t_bsFloat

The total amount of data disk group storage, in terabytes (TB), that’s available on the Exadata infrastructure.

Returns:

  • (Float)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#max_db_node_storage_size_in_g_bsInteger

The total amount of local node storage, in gigabytes (GB), that’s available on the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#max_memory_in_g_bsInteger

The total amount of memory, in gigabytes (GB), that’s available on the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#memory_size_in_g_bsInteger

The amount of memory, in gigabytes (GB), that’s allocated on the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_db_server_versionString

The monthly software version of the database servers (dom0) installed on the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_storage_server_versionString

The monthly software version of the storage servers installed on the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#next_maintenance_run_idString

The OCID of the next maintenance run for the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#oci_resource_anchor_nameString

The name of the OCI resource anchor for the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#oci_urlString

The HTTPS link to the Exadata infrastructure in OCI.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#ocidString

The OCID of the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#percent_progressFloat

The amount of progress made on the current operation on the Exadata infrastructure, expressed as a percentage.

Returns:

  • (Float)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#shapeString

The model name of the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Additional information about the status of the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#storage_countInteger

The number of storage servers that are activated for the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#storage_server_typeString

The storage server model type of the Exadata infrastructure. For the list of valid model names, use the ‘ListDbSystemShapes` operation.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#storage_server_versionString

The software version of the storage servers on the Exadata infrastructure.

Returns:

  • (String)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end

#total_storage_size_in_g_bsInteger

The total amount of storage, in gigabytes (GB), on the the Exadata infrastructure.

Returns:

  • (Integer)


2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-odb/types.rb', line 2891

class CloudExadataInfrastructureSummary < Struct.new(
  :cloud_exadata_infrastructure_id,
  :display_name,
  :status,
  :status_reason,
  :cloud_exadata_infrastructure_arn,
  :activated_storage_count,
  :additional_storage_count,
  :available_storage_size_in_g_bs,
  :availability_zone,
  :availability_zone_id,
  :compute_count,
  :cpu_count,
  :customer_contacts_to_send_to_oci,
  :data_storage_size_in_t_bs,
  :db_node_storage_size_in_g_bs,
  :db_server_version,
  :last_maintenance_run_id,
  :maintenance_window,
  :max_cpu_count,
  :max_data_storage_in_t_bs,
  :max_db_node_storage_size_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :monthly_db_server_version,
  :monthly_storage_server_version,
  :next_maintenance_run_id,
  :oci_resource_anchor_name,
  :oci_url,
  :ocid,
  :shape,
  :storage_count,
  :storage_server_version,
  :created_at,
  :total_storage_size_in_g_bs,
  :percent_progress,
  :database_server_type,
  :storage_server_type,
  :compute_model)
  SENSITIVE = []
  include Aws::Structure
end