Class: Aws::Odb::Types::CreateAutonomousDatabaseWalletInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:password]

Instance Attribute Summary collapse

Instance Attribute Details

#autonomous_database_idString

The unique identifier of the Autonomous Database to create a wallet for.

Returns:

  • (String)


3864
3865
3866
3867
3868
3869
3870
3871
# File 'lib/aws-sdk-odb/types.rb', line 3864

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#client_tokenString

A client-provided token to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3864
3865
3866
3867
3868
3869
3870
3871
# File 'lib/aws-sdk-odb/types.rb', line 3864

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#passwordString

The password to encrypt the keys inside the wallet.

Returns:

  • (String)


3864
3865
3866
3867
3868
3869
3870
3871
# File 'lib/aws-sdk-odb/types.rb', line 3864

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end

#wallet_typeString

The type of wallet to create, either a regional wallet or an instance wallet.

Returns:

  • (String)


3864
3865
3866
3867
3868
3869
3870
3871
# File 'lib/aws-sdk-odb/types.rb', line 3864

class CreateAutonomousDatabaseWalletInput < Struct.new(
  :autonomous_database_id,
  :wallet_type,
  :password,
  :client_token)
  SENSITIVE = [:password]
  include Aws::Structure
end