Class: Aws::Odb::Types::CreateExadbVmClusterInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateExadbVmClusterInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_name ⇒ String
A name for the Grid Infrastructure cluster.
-
#data_collection_options ⇒ Types::DataCollectionOptions
The set of preferences for the various diagnostic collection options for the Exascale VM cluster.
-
#display_name ⇒ String
A user-friendly name for the Exascale VM cluster.
-
#enabled_ecpu_count ⇒ Integer
The number of ECPUs to enable for the Exascale VM cluster.
-
#exascale_db_storage_vault_id ⇒ String
The unique identifier of the Exascale storage vault for this Exascale VM cluster.
-
#grid_image_id ⇒ String
The Grid Infrastructure software image ID for the Exascale VM cluster.
-
#hostname ⇒ String
The host name for the Exascale VM cluster.
-
#license_model ⇒ String
The Oracle license model to apply to the Exascale VM cluster.
-
#node_count ⇒ Integer
The number of nodes in the Exascale VM cluster.
-
#odb_network_id ⇒ String
The unique identifier of the ODB network for the Exascale VM cluster.
-
#scan_listener_port_tcp ⇒ Integer
The port number for TCP connections to the single client access name (SCAN) listener.
-
#scan_listener_port_tcp_ssl ⇒ Integer
The port number for TCP connections with SSL to the single client access name (SCAN) listener.
-
#shape ⇒ String
The shape of the Exascale VM cluster.
-
#shape_attribute ⇒ String
The shape attribute for the Exascale VM cluster.
-
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the Exascale VM cluster.
-
#system_version ⇒ String
The version of the operating system of the image for the Exascale VM cluster.
-
#tags ⇒ Hash<String,String>
The list of resource tags to apply to the Exascale VM cluster.
-
#time_zone ⇒ String
The time zone for the Exascale VM cluster.
-
#total_ecpu_count ⇒ Integer
The total number of ECPUs for the Exascale VM cluster.
-
#vm_file_system_storage_total_size_in_g_bs ⇒ Integer
The total amount of file system storage, in gigabytes (GB), for the Exascale VM cluster.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, the Amazon Web Services SDK automatically generates one and uses it for the request to ensure idempotency. The client token is valid for up to 24 hours after it's first used.
A suitable default value is auto-generated. You should normally not need to pass this option.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#cluster_name ⇒ String
A name for the Grid Infrastructure cluster. The name isn't case sensitive.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#data_collection_options ⇒ Types::DataCollectionOptions
The set of preferences for the various diagnostic collection options for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
A user-friendly name for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#enabled_ecpu_count ⇒ Integer
The number of ECPUs to enable for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#exascale_db_storage_vault_id ⇒ String
The unique identifier of the Exascale storage vault for this Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#grid_image_id ⇒ String
The Grid Infrastructure software image ID for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#hostname ⇒ String
The host name for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#license_model ⇒ String
The Oracle license model to apply to the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#node_count ⇒ Integer
The number of nodes in the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#odb_network_id ⇒ String
The unique identifier of the ODB network for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#scan_listener_port_tcp ⇒ Integer
The port number for TCP connections to the single client access name (SCAN) listener.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#scan_listener_port_tcp_ssl ⇒ Integer
The port number for TCP connections with SSL to the single client access name (SCAN) listener.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#shape ⇒ String
The shape of the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#shape_attribute ⇒ String
The shape attribute for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#system_version ⇒ String
The version of the operating system of the image for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of resource tags to apply to the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The time zone for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#total_ecpu_count ⇒ Integer
The total number of ECPUs for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |
#vm_file_system_storage_total_size_in_g_bs ⇒ Integer
The total amount of file system storage, in gigabytes (GB), for the Exascale VM cluster.
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-odb/types.rb', line 4588 class CreateExadbVmClusterInput < Struct.new( :display_name, :enabled_ecpu_count, :exascale_db_storage_vault_id, :grid_image_id, :hostname, :node_count, :odb_network_id, :shape, :ssh_public_keys, :total_ecpu_count, :vm_file_system_storage_total_size_in_g_bs, :cluster_name, :data_collection_options, :license_model, :scan_listener_port_tcp, :scan_listener_port_tcp_ssl, :shape_attribute, :system_version, :tags, :time_zone, :client_token) SENSITIVE = [] include Aws::Structure end |