Class: Aws::Odb::Types::CreateOdbNetworkInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CreateOdbNetworkInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Amazon Web Services Availability Zone (AZ) where the ODB network is located.
-
#availability_zone_id ⇒ String
The AZ ID of the AZ where the ODB network is located.
-
#backup_subnet_cidr ⇒ String
The CIDR range of the backup subnet for the ODB network.
-
#client_subnet_cidr ⇒ String
The CIDR range of the client subnet for the ODB network.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#custom_domain_name ⇒ String
The domain name to use for the resources in the ODB network.
-
#default_dns_prefix ⇒ String
The DNS prefix to the default DNS domain name.
-
#display_name ⇒ String
A user-friendly name for the ODB network.
-
#s3_access ⇒ String
Specifies the configuration for Amazon S3 access from the ODB network.
-
#s3_policy_document ⇒ String
Specifies the endpoint policy for Amazon S3 access from the ODB network.
-
#tags ⇒ Hash<String,String>
The list of resource tags to apply to the ODB network.
-
#zero_etl_access ⇒ String
Specifies the configuration for Zero-ETL access from the ODB network.
Instance Attribute Details
#availability_zone ⇒ String
The Amazon Web Services Availability Zone (AZ) where the ODB network is located.
This operation requires that you specify a value for either ‘availabilityZone` or `availabilityZoneId`.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The AZ ID of the AZ where the ODB network is located.
This operation requires that you specify a value for either ‘availabilityZone` or `availabilityZoneId`.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#backup_subnet_cidr ⇒ String
The CIDR range of the backup subnet for the ODB network.
Constraints:
-
Must not overlap with the CIDR range of the client subnet.
-
Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network.
-
Must not use the following CIDR ranges that are reserved by OCI:
-
‘100.106.0.0/16` and `100.107.0.0/16`
-
‘169.254.0.0/16`
-
‘224.0.0.0 - 239.255.255.255`
-
‘240.0.0.0 - 255.255.255.255`
-
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#client_subnet_cidr ⇒ String
The CIDR range of the client subnet for the ODB network.
Constraints:
-
Must not overlap with the CIDR range of the backup subnet.
-
Must not overlap with the CIDR ranges of the VPCs that are connected to the ODB network.
-
Must not use the following CIDR ranges that are reserved by OCI:
-
‘100.106.0.0/16` and `100.107.0.0/16`
-
‘169.254.0.0/16`
-
‘224.0.0.0 - 239.255.255.255`
-
‘240.0.0.0 - 255.255.255.255`
-
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency. The client token is valid for up to 24 hours after it’s first used.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The domain name to use for the resources in the ODB network.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#default_dns_prefix ⇒ String
The DNS prefix to the default DNS domain name. The default DNS domain name is oraclevcn.com.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
A user-friendly name for the ODB network.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#s3_access ⇒ String
Specifies the configuration for Amazon S3 access from the ODB network.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#s3_policy_document ⇒ String
Specifies the endpoint policy for Amazon S3 access from the ODB network.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of resource tags to apply to the ODB network.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |
#zero_etl_access ⇒ String
Specifies the configuration for Zero-ETL access from the ODB network.
2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-odb/types.rb', line 2259 class CreateOdbNetworkInput < Struct.new( :display_name, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :client_token, :s3_access, :zero_etl_access, :s3_policy_document, :tags) SENSITIVE = [] include Aws::Structure end |