Class: Aws::Odb::Types::CustomerManagedAwsSecretConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The configuration of a customer-managed Amazon Web Services Secrets Manager secret used to supply a password.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#external_id_typeString

The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.

Returns:

  • (String)


4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-odb/types.rb', line 4806

class CustomerManagedAwsSecretConfiguration < Struct.new(
  :iam_role_arn,
  :secret_id,
  :external_id_type)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.

Returns:

  • (String)


4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-odb/types.rb', line 4806

class CustomerManagedAwsSecretConfiguration < Struct.new(
  :iam_role_arn,
  :secret_id,
  :external_id_type)
  SENSITIVE = []
  include Aws::Structure
end

#secret_idString

The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.

Returns:

  • (String)


4806
4807
4808
4809
4810
4811
4812
# File 'lib/aws-sdk-odb/types.rb', line 4806

class CustomerManagedAwsSecretConfiguration < Struct.new(
  :iam_role_arn,
  :secret_id,
  :external_id_type)
  SENSITIVE = []
  include Aws::Structure
end