Class: Aws::Odb::Types::CustomerManagedAwsSecretConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CustomerManagedAwsSecretConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The configuration of a customer-managed Amazon Web Services Secrets Manager secret used to supply a password.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#external_id_type ⇒ String
The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.
-
#secret_id ⇒ String
The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.
Instance Attribute Details
#external_id_type ⇒ String
The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.
4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-odb/types.rb', line 4806 class CustomerManagedAwsSecretConfiguration < Struct.new( :iam_role_arn, :secret_id, :external_id_type) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.
4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-odb/types.rb', line 4806 class CustomerManagedAwsSecretConfiguration < Struct.new( :iam_role_arn, :secret_id, :external_id_type) SENSITIVE = [] include Aws::Structure end |
#secret_id ⇒ String
The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.
4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/aws-sdk-odb/types.rb', line 4806 class CustomerManagedAwsSecretConfiguration < Struct.new( :iam_role_arn, :secret_id, :external_id_type) SENSITIVE = [] include Aws::Structure end |