Class: Aws::Odb::Types::CustomerManagedAwsSecretConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::CustomerManagedAwsSecretConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The input configuration for a customer-managed Amazon Web Services Secrets Manager secret used to supply a password.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#external_id_type ⇒ String
The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.
-
#secret_id ⇒ String
The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.
Instance Attribute Details
#external_id_type ⇒ String
The type of Oracle Cloud Identifier (OCID) used as the external ID when assuming the IAM role.
The valid values depend on the operation. For the
CreateAutonomousDatabase operation, only compartment_ocid and
tenant_ocid are allowed. For the UpdateAutonomousDatabase and
CreateAutonomousDatabaseWallet operations, database_ocid,
compartment_ocid, and tenant_ocid are all allowed.
4841 4842 4843 4844 4845 4846 4847 |
# File 'lib/aws-sdk-odb/types.rb', line 4841 class CustomerManagedAwsSecretConfigurationInput < Struct.new( :secret_id, :iam_role_arn, :external_id_type) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that OCI assumes to retrieve the secret value.
4841 4842 4843 4844 4845 4846 4847 |
# File 'lib/aws-sdk-odb/types.rb', line 4841 class CustomerManagedAwsSecretConfigurationInput < Struct.new( :secret_id, :iam_role_arn, :external_id_type) SENSITIVE = [] include Aws::Structure end |
#secret_id ⇒ String
The identifier or ARN of the Amazon Web Services Secrets Manager secret that contains the password.
4841 4842 4843 4844 4845 4846 4847 |
# File 'lib/aws-sdk-odb/types.rb', line 4841 class CustomerManagedAwsSecretConfigurationInput < Struct.new( :secret_id, :iam_role_arn, :external_id_type) SENSITIVE = [] include Aws::Structure end |