Class: Aws::Odb::Types::DatabaseCloneConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DatabaseCloneConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The configuration for creating an Autonomous Database as a clone of an existing database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clone_type ⇒ String
The type of clone to create, either a full clone, a metadata clone, or a partial clone.
-
#source_autonomous_database_id ⇒ String
The unique identifier of the source Autonomous Database to clone.
Instance Attribute Details
#clone_type ⇒ String
The type of clone to create, either a full clone, a metadata clone, or a partial clone.
4715 4716 4717 4718 4719 4720 |
# File 'lib/aws-sdk-odb/types.rb', line 4715 class DatabaseCloneConfiguration < Struct.new( :source_autonomous_database_id, :clone_type) SENSITIVE = [] include Aws::Structure end |
#source_autonomous_database_id ⇒ String
The unique identifier of the source Autonomous Database to clone.
4715 4716 4717 4718 4719 4720 |
# File 'lib/aws-sdk-odb/types.rb', line 4715 class DatabaseCloneConfiguration < Struct.new( :source_autonomous_database_id, :clone_type) SENSITIVE = [] include Aws::Structure end |