Class: Aws::Odb::Types::DatabaseConnectionStringProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DatabaseConnectionStringProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
A connection string profile for an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_group ⇒ String
The consumer group associated with the connection string profile.
-
#display_name ⇒ String
The user-friendly name of the connection string profile.
-
#host_format ⇒ String
The host name format used in the connection string.
-
#is_regional ⇒ Boolean
Indicates whether the connection string profile is regional.
-
#protocol ⇒ String
The protocol used by the connection string profile.
-
#session_mode ⇒ String
The session mode of the connection string profile.
-
#syntax_format ⇒ String
The syntax format of the connection string profile.
-
#tls_authentication ⇒ String
The TLS authentication method used by the connection string profile.
-
#value ⇒ String
The connection string value of the profile.
Instance Attribute Details
#consumer_group ⇒ String
The consumer group associated with the connection string profile.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the connection string profile.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#host_format ⇒ String
The host name format used in the connection string.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#is_regional ⇒ Boolean
Indicates whether the connection string profile is regional.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol used by the connection string profile.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#session_mode ⇒ String
The session mode of the connection string profile.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#syntax_format ⇒ String
The syntax format of the connection string profile.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#tls_authentication ⇒ String
The TLS authentication method used by the connection string profile.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The connection string value of the profile.
4762 4763 4764 4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/aws-sdk-odb/types.rb', line 4762 class DatabaseConnectionStringProfile < Struct.new( :consumer_group, :display_name, :host_format, :is_regional, :protocol, :session_mode, :syntax_format, :tls_authentication, :value) SENSITIVE = [] include Aws::Structure end |