Class: Aws::Odb::Types::DbNode
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DbNode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Information about a DB node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_details ⇒ String
Additional information about the planned maintenance.
-
#backup_ip_id ⇒ String
The Oracle Cloud ID (OCID) of the backup IP address that's associated with the DB node.
-
#backup_vnic_2_id ⇒ String
The OCID of the second backup VNIC.
-
#backup_vnic_id ⇒ String
The OCID of the backup VNIC.
-
#cpu_core_count ⇒ Integer
Number of CPU cores enabled on the DB node.
-
#created_at ⇒ Time
The date and time when the DB node was created.
-
#db_node_arn ⇒ String
The Amazon Resource Name (ARN) of the DB node.
-
#db_node_id ⇒ String
The unique identifier of the DB node.
-
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), that's allocated on the DB node.
-
#db_server_id ⇒ String
The unique identifier of the Db server that is associated with the DB node.
-
#db_system_id ⇒ String
The OCID of the DB system.
-
#fault_domain ⇒ String
The name of the fault domain the instance is contained in.
-
#floating_ip_address ⇒ String
The floating IP address assigned to the DB node.
-
#host_ip_id ⇒ String
The OCID of the host IP address that's associated with the DB node.
-
#hostname ⇒ String
The host name for the DB node.
-
#maintenance_type ⇒ String
The type of database node maintenance.
-
#memory_size_in_g_bs ⇒ Integer
The allocated memory in GBs on the DB node.
-
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the DB node.
-
#ocid ⇒ String
The OCID of the DB node.
-
#private_ip_address ⇒ String
The private IP address assigned to the DB node.
-
#software_storage_size_in_gb ⇒ Integer
The size (in GB) of the block storage volume allocation for the DB system.
-
#status ⇒ String
The current status of the DB node.
-
#status_reason ⇒ String
Additional information about the status of the DB node.
-
#time_maintenance_window_end ⇒ String
End date and time of maintenance window.
-
#time_maintenance_window_start ⇒ String
Start date and time of maintenance window.
-
#total_cpu_core_count ⇒ Integer
The total number of CPU cores reserved on the DB node.
-
#vnic2_id ⇒ String
The OCID of the second VNIC.
-
#vnic_id ⇒ String
The OCID of the VNIC.
Instance Attribute Details
#additional_details ⇒ String
Additional information about the planned maintenance.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#backup_ip_id ⇒ String
The Oracle Cloud ID (OCID) of the backup IP address that's associated with the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#backup_vnic_2_id ⇒ String
The OCID of the second backup VNIC.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#backup_vnic_id ⇒ String
The OCID of the backup VNIC.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#cpu_core_count ⇒ Integer
Number of CPU cores enabled on the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the DB node was created.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#db_node_arn ⇒ String
The Amazon Resource Name (ARN) of the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#db_node_id ⇒ String
The unique identifier of the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), that's allocated on the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#db_server_id ⇒ String
The unique identifier of the Db server that is associated with the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#db_system_id ⇒ String
The OCID of the DB system.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#fault_domain ⇒ String
The name of the fault domain the instance is contained in.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#floating_ip_address ⇒ String
The floating IP address assigned to the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#host_ip_id ⇒ String
The OCID of the host IP address that's associated with the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#hostname ⇒ String
The host name for the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#maintenance_type ⇒ String
The type of database node maintenance. Either
VMDB_REBOOT_MIGRATION or EXADBXS_REBOOT_MIGRATION.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_g_bs ⇒ Integer
The allocated memory in GBs on the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The OCID of the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The private IP address assigned to the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#software_storage_size_in_gb ⇒ Integer
The size (in GB) of the block storage volume allocation for the DB system.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#time_maintenance_window_end ⇒ String
End date and time of maintenance window.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#time_maintenance_window_start ⇒ String
Start date and time of maintenance window.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#total_cpu_core_count ⇒ Integer
The total number of CPU cores reserved on the DB node.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#vnic2_id ⇒ String
The OCID of the second VNIC.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |
#vnic_id ⇒ String
The OCID of the VNIC.
5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 5538 5539 5540 5541 |
# File 'lib/aws-sdk-odb/types.rb', line 5510 class DbNode < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id, :private_ip_address, :floating_ip_address) SENSITIVE = [] include Aws::Structure end |