Class: Aws::Odb::Types::DbNodeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DbNodeSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Information about a DB node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_details ⇒ String
Additional information about the planned maintenance.
-
#backup_ip_id ⇒ String
The Oracle Cloud ID (OCID) of the backup IP address that’s associated with the DB node.
-
#backup_vnic_2_id ⇒ String
The OCID of the second backup virtual network interface card (VNIC) for the DB node.
-
#backup_vnic_id ⇒ String
The OCID of the backup VNIC for the DB node.
-
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the DB node.
-
#created_at ⇒ Time
The date and time when the DB node was created.
-
#db_node_arn ⇒ String
The Amazon Resource Name (ARN) of the DB node.
-
#db_node_id ⇒ String
The unique identifier of the DB node.
-
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), that’s allocated on the DB node.
-
#db_server_id ⇒ String
The unique identifier of the database server that’s associated with the DB node.
-
#db_system_id ⇒ String
The OCID of the DB system.
-
#fault_domain ⇒ String
The name of the fault domain where the DB node is located.
-
#host_ip_id ⇒ String
The OCID of the host IP address that’s associated with the DB node.
-
#hostname ⇒ String
The host name for the DB node.
-
#maintenance_type ⇒ String
The type of maintenance the DB node.
-
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), that allocated on the DB node.
-
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the DB node.
-
#ocid ⇒ String
The OCID of the DB node.
-
#software_storage_size_in_gb ⇒ Integer
The size of the block storage volume, in gigabytes (GB), that’s allocated for the DB system.
-
#status ⇒ String
The current status of the DB node.
-
#status_reason ⇒ String
Additional information about the status of the DB node.
-
#time_maintenance_window_end ⇒ String
The end date and time of the maintenance window.
-
#time_maintenance_window_start ⇒ String
The start date and time of the maintenance window.
-
#total_cpu_core_count ⇒ Integer
The total number of CPU cores reserved on the DB node.
-
#vnic2_id ⇒ String
The OCID of the second VNIC.
-
#vnic_id ⇒ String
The OCID of the VNIC.
Instance Attribute Details
#additional_details ⇒ String
Additional information about the planned maintenance.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#backup_ip_id ⇒ String
The Oracle Cloud ID (OCID) of the backup IP address that’s associated with the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#backup_vnic_2_id ⇒ String
The OCID of the second backup virtual network interface card (VNIC) for the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#backup_vnic_id ⇒ String
The OCID of the backup VNIC for the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the DB node was created.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#db_node_arn ⇒ String
The Amazon Resource Name (ARN) of the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#db_node_id ⇒ String
The unique identifier of the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), that’s allocated on the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#db_server_id ⇒ String
The unique identifier of the database server that’s associated with the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#db_system_id ⇒ String
The OCID of the DB system.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#fault_domain ⇒ String
The name of the fault domain where the DB node is located.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#host_ip_id ⇒ String
The OCID of the host IP address that’s associated with the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#hostname ⇒ String
The host name for the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#maintenance_type ⇒ String
The type of maintenance the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), that allocated on the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The OCID of the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#software_storage_size_in_gb ⇒ Integer
The size of the block storage volume, in gigabytes (GB), that’s allocated for the DB system. This attribute applies only for virtual machine DB systems.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#time_maintenance_window_end ⇒ String
The end date and time of the maintenance window.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#time_maintenance_window_start ⇒ String
The start date and time of the maintenance window.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#total_cpu_core_count ⇒ Integer
The total number of CPU cores reserved on the DB node.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#vnic2_id ⇒ String
The OCID of the second VNIC.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |
#vnic_id ⇒ String
The OCID of the VNIC.
5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-odb/types.rb', line 5178 class DbNodeSummary < Struct.new( :db_node_id, :db_node_arn, :status, :status_reason, :additional_details, :backup_ip_id, :backup_vnic_2_id, :backup_vnic_id, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_id, :db_system_id, :fault_domain, :host_ip_id, :hostname, :ocid, :oci_resource_anchor_name, :maintenance_type, :memory_size_in_g_bs, :software_storage_size_in_gb, :created_at, :time_maintenance_window_end, :time_maintenance_window_start, :total_cpu_core_count, :vnic2_id, :vnic_id) SENSITIVE = [] include Aws::Structure end |