Class: Aws::Odb::Types::DbServer
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DbServer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Information about a database server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_virtual_machine_ids ⇒ Array<String>
The list of unique identifiers for the Autonomous VMs associated with this database server.
-
#autonomous_vm_cluster_ids ⇒ Array<String>
The list of identifiers for the Autonomous VM clusters associated with this database server.
-
#compute_model ⇒ String
The compute model of the database server (ECPU or OCPU).
-
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the database server.
-
#created_at ⇒ Time
The date and time when the database server was created.
-
#db_node_storage_size_in_g_bs ⇒ Integer
The allocated local node storage in GBs on the database server.
-
#db_server_id ⇒ String
The unique identifier for the database server.
-
#db_server_patching_details ⇒ Types::DbServerPatchingDetails
The scheduling details for the quarterly maintenance window.
-
#display_name ⇒ String
The user-friendly name of the database server.
-
#exadata_infrastructure_id ⇒ String
The ID of the Exadata infrastructure the database server belongs to.
-
#max_cpu_count ⇒ Integer
The total number of CPU cores available.
-
#max_db_node_storage_in_g_bs ⇒ Integer
The total local node storage available in GBs.
-
#max_memory_in_g_bs ⇒ Integer
The total memory available in GBs.
-
#memory_size_in_g_bs ⇒ Integer
The allocated memory in GBs on the database server.
-
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the database server.
-
#ocid ⇒ String
The OCID of the database server.
-
#shape ⇒ String
The shape of the database server.
-
#status ⇒ String
The current status of the database server.
-
#status_reason ⇒ String
Additional information about the current status of the database server.
-
#vm_cluster_ids ⇒ Array<String>
The OCID of the VM clusters that are associated with the database server.
Instance Attribute Details
#autonomous_virtual_machine_ids ⇒ Array<String>
The list of unique identifiers for the Autonomous VMs associated with this database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#autonomous_vm_cluster_ids ⇒ Array<String>
The list of identifiers for the Autonomous VM clusters associated with this database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#compute_model ⇒ String
The compute model of the database server (ECPU or OCPU).
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the database server was created.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#db_node_storage_size_in_g_bs ⇒ Integer
The allocated local node storage in GBs on the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#db_server_id ⇒ String
The unique identifier for the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#db_server_patching_details ⇒ Types::DbServerPatchingDetails
The scheduling details for the quarterly maintenance window. Patching and system updates take place during the maintenance window.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#exadata_infrastructure_id ⇒ String
The ID of the Exadata infrastructure the database server belongs to.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#max_cpu_count ⇒ Integer
The total number of CPU cores available.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#max_db_node_storage_in_g_bs ⇒ Integer
The total local node storage available in GBs.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#max_memory_in_g_bs ⇒ Integer
The total memory available in GBs.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_g_bs ⇒ Integer
The allocated memory in GBs on the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The OCID of the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#shape ⇒ String
The shape of the database server. The shape determines the amount of CPU, storage, and memory resources available.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the current status of the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#vm_cluster_ids ⇒ Array<String>
The OCID of the VM clusters that are associated with the database server.
5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-odb/types.rb', line 5469 class DbServer < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |