Class: Aws::Odb::Types::DbServerSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DbServerSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Information about a database server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_virtual_machine_ids ⇒ Array<String>
A list of unique identifiers for the Autonomous VMs.
-
#autonomous_vm_cluster_ids ⇒ Array<String>
A list of identifiers for the Autonomous VM clusters.
-
#compute_model ⇒ String
The OCI model compute model used when you create or clone an instance: ECPU or OCPU.
-
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the database server.
-
#created_at ⇒ Time
The date and time when the database server was created.
-
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), that's allocated on the database server.
-
#db_server_id ⇒ String
The unique identifier of the database server.
-
#db_server_patching_details ⇒ Types::DbServerPatchingDetails
The scheduling details for the quarterly maintenance window.
-
#display_name ⇒ String
The user-friendly name of the database server.
-
#exadata_infrastructure_id ⇒ String
The ID of the Exadata infrastructure that hosts the database server.
-
#max_cpu_count ⇒ Integer
The total number of CPU cores available on the database server.
-
#max_db_node_storage_in_g_bs ⇒ Integer
The total amount of local node storage, in gigabytes (GB), that's available on the database server.
-
#max_memory_in_g_bs ⇒ Integer
The total amount of memory, in gigabytes (GB), that's available on the database server.
-
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), that's allocated on the database server.
-
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the database server.
-
#ocid ⇒ String
The OCID of the database server.
-
#shape ⇒ String
The hardware system model of the Exadata infrastructure that the database server is hosted on.
-
#status ⇒ String
The current status of the database server.
-
#status_reason ⇒ String
Additional information about the status of the database server.
-
#vm_cluster_ids ⇒ Array<String>
The IDs of the VM clusters that are associated with the database server.
Instance Attribute Details
#autonomous_virtual_machine_ids ⇒ Array<String>
A list of unique identifiers for the Autonomous VMs.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#autonomous_vm_cluster_ids ⇒ Array<String>
A list of identifiers for the Autonomous VM clusters.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#compute_model ⇒ String
The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the database server was created.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#db_node_storage_size_in_g_bs ⇒ Integer
The amount of local node storage, in gigabytes (GB), that's allocated on the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#db_server_id ⇒ String
The unique identifier of the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#db_server_patching_details ⇒ Types::DbServerPatchingDetails
The scheduling details for the quarterly maintenance window. Patching and system updates take place during the maintenance window.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the database server. The name doesn't need to be unique.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#exadata_infrastructure_id ⇒ String
The ID of the Exadata infrastructure that hosts the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#max_cpu_count ⇒ Integer
The total number of CPU cores available on the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#max_db_node_storage_in_g_bs ⇒ Integer
The total amount of local node storage, in gigabytes (GB), that's available on the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#max_memory_in_g_bs ⇒ Integer
The total amount of memory, in gigabytes (GB), that's available on the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#memory_size_in_g_bs ⇒ Integer
The amount of memory, in gigabytes (GB), that's allocated on the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor for the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#ocid ⇒ String
The OCID of the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#shape ⇒ String
The hardware system model of the Exadata infrastructure that the database server is hosted on. The shape determines the amount of CPU, storage, and memory resources available.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the status of the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |
#vm_cluster_ids ⇒ Array<String>
The IDs of the VM clusters that are associated with the database server.
5624 5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 |
# File 'lib/aws-sdk-odb/types.rb', line 5624 class DbServerSummary < Struct.new( :db_server_id, :status, :status_reason, :cpu_core_count, :db_node_storage_size_in_g_bs, :db_server_patching_details, :display_name, :exadata_infrastructure_id, :ocid, :oci_resource_anchor_name, :max_cpu_count, :max_db_node_storage_in_g_bs, :max_memory_in_g_bs, :memory_size_in_g_bs, :shape, :created_at, :vm_cluster_ids, :compute_model, :autonomous_vm_cluster_ids, :autonomous_virtual_machine_ids) SENSITIVE = [] include Aws::Structure end |