Class: Aws::Odb::Types::DbServerSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about a database server.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#autonomous_virtual_machine_idsArray<String>

A list of unique identifiers for the Autonomous VMs.

Returns:

  • (Array<String>)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#autonomous_vm_cluster_idsArray<String>

A list of identifiers for the Autonomous VM clusters.

Returns:

  • (Array<String>)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#compute_modelString

The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#cpu_core_countInteger

The number of CPU cores enabled on the database server.

Returns:

  • (Integer)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the database server was created.

Returns:

  • (Time)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#db_node_storage_size_in_g_bsInteger

The amount of local node storage, in gigabytes (GB), that’s allocated on the database server.

Returns:

  • (Integer)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#db_server_idString

The unique identifier of the database server.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#db_server_patching_detailsTypes::DbServerPatchingDetails

The scheduling details for the quarterly maintenance window. Patching and system updates take place during the maintenance window.



5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The user-friendly name of the database server. The name doesn’t need to be unique.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#exadata_infrastructure_idString

The ID of the Exadata infrastructure that hosts the database server.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_cpu_countInteger

The total number of CPU cores available on the database server.

Returns:

  • (Integer)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_db_node_storage_in_g_bsInteger

The total amount of local node storage, in gigabytes (GB), that’s available on the database server.

Returns:

  • (Integer)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#max_memory_in_g_bsInteger

The total amount of memory, in gigabytes (GB), that’s available on the database server.

Returns:

  • (Integer)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#memory_size_in_g_bsInteger

The amount of memory, in gigabytes (GB), that’s allocated on the database server.

Returns:

  • (Integer)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#oci_resource_anchor_nameString

The name of the OCI resource anchor for the database server.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ocidString

The OCID of the database server.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#shapeString

The hardware system model of the Exadata infrastructure that the database server is hosted on. The shape determines the amount of CPU, storage, and memory resources available.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the database server.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Additional information about the status of the database server.

Returns:

  • (String)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vm_cluster_idsArray<String>

The IDs of the VM clusters that are associated with the database server.

Returns:

  • (Array<String>)


5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
# File 'lib/aws-sdk-odb/types.rb', line 5455

class DbServerSummary < Struct.new(
  :db_server_id,
  :status,
  :status_reason,
  :cpu_core_count,
  :db_node_storage_size_in_g_bs,
  :db_server_patching_details,
  :display_name,
  :exadata_infrastructure_id,
  :ocid,
  :oci_resource_anchor_name,
  :max_cpu_count,
  :max_db_node_storage_in_g_bs,
  :max_memory_in_g_bs,
  :memory_size_in_g_bs,
  :shape,
  :created_at,
  :vm_cluster_ids,
  :compute_model,
  :autonomous_vm_cluster_ids,
  :autonomous_virtual_machine_ids)
  SENSITIVE = []
  include Aws::Structure
end