Class: Aws::Odb::Types::DisassociateIamRoleFromResourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DisassociateIamRoleFromResourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_integration ⇒ String
The Amazon Web Services integration configuration settings for the Amazon Web Services Identity and Access Management (IAM) service role disassociation.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) service role to disassociate from the resource.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target resource to disassociate from the Amazon Web Services Identity and Access Management (IAM) service role.
Instance Attribute Details
#aws_integration ⇒ String
The Amazon Web Services integration configuration settings for the Amazon Web Services Identity and Access Management (IAM) service role disassociation.
5942 5943 5944 5945 5946 5947 5948 |
# File 'lib/aws-sdk-odb/types.rb', line 5942 class DisassociateIamRoleFromResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) service role to disassociate from the resource.
5942 5943 5944 5945 5946 5947 5948 |
# File 'lib/aws-sdk-odb/types.rb', line 5942 class DisassociateIamRoleFromResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target resource to disassociate from the Amazon Web Services Identity and Access Management (IAM) service role.
5942 5943 5944 5945 5946 5947 5948 |
# File 'lib/aws-sdk-odb/types.rb', line 5942 class DisassociateIamRoleFromResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |