Class: Aws::Odb::Types::DisassociateIamRoleFromResourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::DisassociateIamRoleFromResourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_integration ⇒ String
The Amazon Web Services integration configuration settings for the Amazon Web Services Identity and Access Management (IAM) service role disassociation.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) service role to disassociate from the resource.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target resource to disassociate from the Amazon Web Services Identity and Access Management (IAM) service role.
Instance Attribute Details
#aws_integration ⇒ String
The Amazon Web Services integration configuration settings for the Amazon Web Services Identity and Access Management (IAM) service role disassociation.
5773 5774 5775 5776 5777 5778 5779 |
# File 'lib/aws-sdk-odb/types.rb', line 5773 class DisassociateIamRoleFromResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) service role to disassociate from the resource.
5773 5774 5775 5776 5777 5778 5779 |
# File 'lib/aws-sdk-odb/types.rb', line 5773 class DisassociateIamRoleFromResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target resource to disassociate from the Amazon Web Services Identity and Access Management (IAM) service role.
5773 5774 5775 5776 5777 5778 5779 |
# File 'lib/aws-sdk-odb/types.rb', line 5773 class DisassociateIamRoleFromResourceInput < Struct.new( :iam_role_arn, :aws_integration, :resource_arn) SENSITIVE = [] include Aws::Structure end |