Class: Aws::Odb::Types::DisasterRecoveryConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The disaster recovery configuration for an Autonomous Database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disaster_recovery_typeString

The type of disaster recovery configured for the Autonomous Database.

Returns:

  • (String)


5808
5809
5810
5811
5812
5813
5814
5815
# File 'lib/aws-sdk-odb/types.rb', line 5808

class DisasterRecoveryConfiguration < Struct.new(
  :disaster_recovery_type,
  :is_replicate_automatic_backups,
  :is_snapshot_standby,
  :time_snapshot_standby_enabled_till)
  SENSITIVE = []
  include Aws::Structure
end

#is_replicate_automatic_backupsBoolean

Indicates whether automatic backups are replicated to the disaster recovery database.

Returns:

  • (Boolean)


5808
5809
5810
5811
5812
5813
5814
5815
# File 'lib/aws-sdk-odb/types.rb', line 5808

class DisasterRecoveryConfiguration < Struct.new(
  :disaster_recovery_type,
  :is_replicate_automatic_backups,
  :is_snapshot_standby,
  :time_snapshot_standby_enabled_till)
  SENSITIVE = []
  include Aws::Structure
end

#is_snapshot_standbyBoolean

Indicates whether the standby database is a snapshot standby.

Returns:

  • (Boolean)


5808
5809
5810
5811
5812
5813
5814
5815
# File 'lib/aws-sdk-odb/types.rb', line 5808

class DisasterRecoveryConfiguration < Struct.new(
  :disaster_recovery_type,
  :is_replicate_automatic_backups,
  :is_snapshot_standby,
  :time_snapshot_standby_enabled_till)
  SENSITIVE = []
  include Aws::Structure
end

#time_snapshot_standby_enabled_tillTime

The date and time until which the snapshot standby database remains enabled.

Returns:

  • (Time)


5808
5809
5810
5811
5812
5813
5814
5815
# File 'lib/aws-sdk-odb/types.rb', line 5808

class DisasterRecoveryConfiguration < Struct.new(
  :disaster_recovery_type,
  :is_replicate_automatic_backups,
  :is_snapshot_standby,
  :time_snapshot_standby_enabled_till)
  SENSITIVE = []
  include Aws::Structure
end