Class: Aws::Odb::Types::EncryptionKeyConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Note:

EncryptionKeyConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EncryptionKeyConfiguration corresponding to the set member.

The configuration of the encryption key used for an Autonomous Database. This is a union, so only one of the following members can be specified.

Defined Under Namespace

Classes: AwsEncryptionKey, OciEncryptionKey, OkvEncryptionKey, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_encryption_keyTypes::AwsEncryptionKeyConfiguration

The configuration of the Amazon Web Services Key Management Service (KMS) encryption key.



5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
# File 'lib/aws-sdk-odb/types.rb', line 5839

class EncryptionKeyConfiguration < Struct.new(
  :aws_encryption_key,
  :oci_encryption_key,
  :okv_encryption_key,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AwsEncryptionKey < EncryptionKeyConfiguration; end
  class OciEncryptionKey < EncryptionKeyConfiguration; end
  class OkvEncryptionKey < EncryptionKeyConfiguration; end
  class Unknown < EncryptionKeyConfiguration; end
end

#oci_encryption_keyTypes::OciEncryptionKeyConfiguration

The configuration of the Oracle Cloud Infrastructure (OCI) Vault encryption key.



5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
# File 'lib/aws-sdk-odb/types.rb', line 5839

class EncryptionKeyConfiguration < Struct.new(
  :aws_encryption_key,
  :oci_encryption_key,
  :okv_encryption_key,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AwsEncryptionKey < EncryptionKeyConfiguration; end
  class OciEncryptionKey < EncryptionKeyConfiguration; end
  class OkvEncryptionKey < EncryptionKeyConfiguration; end
  class Unknown < EncryptionKeyConfiguration; end
end

#okv_encryption_keyTypes::OkvEncryptionKeyConfiguration

The configuration of the Oracle Key Vault (OKV) encryption key.



5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
5851
5852
# File 'lib/aws-sdk-odb/types.rb', line 5839

class EncryptionKeyConfiguration < Struct.new(
  :aws_encryption_key,
  :oci_encryption_key,
  :okv_encryption_key,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AwsEncryptionKey < EncryptionKeyConfiguration; end
  class OciEncryptionKey < EncryptionKeyConfiguration; end
  class OkvEncryptionKey < EncryptionKeyConfiguration; end
  class Unknown < EncryptionKeyConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5839
5840
5841
# File 'lib/aws-sdk-odb/types.rb', line 5839

def unknown
  @unknown
end