Class: Aws::Odb::Types::EncryptionKeyConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Note:

EncryptionKeyConfigurationInput is a union - when making an API calls you must set exactly one of the members.

The configuration of the encryption key to use for an Autonomous Database. This is a union, so only one of the following members can be specified.

Direct Known Subclasses

AwsEncryptionKey, Unknown

Defined Under Namespace

Classes: AwsEncryptionKey, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_encryption_keyTypes::AwsEncryptionKeyConfigurationInput

The configuration of the Amazon Web Services Key Management Service (KMS) encryption key to use.



5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
# File 'lib/aws-sdk-odb/types.rb', line 5867

class EncryptionKeyConfigurationInput < Struct.new(
  :aws_encryption_key,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AwsEncryptionKey < EncryptionKeyConfigurationInput; end
  class Unknown < EncryptionKeyConfigurationInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5867
5868
5869
# File 'lib/aws-sdk-odb/types.rb', line 5867

def unknown
  @unknown
end