Class: Aws::Odb::Types::ListDbSystemShapesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ListDbSystemShapesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The logical name of the AZ, for example, us-east-1a.
-
#availability_zone_id ⇒ String
The physical ID of the AZ, for example, use1-az4.
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#shape_family ⇒ String
The shape family to filter results by.
Instance Attribute Details
#availability_zone ⇒ String
The logical name of the AZ, for example, us-east-1a. This name varies depending on the account.
8552 8553 8554 8555 8556 8557 8558 8559 8560 |
# File 'lib/aws-sdk-odb/types.rb', line 8552 class ListDbSystemShapesInput < Struct.new( :max_results, :next_token, :availability_zone, :availability_zone_id, :shape_family) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The physical ID of the AZ, for example, use1-az4. This ID persists across accounts.
8552 8553 8554 8555 8556 8557 8558 8559 8560 |
# File 'lib/aws-sdk-odb/types.rb', line 8552 class ListDbSystemShapesInput < Struct.new( :max_results, :next_token, :availability_zone, :availability_zone_id, :shape_family) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.
Default: 10
8552 8553 8554 8555 8556 8557 8558 8559 8560 |
# File 'lib/aws-sdk-odb/types.rb', line 8552 class ListDbSystemShapesInput < Struct.new( :max_results, :next_token, :availability_zone, :availability_zone_id, :shape_family) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
8552 8553 8554 8555 8556 8557 8558 8559 8560 |
# File 'lib/aws-sdk-odb/types.rb', line 8552 class ListDbSystemShapesInput < Struct.new( :max_results, :next_token, :availability_zone, :availability_zone_id, :shape_family) SENSITIVE = [] include Aws::Structure end |
#shape_family ⇒ String
The shape family to filter results by.
8552 8553 8554 8555 8556 8557 8558 8559 8560 |
# File 'lib/aws-sdk-odb/types.rb', line 8552 class ListDbSystemShapesInput < Struct.new( :max_results, :next_token, :availability_zone, :availability_zone_id, :shape_family) SENSITIVE = [] include Aws::Structure end |