Class: Aws::Odb::Types::ListFlexComponentsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ListFlexComponentsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return for this request.
-
#next_token ⇒ String
The token returned from a previous paginated request.
-
#shape ⇒ String
The shape to return flex components for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output.
8683 8684 8685 8686 8687 8688 8689 |
# File 'lib/aws-sdk-odb/types.rb', line 8683 class ListFlexComponentsInput < Struct.new( :max_results, :next_token, :shape) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
8683 8684 8685 8686 8687 8688 8689 |
# File 'lib/aws-sdk-odb/types.rb', line 8683 class ListFlexComponentsInput < Struct.new( :max_results, :next_token, :shape) SENSITIVE = [] include Aws::Structure end |
#shape ⇒ String
The shape to return flex components for. For a list of valid shapes,
use the ListDbSystemShapes operation.
8683 8684 8685 8686 8687 8688 8689 |
# File 'lib/aws-sdk-odb/types.rb', line 8683 class ListFlexComponentsInput < Struct.new( :max_results, :next_token, :shape) SENSITIVE = [] include Aws::Structure end |