Class: Aws::Odb::Types::ListFlexComponentsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::ListFlexComponentsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flex_components ⇒ Array<Types::FlexComponentSummary>
The list of flex components along with their properties.
-
#next_token ⇒ String
The token to include in another request to get the next page of items.
Instance Attribute Details
#flex_components ⇒ Array<Types::FlexComponentSummary>
The list of flex components along with their properties.
8702 8703 8704 8705 8706 8707 |
# File 'lib/aws-sdk-odb/types.rb', line 8702 class ListFlexComponentsOutput < Struct.new( :next_token, :flex_components) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to include in another request to get the next page of
items. This value is null when there are no more items to return.
8702 8703 8704 8705 8706 8707 |
# File 'lib/aws-sdk-odb/types.rb', line 8702 class ListFlexComponentsOutput < Struct.new( :next_token, :flex_components) SENSITIVE = [] include Aws::Structure end |