Class: Aws::Odb::Types::OdbNetwork

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Information about an ODB network.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Amazon Web Services Availability Zone (AZ) where the ODB network is located.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The AZ ID of the AZ where the ODB network is located.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#backup_subnet_cidrString

The CIDR range of the backup subnet in the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#client_subnet_cidrString

The CIDR range of the client subnet in the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the ODB network was created.

Returns:

  • (Time)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_nameString

The domain name for the resources in the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#default_dns_prefixString

The DNS prefix to the default DNS domain name. The default DNS domain name is oraclevcn.com.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The user-friendly name of the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_placement_group_idsArray<String>

The list of EC2 Placement Group IDs associated with your ODB network.

Returns:

  • (Array<String>)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#managed_servicesTypes::ManagedServices

The managed services configuration for the ODB network.



4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#oci_dns_forwarding_configsArray<Types::OciDnsForwardingConfig>

The DNS resolver endpoint in OCI for forwarding DNS queries for the ociPrivateZone domain.

Returns:



4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#oci_network_anchor_idString

The unique identifier of the OCI network anchor for the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#oci_network_anchor_urlString

The URL of the OCI network anchor for the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#oci_resource_anchor_nameString

The name of the OCI resource anchor that’s associated with the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#oci_vcn_idString

The Oracle Cloud ID (OCID) for the Virtual Cloud Network (VCN) that’s associated with the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#oci_vcn_urlString

The URL for the VCN that’s associated with the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#odb_network_arnString

The Amazon Resource Name (ARN) of the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#odb_network_idString

The unique identifier of the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#peered_cidrsArray<String>

The list of CIDR ranges from the peered VPC that are allowed access to the ODB network.

Returns:

  • (Array<String>)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#percent_progressFloat

The amount of progress made on the current operation on the ODB network, expressed as a percentage.

Returns:

  • (Float)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Additional information about the current status of the ODB network.

Returns:

  • (String)


4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
# File 'lib/aws-sdk-odb/types.rb', line 4722

class OdbNetwork < Struct.new(
  :odb_network_id,
  :display_name,
  :status,
  :status_reason,
  :odb_network_arn,
  :availability_zone,
  :availability_zone_id,
  :client_subnet_cidr,
  :backup_subnet_cidr,
  :custom_domain_name,
  :default_dns_prefix,
  :peered_cidrs,
  :oci_network_anchor_id,
  :oci_network_anchor_url,
  :oci_resource_anchor_name,
  :oci_vcn_id,
  :oci_vcn_url,
  :oci_dns_forwarding_configs,
  :created_at,
  :percent_progress,
  :managed_services,
  :ec2_placement_group_ids)
  SENSITIVE = []
  include Aws::Structure
end