Class: Aws::Odb::Types::OdbNetworkSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::OdbNetworkSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Information about an ODB network.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Amazon Web Services Availability Zone (AZ) where the ODB network is located.
-
#availability_zone_id ⇒ String
The AZ ID of the AZ where the ODB network is located.
-
#backup_subnet_cidr ⇒ String
The CIDR range of the backup subnet in the ODB network.
-
#client_subnet_cidr ⇒ String
The CIDR range of the client subnet in the ODB network.
-
#created_at ⇒ Time
The date and time when the ODB network was created.
-
#custom_domain_name ⇒ String
The domain name for the resources in the ODB network.
-
#default_dns_prefix ⇒ String
The DNS prefix to the default DNS domain name.
-
#display_name ⇒ String
The user-friendly name of the ODB network.
-
#ec2_placement_group_ids ⇒ Array<String>
The list of EC2 Placement Group IDs associated with your ODB network.
-
#managed_services ⇒ Types::ManagedServices
The managed services configuration for the ODB network.
-
#oci_dns_forwarding_configs ⇒ Array<Types::OciDnsForwardingConfig>
The DNS resolver endpoint in OCI for forwarding DNS queries for the ociPrivateZone domain.
-
#oci_network_anchor_id ⇒ String
The unique identifier of the OCI network anchor for the ODB network.
-
#oci_network_anchor_url ⇒ String
The URL of the OCI network anchor for the ODB network.
-
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor associated with the ODB network.
-
#oci_vcn_id ⇒ String
The Oracle Cloud ID (OCID) for the Virtual Cloud Network (VCN) associated with the ODB network.
-
#oci_vcn_url ⇒ String
The URL for the VCN that’s associated with the ODB network.
-
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
-
#odb_network_id ⇒ String
The unique identifier of the ODB network.
-
#peered_cidrs ⇒ Array<String>
The list of CIDR ranges from the peered VPC that are allowed access to the ODB network.
-
#percent_progress ⇒ Float
The amount of progress made on the current operation on the ODB network, expressed as a percentage.
-
#status ⇒ String
The current status of the ODB network.
-
#status_reason ⇒ String
Additional information about the current status of the ODB network.
Instance Attribute Details
#availability_zone ⇒ String
The Amazon Web Services Availability Zone (AZ) where the ODB network is located.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The AZ ID of the AZ where the ODB network is located.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#backup_subnet_cidr ⇒ String
The CIDR range of the backup subnet in the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#client_subnet_cidr ⇒ String
The CIDR range of the client subnet in the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the ODB network was created.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The domain name for the resources in the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#default_dns_prefix ⇒ String
The DNS prefix to the default DNS domain name. The default DNS domain name is oraclevcn.com.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The user-friendly name of the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#ec2_placement_group_ids ⇒ Array<String>
The list of EC2 Placement Group IDs associated with your ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#managed_services ⇒ Types::ManagedServices
The managed services configuration for the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#oci_dns_forwarding_configs ⇒ Array<Types::OciDnsForwardingConfig>
The DNS resolver endpoint in OCI for forwarding DNS queries for the ociPrivateZone domain.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#oci_network_anchor_id ⇒ String
The unique identifier of the OCI network anchor for the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#oci_network_anchor_url ⇒ String
The URL of the OCI network anchor for the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#oci_resource_anchor_name ⇒ String
The name of the OCI resource anchor associated with the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#oci_vcn_id ⇒ String
The Oracle Cloud ID (OCID) for the Virtual Cloud Network (VCN) associated with the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#oci_vcn_url ⇒ String
The URL for the VCN that’s associated with the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#odb_network_id ⇒ String
The unique identifier of the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#peered_cidrs ⇒ Array<String>
The list of CIDR ranges from the peered VPC that are allowed access to the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#percent_progress ⇒ Float
The amount of progress made on the current operation on the ODB network, expressed as a percentage.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Additional information about the current status of the ODB network.
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 |
# File 'lib/aws-sdk-odb/types.rb', line 4848 class OdbNetworkSummary < Struct.new( :odb_network_id, :display_name, :status, :status_reason, :odb_network_arn, :availability_zone, :availability_zone_id, :client_subnet_cidr, :backup_subnet_cidr, :custom_domain_name, :default_dns_prefix, :peered_cidrs, :oci_network_anchor_id, :oci_network_anchor_url, :oci_resource_anchor_name, :oci_vcn_id, :oci_vcn_url, :oci_dns_forwarding_configs, :created_at, :percent_progress, :managed_services, :ec2_placement_group_ids) SENSITIVE = [] include Aws::Structure end |