Class: Aws::Odb::Types::OdbPeeringConnection
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::OdbPeeringConnection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
A peering connection between an ODB network and either another ODB network or a customer-owned VPC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the ODB peering connection was created.
-
#display_name ⇒ String
The display name of the ODB peering connection.
-
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network that initiated the peering connection.
-
#odb_peering_connection_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB peering connection.
-
#odb_peering_connection_id ⇒ String
The unique identifier of the ODB peering connection.
-
#odb_peering_connection_type ⇒ String
The type of the ODB peering connection.
-
#peer_network_arn ⇒ String
The Amazon Resource Name (ARN) of the peer network.
-
#peer_network_cidrs ⇒ Array<String>
The CIDR blocks associated with the peering connection.
-
#percent_progress ⇒ Float
The percentage progress of the ODB peering connection creation or deletion.
-
#status ⇒ String
The status of the ODB peering connection.
-
#status_reason ⇒ String
The reason for the current status of the ODB peering connection.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the ODB peering connection was created.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the ODB peering connection.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network that initiated the peering connection.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB peering connection.
Example: ‘arn:aws:odb:us-east-1:123456789012:odb-peering-connection/odbpcx-abcdefgh12345678`
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_id ⇒ String
The unique identifier of the ODB peering connection. A sample ID is ‘odbpcx-abcdefgh12345678`.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_type ⇒ String
The type of the ODB peering connection.
Valid Values: ‘ODB-VPC | ODB-ODB`
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#peer_network_arn ⇒ String
The Amazon Resource Name (ARN) of the peer network.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#peer_network_cidrs ⇒ Array<String>
The CIDR blocks associated with the peering connection. These CIDR blocks define the IP address ranges that can communicate through the peering connection.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#percent_progress ⇒ Float
The percentage progress of the ODB peering connection creation or deletion.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the ODB peering connection.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status of the ODB peering connection.
7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 7867 7868 |
# File 'lib/aws-sdk-odb/types.rb', line 7854 class OdbPeeringConnection < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |