Class: Aws::Odb::Types::OdbPeeringConnectionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::OdbPeeringConnectionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
A summary of an ODB peering connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the ODB peering connection was created.
-
#display_name ⇒ String
The display name of the ODB peering connection.
-
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network that initiated the peering connection.
-
#odb_peering_connection_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB peering connection.
-
#odb_peering_connection_id ⇒ String
The unique identifier of the ODB peering connection.
-
#odb_peering_connection_type ⇒ String
The type of the ODB peering connection.
-
#peer_network_arn ⇒ String
The Amazon Resource Name (ARN) of the peer network.
-
#peer_network_cidrs ⇒ Array<String>
The CIDR blocks associated with the peering connection.
-
#percent_progress ⇒ Float
The percentage progress of the ODB peering connection creation or deletion.
-
#status ⇒ String
The status of the ODB peering connection.
-
#status_reason ⇒ String
The reason for the current status of the ODB peering connection.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the ODB peering connection was created.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the ODB peering connection.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_network_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB network that initiated the peering connection.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_arn ⇒ String
The Amazon Resource Name (ARN) of the ODB peering connection.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_id ⇒ String
The unique identifier of the ODB peering connection. A sample ID is
odbpcx-abcdefgh12345678.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_type ⇒ String
The type of the ODB peering connection.
Valid Values: ODB-VPC | ODB-ODB
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#peer_network_arn ⇒ String
The Amazon Resource Name (ARN) of the peer network.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#peer_network_cidrs ⇒ Array<String>
The CIDR blocks associated with the peering connection. These CIDR blocks define the IP address ranges that can communicate through the peering connection.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#percent_progress ⇒ Float
The percentage progress of the ODB peering connection creation or deletion.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the ODB peering connection.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status of the ODB peering connection.
8112 8113 8114 8115 8116 8117 8118 8119 8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/aws-sdk-odb/types.rb', line 8112 class OdbPeeringConnectionSummary < Struct.new( :odb_peering_connection_id, :display_name, :status, :status_reason, :odb_peering_connection_arn, :odb_network_arn, :peer_network_arn, :odb_peering_connection_type, :peer_network_cidrs, :created_at, :percent_progress) SENSITIVE = [] include Aws::Structure end |