Class: Aws::Odb::Types::OkvEncryptionKeyConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

The configuration of the Oracle Key Vault (OKV) encryption key used for an Autonomous Database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_directory_nameString

The name of the directory that contains the Oracle Key Vault (OKV) certificate.

Returns:

  • (String)


7969
7970
7971
7972
7973
7974
7975
7976
7977
# File 'lib/aws-sdk-odb/types.rb', line 7969

class OkvEncryptionKeyConfiguration < Struct.new(
  :certificate_directory_name,
  :certificate_id,
  :directory_name,
  :okv_kms_key,
  :okv_uri)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_idString

The identifier of the Oracle Key Vault (OKV) certificate.

Returns:

  • (String)


7969
7970
7971
7972
7973
7974
7975
7976
7977
# File 'lib/aws-sdk-odb/types.rb', line 7969

class OkvEncryptionKeyConfiguration < Struct.new(
  :certificate_directory_name,
  :certificate_id,
  :directory_name,
  :okv_kms_key,
  :okv_uri)
  SENSITIVE = []
  include Aws::Structure
end

#directory_nameString

The name of the directory where the Oracle Key Vault (OKV) configuration is stored.

Returns:

  • (String)


7969
7970
7971
7972
7973
7974
7975
7976
7977
# File 'lib/aws-sdk-odb/types.rb', line 7969

class OkvEncryptionKeyConfiguration < Struct.new(
  :certificate_directory_name,
  :certificate_id,
  :directory_name,
  :okv_kms_key,
  :okv_uri)
  SENSITIVE = []
  include Aws::Structure
end

#okv_kms_keyString

The identifier of the Oracle Key Vault (OKV) key to use for encryption.

Returns:

  • (String)


7969
7970
7971
7972
7973
7974
7975
7976
7977
# File 'lib/aws-sdk-odb/types.rb', line 7969

class OkvEncryptionKeyConfiguration < Struct.new(
  :certificate_directory_name,
  :certificate_id,
  :directory_name,
  :okv_kms_key,
  :okv_uri)
  SENSITIVE = []
  include Aws::Structure
end

#okv_uriString

The URI of the Oracle Key Vault (OKV) server.

Returns:

  • (String)


7969
7970
7971
7972
7973
7974
7975
7976
7977
# File 'lib/aws-sdk-odb/types.rb', line 7969

class OkvEncryptionKeyConfiguration < Struct.new(
  :certificate_directory_name,
  :certificate_id,
  :directory_name,
  :okv_kms_key,
  :okv_uri)
  SENSITIVE = []
  include Aws::Structure
end