Class: Aws::Odb::Types::OkvEncryptionKeyConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::OkvEncryptionKeyConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The configuration of the Oracle Key Vault (OKV) encryption key used for an Autonomous Database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_directory_name ⇒ String
The name of the directory that contains the Oracle Key Vault (OKV) certificate.
-
#certificate_id ⇒ String
The identifier of the Oracle Key Vault (OKV) certificate.
-
#directory_name ⇒ String
The name of the directory where the Oracle Key Vault (OKV) configuration is stored.
-
#okv_kms_key ⇒ String
The identifier of the Oracle Key Vault (OKV) key to use for encryption.
-
#okv_uri ⇒ String
The URI of the Oracle Key Vault (OKV) server.
Instance Attribute Details
#certificate_directory_name ⇒ String
The name of the directory that contains the Oracle Key Vault (OKV) certificate.
7969 7970 7971 7972 7973 7974 7975 7976 7977 |
# File 'lib/aws-sdk-odb/types.rb', line 7969 class OkvEncryptionKeyConfiguration < Struct.new( :certificate_directory_name, :certificate_id, :directory_name, :okv_kms_key, :okv_uri) SENSITIVE = [] include Aws::Structure end |
#certificate_id ⇒ String
The identifier of the Oracle Key Vault (OKV) certificate.
7969 7970 7971 7972 7973 7974 7975 7976 7977 |
# File 'lib/aws-sdk-odb/types.rb', line 7969 class OkvEncryptionKeyConfiguration < Struct.new( :certificate_directory_name, :certificate_id, :directory_name, :okv_kms_key, :okv_uri) SENSITIVE = [] include Aws::Structure end |
#directory_name ⇒ String
The name of the directory where the Oracle Key Vault (OKV) configuration is stored.
7969 7970 7971 7972 7973 7974 7975 7976 7977 |
# File 'lib/aws-sdk-odb/types.rb', line 7969 class OkvEncryptionKeyConfiguration < Struct.new( :certificate_directory_name, :certificate_id, :directory_name, :okv_kms_key, :okv_uri) SENSITIVE = [] include Aws::Structure end |
#okv_kms_key ⇒ String
The identifier of the Oracle Key Vault (OKV) key to use for encryption.
7969 7970 7971 7972 7973 7974 7975 7976 7977 |
# File 'lib/aws-sdk-odb/types.rb', line 7969 class OkvEncryptionKeyConfiguration < Struct.new( :certificate_directory_name, :certificate_id, :directory_name, :okv_kms_key, :okv_uri) SENSITIVE = [] include Aws::Structure end |
#okv_uri ⇒ String
The URI of the Oracle Key Vault (OKV) server.
7969 7970 7971 7972 7973 7974 7975 7976 7977 |
# File 'lib/aws-sdk-odb/types.rb', line 7969 class OkvEncryptionKeyConfiguration < Struct.new( :certificate_directory_name, :certificate_id, :directory_name, :okv_kms_key, :okv_uri) SENSITIVE = [] include Aws::Structure end |