Class: Aws::Odb::Types::PointInTimeRestoreConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::PointInTimeRestoreConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
The configuration for creating an Autonomous Database by restoring to a point in time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clone_table_space_list ⇒ Array<Integer>
The list of tablespace identifiers to clone from the point-in-time restore.
-
#clone_type ⇒ String
The type of clone to create from the point-in-time restore.
-
#source_autonomous_database_id ⇒ String
The unique identifier of the source Autonomous Database to restore from.
-
#timestamp ⇒ Time
The date and time to which to restore the Autonomous Database.
-
#use_latest_available_backup_timestamp ⇒ Boolean
Indicates whether to use the latest available backup timestamp for the restore.
Instance Attribute Details
#clone_table_space_list ⇒ Array<Integer>
The list of tablespace identifiers to clone from the point-in-time restore.
8007 8008 8009 8010 8011 8012 8013 8014 8015 |
# File 'lib/aws-sdk-odb/types.rb', line 8007 class PointInTimeRestoreConfiguration < Struct.new( :source_autonomous_database_id, :clone_type, :timestamp, :use_latest_available_backup_timestamp, :clone_table_space_list) SENSITIVE = [] include Aws::Structure end |
#clone_type ⇒ String
The type of clone to create from the point-in-time restore.
8007 8008 8009 8010 8011 8012 8013 8014 8015 |
# File 'lib/aws-sdk-odb/types.rb', line 8007 class PointInTimeRestoreConfiguration < Struct.new( :source_autonomous_database_id, :clone_type, :timestamp, :use_latest_available_backup_timestamp, :clone_table_space_list) SENSITIVE = [] include Aws::Structure end |
#source_autonomous_database_id ⇒ String
The unique identifier of the source Autonomous Database to restore from.
8007 8008 8009 8010 8011 8012 8013 8014 8015 |
# File 'lib/aws-sdk-odb/types.rb', line 8007 class PointInTimeRestoreConfiguration < Struct.new( :source_autonomous_database_id, :clone_type, :timestamp, :use_latest_available_backup_timestamp, :clone_table_space_list) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The date and time to which to restore the Autonomous Database.
8007 8008 8009 8010 8011 8012 8013 8014 8015 |
# File 'lib/aws-sdk-odb/types.rb', line 8007 class PointInTimeRestoreConfiguration < Struct.new( :source_autonomous_database_id, :clone_type, :timestamp, :use_latest_available_backup_timestamp, :clone_table_space_list) SENSITIVE = [] include Aws::Structure end |
#use_latest_available_backup_timestamp ⇒ Boolean
Indicates whether to use the latest available backup timestamp for the restore.
8007 8008 8009 8010 8011 8012 8013 8014 8015 |
# File 'lib/aws-sdk-odb/types.rb', line 8007 class PointInTimeRestoreConfiguration < Struct.new( :source_autonomous_database_id, :clone_type, :timestamp, :use_latest_available_backup_timestamp, :clone_table_space_list) SENSITIVE = [] include Aws::Structure end |