Class: Aws::Odb::Types::RebootAutonomousDatabaseInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::RebootAutonomousDatabaseInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to reboot.
-
#is_online_reboot ⇒ Boolean
Specifies whether to perform an online reboot of the Autonomous Database without interrupting active connections.
Instance Attribute Details
#autonomous_database_id ⇒ String
The unique identifier of the Autonomous Database to reboot.
8028 8029 8030 8031 8032 8033 |
# File 'lib/aws-sdk-odb/types.rb', line 8028 class RebootAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :is_online_reboot) SENSITIVE = [] include Aws::Structure end |
#is_online_reboot ⇒ Boolean
Specifies whether to perform an online reboot of the Autonomous Database without interrupting active connections.
8028 8029 8030 8031 8032 8033 |
# File 'lib/aws-sdk-odb/types.rb', line 8028 class RebootAutonomousDatabaseInput < Struct.new( :autonomous_database_id, :is_online_reboot) SENSITIVE = [] include Aws::Structure end |