Class: Aws::Odb::Types::UpdateOdbNetworkInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::UpdateOdbNetworkInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cross_region_s3_restore_sources_to_disable ⇒ Array<String>
The cross-Region Amazon S3 restore sources to disable for the ODB network.
-
#cross_region_s3_restore_sources_to_enable ⇒ Array<String>
The cross-Region Amazon S3 restore sources to enable for the ODB network.
-
#display_name ⇒ String
The new user-friendly name of the ODB network.
-
#kms_access ⇒ String
The Amazon Web Services Key Management Service (KMS) access configuration for the ODB network.
-
#kms_policy_document ⇒ String
The Amazon Web Services Key Management Service (KMS) policy document that defines permissions for key usage within the ODB network.
-
#odb_network_id ⇒ String
The unique identifier of the ODB network to update.
-
#peered_cidrs_to_be_added ⇒ Array<String>
The list of CIDR ranges from the peered VPC that allow access to the ODB network.
-
#peered_cidrs_to_be_removed ⇒ Array<String>
The list of CIDR ranges from the peered VPC to remove from the ODB network.
-
#s3_access ⇒ String
Specifies the updated configuration for Amazon S3 access from the ODB network.
-
#s3_policy_document ⇒ String
Specifies the updated endpoint policy for Amazon S3 access from the ODB network.
-
#sts_access ⇒ String
The Amazon Web Services Security Token Service (STS) access configuration for the ODB network.
-
#sts_policy_document ⇒ String
The Amazon Web Services Security Token Service (STS) policy document that defines permissions for token service usage within the ODB network.
-
#zero_etl_access ⇒ String
Specifies the updated configuration for Zero-ETL access from the ODB network.
Instance Attribute Details
#cross_region_s3_restore_sources_to_disable ⇒ Array<String>
The cross-Region Amazon S3 restore sources to disable for the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#cross_region_s3_restore_sources_to_enable ⇒ Array<String>
The cross-Region Amazon S3 restore sources to enable for the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The new user-friendly name of the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#kms_access ⇒ String
The Amazon Web Services Key Management Service (KMS) access configuration for the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#kms_policy_document ⇒ String
The Amazon Web Services Key Management Service (KMS) policy document that defines permissions for key usage within the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#odb_network_id ⇒ String
The unique identifier of the ODB network to update.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#peered_cidrs_to_be_added ⇒ Array<String>
The list of CIDR ranges from the peered VPC that allow access to the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#peered_cidrs_to_be_removed ⇒ Array<String>
The list of CIDR ranges from the peered VPC to remove from the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#s3_access ⇒ String
Specifies the updated configuration for Amazon S3 access from the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#s3_policy_document ⇒ String
Specifies the updated endpoint policy for Amazon S3 access from the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#sts_access ⇒ String
The Amazon Web Services Security Token Service (STS) access configuration for the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#sts_policy_document ⇒ String
The Amazon Web Services Security Token Service (STS) policy document that defines permissions for token service usage within the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |
#zero_etl_access ⇒ String
Specifies the updated configuration for Zero-ETL access from the ODB network.
9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 |
# File 'lib/aws-sdk-odb/types.rb', line 9448 class UpdateOdbNetworkInput < Struct.new( :odb_network_id, :display_name, :peered_cidrs_to_be_added, :peered_cidrs_to_be_removed, :s3_access, :zero_etl_access, :sts_access, :kms_access, :s3_policy_document, :sts_policy_document, :kms_policy_document, :cross_region_s3_restore_sources_to_enable, :cross_region_s3_restore_sources_to_disable) SENSITIVE = [] include Aws::Structure end |