Class: Aws::Odb::Types::UpdateOdbNetworkInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cross_region_s3_restore_sources_to_disableArray<String>

The cross-Region Amazon S3 restore sources to disable for the ODB network.

Returns:

  • (Array<String>)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#cross_region_s3_restore_sources_to_enableArray<String>

The cross-Region Amazon S3 restore sources to enable for the ODB network.

Returns:

  • (Array<String>)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The new user-friendly name of the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#kms_accessString

The Amazon Web Services Key Management Service (KMS) access configuration for the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#kms_policy_documentString

The Amazon Web Services Key Management Service (KMS) policy document that defines permissions for key usage within the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#odb_network_idString

The unique identifier of the ODB network to update.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#peered_cidrs_to_be_addedArray<String>

The list of CIDR ranges from the peered VPC that allow access to the ODB network.

Returns:

  • (Array<String>)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#peered_cidrs_to_be_removedArray<String>

The list of CIDR ranges from the peered VPC to remove from the ODB network.

Returns:

  • (Array<String>)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#s3_accessString

Specifies the updated configuration for Amazon S3 access from the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#s3_policy_documentString

Specifies the updated endpoint policy for Amazon S3 access from the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#sts_accessString

The Amazon Web Services Security Token Service (STS) access configuration for the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#sts_policy_documentString

The Amazon Web Services Security Token Service (STS) policy document that defines permissions for token service usage within the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end

#zero_etl_accessString

Specifies the updated configuration for Zero-ETL access from the ODB network.

Returns:

  • (String)


5478
5479
5480
5481
5482
5483
5484
5485
5486
5487
5488
5489
5490
5491
5492
5493
5494
# File 'lib/aws-sdk-odb/types.rb', line 5478

class UpdateOdbNetworkInput < Struct.new(
  :odb_network_id,
  :display_name,
  :peered_cidrs_to_be_added,
  :peered_cidrs_to_be_removed,
  :s3_access,
  :zero_etl_access,
  :sts_access,
  :kms_access,
  :s3_policy_document,
  :sts_policy_document,
  :kms_policy_document,
  :cross_region_s3_restore_sources_to_enable,
  :cross_region_s3_restore_sources_to_disable)
  SENSITIVE = []
  include Aws::Structure
end