Class: Aws::Odb::Types::UpdateOdbPeeringConnectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::UpdateOdbPeeringConnectionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
A new display name for the peering connection.
-
#odb_peering_connection_id ⇒ String
The identifier of the Oracle Database@Amazon Web Services peering connection to update.
-
#peer_network_cidrs_to_be_added ⇒ Array<String>
A list of CIDR blocks to add to the peering connection.
-
#peer_network_cidrs_to_be_removed ⇒ Array<String>
A list of CIDR blocks to remove from the peering connection.
Instance Attribute Details
#display_name ⇒ String
A new display name for the peering connection.
9310 9311 9312 9313 9314 9315 9316 9317 |
# File 'lib/aws-sdk-odb/types.rb', line 9310 class UpdateOdbPeeringConnectionInput < Struct.new( :odb_peering_connection_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_cidrs_to_be_removed) SENSITIVE = [] include Aws::Structure end |
#odb_peering_connection_id ⇒ String
The identifier of the Oracle Database@Amazon Web Services peering connection to update.
9310 9311 9312 9313 9314 9315 9316 9317 |
# File 'lib/aws-sdk-odb/types.rb', line 9310 class UpdateOdbPeeringConnectionInput < Struct.new( :odb_peering_connection_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_cidrs_to_be_removed) SENSITIVE = [] include Aws::Structure end |
#peer_network_cidrs_to_be_added ⇒ Array<String>
A list of CIDR blocks to add to the peering connection. These CIDR blocks define the IP address ranges that can communicate through the peering connection. The CIDR blocks must not overlap with existing CIDR blocks in the Oracle Database@Amazon Web Services network.
9310 9311 9312 9313 9314 9315 9316 9317 |
# File 'lib/aws-sdk-odb/types.rb', line 9310 class UpdateOdbPeeringConnectionInput < Struct.new( :odb_peering_connection_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_cidrs_to_be_removed) SENSITIVE = [] include Aws::Structure end |
#peer_network_cidrs_to_be_removed ⇒ Array<String>
A list of CIDR blocks to remove from the peering connection. The CIDR blocks must currently exist in the peering connection.
9310 9311 9312 9313 9314 9315 9316 9317 |
# File 'lib/aws-sdk-odb/types.rb', line 9310 class UpdateOdbPeeringConnectionInput < Struct.new( :odb_peering_connection_id, :display_name, :peer_network_cidrs_to_be_added, :peer_network_cidrs_to_be_removed) SENSITIVE = [] include Aws::Structure end |