Class: Aws::Odb::Types::WalletPasswordSourceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Note:

WalletPasswordSourceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WalletPasswordSourceConfiguration corresponding to the set member.

The configuration of the wallet password source. This is a union, so only one of the following members can be specified.

Defined Under Namespace

Classes: CustomerManagedAwsSecret, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_managed_aws_secretTypes::CustomerManagedAwsSecretConfiguration

The configuration for a customer-managed Amazon Web Services Secrets Manager secret used as the wallet password source.



9605
9606
9607
9608
9609
9610
9611
9612
9613
9614
# File 'lib/aws-sdk-odb/types.rb', line 9605

class WalletPasswordSourceConfiguration < Struct.new(
  :customer_managed_aws_secret,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerManagedAwsSecret < WalletPasswordSourceConfiguration; end
  class Unknown < WalletPasswordSourceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9605
9606
9607
# File 'lib/aws-sdk-odb/types.rb', line 9605

def unknown
  @unknown
end