Class: Aws::Odb::Types::WalletPasswordSourceConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-odb/types.rb

Overview

Note:

WalletPasswordSourceConfigurationInput is a union - when making an API calls you must set exactly one of the members.

The input configuration for the wallet password source. This is a union, so only one of the following members can be specified.

Defined Under Namespace

Classes: CustomerManagedAwsSecret, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_managed_aws_secretTypes::CustomerManagedAwsSecretConfigurationInput

The configuration for using a customer-managed Amazon Web Services Secrets Manager secret as the wallet password source.



9628
9629
9630
9631
9632
9633
9634
9635
9636
9637
# File 'lib/aws-sdk-odb/types.rb', line 9628

class WalletPasswordSourceConfigurationInput < Struct.new(
  :customer_managed_aws_secret,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CustomerManagedAwsSecret < WalletPasswordSourceConfigurationInput; end
  class Unknown < WalletPasswordSourceConfigurationInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9628
9629
9630
# File 'lib/aws-sdk-odb/types.rb', line 9628

def unknown
  @unknown
end