Class: Aws::Odb::Types::WalletPasswordSourceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-odb/types.rb

Overview

A summary of the password source configuration for an Autonomous Database wallet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#password_sourceString

The source of the password for the Autonomous Database wallet.

Returns:

  • (String)


9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-odb/types.rb', line 9653

class WalletPasswordSourceSummary < Struct.new(
  :password_source,
  :password_source_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#password_source_configurationTypes::WalletPasswordSourceConfiguration

The configuration of the password source for the Autonomous Database wallet.



9653
9654
9655
9656
9657
9658
# File 'lib/aws-sdk-odb/types.rb', line 9653

class WalletPasswordSourceSummary < Struct.new(
  :password_source,
  :password_source_configuration)
  SENSITIVE = []
  include Aws::Structure
end