Class: Aws::Odb::Types::WalletPasswordSourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Odb::Types::WalletPasswordSourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-odb/types.rb
Overview
A summary of the password source configuration for an Autonomous Database wallet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#password_source ⇒ String
The source of the password for the Autonomous Database wallet.
-
#password_source_configuration ⇒ Types::WalletPasswordSourceConfiguration
The configuration of the password source for the Autonomous Database wallet.
Instance Attribute Details
#password_source ⇒ String
The source of the password for the Autonomous Database wallet.
9653 9654 9655 9656 9657 9658 |
# File 'lib/aws-sdk-odb/types.rb', line 9653 class WalletPasswordSourceSummary < Struct.new( :password_source, :password_source_configuration) SENSITIVE = [] include Aws::Structure end |
#password_source_configuration ⇒ Types::WalletPasswordSourceConfiguration
The configuration of the password source for the Autonomous Database wallet.
9653 9654 9655 9656 9657 9658 |
# File 'lib/aws-sdk-odb/types.rb', line 9653 class WalletPasswordSourceSummary < Struct.new( :password_source, :password_source_configuration) SENSITIVE = [] include Aws::Structure end |